version 8.2
clear
set more off

capture log close
log using "brazrloc/logs/globfindata.log", replace


/* Auxiliary Programs */

capture program drop fillval
program define fillval
    syntax [varlist]
    local nvar : word count `varlist'
    foreach var of local varlist {
        sort day
        forvalues j = 1/28 {
            qui replace `var' = `var'[_n-`j'] if `var'==.
            }
        }
end

capture program drop day2mo
program define day2mo
    qui gen _mo = month(day)
    qui gen _year = year(day)
    sort _year _mo day
    qui by _year _mo: keep if _n==_N
    drop _*
    sort day
end

capture program drop day2year
program define day2year
    qui gen _year = year(day)
    sort _year day
    qui by _year: keep if _n==_N
    drop _*
    sort day
end

capture program drop day2yearavg
program define day2yearavg
    syntax [varlist]
    qui gen int year = year(day)
    label var year "Calendar Year"
    collapse (mean) `varlist', by(year) fast
    foreach var of local varlist {
      local lbl = subinstr("`var'","_close","",.)
      label var `var' "`lbl'"
      rename `var' `lbl'
      }
    order year
    sort year
end

capture program drop transdate
program define transdate
    args day newvar
    gen str `newvar' = string(day(`day')) + "-" + string(year(`day'))
    local i 1
    foreach month in "Jan" "Feb" "Mar" "Apr" "May" "Jun" "Jul" "Aug" "Sep" "Oct" "Nov" "Dec" {
      replace `newvar' = "`month'" + `newvar' if month(`day')==`i'
      local i = `i' + 1
      }
    drop `day'
    order `newvar'
end


/* PREPARE GLOBAL FINANCIAL DATA */

* __brl_d: Brazil Real, 1986-2007 (monthly)
* cpbram:  Brazil Consumer Price Index, 1986-2007 (monthly)
* wpbram:  Brazil Producer Price Index, 1986-2007 (monthly)
* idbrasd: Brazil Deposit Rate Over SELIC, 1988-2007 (monthly)
* imbrad:  Brazil Overnight Interest Rate, 1986-2004 (monthly)
* itbra3d: Brazil 3-month Treasury Bill Yield, 1986-2007 (monthly)
* _ibx50d: Sao Paulo IBrX-50 Return Index, 1987-2007 (monthly)
* sybraym: Brazil Dividend Yield, 1988-2007 (monthly)

local country = "brazil"
tempfile `country'
local i 0
foreach file in "gfd/__brl_d" "gfd/cpbram" "gfd/wpbram" "gfd/idbrasd" "gfd/imbrad" "gfd/itbra3d" "gfd/_ibx50d" "gfd/sybraym" {
    local i = `i' + 1
    local series = substr("`file'",-index(reverse("`file'"),"/")+1,index(reverse("`file'"),"/")-1)
    local dir = substr("`file'",1,index("`file'","/")-1)
    local loadfile = "`dir'/" + upper("`series'")
    insheet using "brazrloc/auxil/`loadfile'.csv", comma names clear
    gen day = date(date,"mdy")
    format day %d
    order day
    sort day
    drop if day==. & trim(lower(substr(date,1,12)))~="description:"
    local descrpt = date[_N]
    drop date
    drop if day==.
    local descrpt = subinstr("`descrpt'","Description: ","",.)
    if index("`descrpt'"," - ")~=0  local descrpt = trim(subinstr(substr("`descrpt'",index("`descrpt'"," - "),.),"- ","",.))
    label var day "Calendar Day"
    foreach var in open high low close volume openint {
      capture rename `var' `series'_`var'
      capture confirm string variable `series'_`var'
      if _rc==0 {
        gen _`series'_`var' = real(subinstr(`series'_`var',",","",.))
        drop `series'_`var'
        rename _`series'_`var' `series'_`var'
        }
      local newlbl = proper("`var'")
      capture label var `series'_`var' "`descrpt': `newlbl'"
      }
    sort day
    if `i'~=1 {
        merge day using ``country''
        drop _m
        }
    sort day
    compress
    save ``country'', replace
}

fillval
day2yearavg *_close

label var __brl_d "Brazil Real"
label var cpbram  "Brazil Consumer Price Index"
label var wpbram  "Brazil Producer Price Index"
label var idbrasd "Brazil Deposit Rate Over SELIC"
label var imbrad  "Brazil Overnight Interest Rate"
label var itbra3d "Brazil 3-month T-Bill Yield"
label var _ibx50d "Sao Paulo IBrX-50 Return Index"
label var sybraym "Brazil Dividend Yield"

order year __brl_d cpbram wpbram idbrasd imbrad itbra3d _ibx50d sybraym
sort year
compress
save "brazrloc/auxil/globfin-annual", replace

log close
