version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/tex/v4/natl"
capture mkdir "brazrloc/tex/v4/natl/cohortstats"


capture log close
log using "brazrloc/logs/cohort-stats.log", replace


// RAIS: NATIONAL 1-PERCENT SAMPLE, END-OF-YEAR EMPLOYMENTS, SEPARATIONS AND ACCESSIONS

use wid ano sexo identificad mes_deslig mes_adm rem_media subs_ibge caus_desl_tc tipo_adm fx_etaria temp_empr grau_instr cbogrp occagg if ano<=1998 using "brazrloc/data/wid-draw-workers-natl", clear
gen byte indfemal = (sexo==2) // female workers
label var indfemal "Indic.: Female worker"
drop sexo
rename ano year
sort wid year 

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if year==.

* identify separation (excluding transfer, death, and retirement)
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
label var inddspl "Indic.: Separation"
gen byte indlayoff = ( inddspl==1 & ( caus_desl==1 | caus_desl==2 ) )
label var indlayoff "Indic.: Layoff"
gen byte indquit = ( inddspl==1 & ( caus_desl==3 | caus_desl==4 ) )
label var indquit "Indic.: Quit"
drop caus_desl_tc

* identify accession (excluding transfer)
gen byte indhire = (mes_adm > 0 & tipo_adm~=0 & tipo_adm~=3 & tipo_adm~=4)
label var indhire "Indic.: Accession"
drop tipo_adm

* keep last employment per year
egen byte _lastjob = max(mes_deslig), by(wid year)
gen byte indexcl = (mes_deslig~=_lastjob)
label var indexcl "Indic.: Not last job in year"
drop _lastjob

* keep employment with highest pay if more than one last employment per year (random drop for pay ties)
sort wid year indexcl rem_media
by wid year indexcl: replace indexcl=1 if _n~=_N

* sector variables, mapping with subs_ibge
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/balassa-compadv-subsibge", nokeep
tab _m  // _m==1: workers in nontraded goods sectors
drop _m wrld_exp wrld_tot braz_exp braz_tot
rename subsibge subs_ibge
rename balcadv subs_balcadv

* merge additional sector information
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/sector-subsibge-data", nokeep
tab _m  // _m==1: could be years 1999 through 2001 if not dropped before
count if _m~=3
if `r(N)'>0  STOP  // incomplete sector-year mapping
drop _m subs_fdistk subs_indunsklb

* reset private-job share before 1995 to 1995
replace subs_indprown_pis = subs_indprown_pis_95 if subs_indprown_pis==.
drop subs_indprown_pis_95

* outsourceable job share
sort cbogrp
merge cbogrp using "brazaux/auxil/cbogrp-outsourcing", nokeep
tab _m  // _m==1: CBO group missing
count if _m~=3 & cbogrp~=.
if `r(N)'>0  STOP  // incomplete CBO mapping
rename indoutsrc occ_indoutsrc
drop _m cbogrp

* merge RAIS information by plant
rename year ano
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-data-natl", nokeep
tab _m  // _m==1: single worker firms will be omitted from regression with plant-level variables
drop _m
replace plant_n_pis = ln(plant_n_pis)
rename plant_n_pis plant_lnempl
label var plant_lnempl "Log Employment"

* switch to firm level (firm ID)
replace identificad = int(identificad/1000000)
rename identificad cnpj_radic
label var cnpj_radic "Firm ID (CGC/CNPJ, firm part)"

* merge export status information by firm
sort cnpj_radic ano
merge cnpj_radic ano using "brazaux/secex/brazaux-exporters", nokeep
gen byte indexp = (_merge==3)
replace indexp = . if ano<1990 | ano>2001  // no SECEX information prior to 1990 or after 2001
label define indexp 0 "Nonexporter", modify
label define indexp 1 "Exporter", modify
label var indexp "Indic.: Exporter"
label values indexp indexp
drop _m
rename ano year
rename indexp firm_indexp

* merge PIA information
rename cnpj_radic firm
sort firm year
merge firm year using "brazrloc/data/pia-data"
tab _m
drop if _m==2
drop firm_lntfp firm_ln_cap_empl _m
iis, clear
tis, clear
tsset, clear
rename firm cnpj_radic

* tenure
replace temp_empr = temp_empr/52
rename temp_empr tenuryr
label var tenuryr "Tenure at plant (in years)"
gen tenr2 = tenuryr*tenuryr
label var tenr2 "Quadratic Tenure Term"

* potential experience
gen workrage = 12 if fx_etaria==1
replace workrage =   16 if fx_etaria==2
replace workrage =   21 if fx_etaria==3
replace workrage =   27 if fx_etaria==4
replace workrage = 34.5 if fx_etaria==5
replace workrage = 44.5 if fx_etaria==6
replace workrage =   57 if fx_etaria==7
replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
gen potexper     = workrage -  6 if grau_instr==1
replace potexper = workrage -  7 if grau_instr==2
replace potexper = workrage - 10 if grau_instr==3
replace potexper = workrage - 11 if grau_instr==4
replace potexper = workrage - 14 if grau_instr==5
replace potexper = workrage - 15 if grau_instr==6
replace potexper = workrage - 18 if grau_instr==7
replace potexper = workrage - 19 if grau_instr==8
replace potexper = workrage - 22 if grau_instr==9
label var potexper "Potential labor force experience"
drop workrage fx_etaria
gen potxper2 = potexper*potexper
label var potxper2 "Quadratic Experience Term"

* education indicators
gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
gen byte indscoll = (grau_instr==8)
label var indscoll "Some College Education"
gen byte indgrad = (grau_instr==9)
label var indgrad "Complete College Education"
drop grau_instr

* occupation indicators (based on 3-digit cbo; see rais/cbo/cbogrp2occagg.csv)
gen byte indprof = (occagg==1)
label var indprof "Professional or Managerial Occ."
gen byte indtech = (occagg==2)
label var indtech "Technical or Supervisory Occup."
gen byte indwhit = (occagg==3)
label var indwhit "Other White Collar Occupation"
gen byte indsklb = (occagg==4)
label var indsklb "Skilled Blue Collar Occupation"
gen byte indunsklb = (occagg==5)
label var indunsklb "Unskilled Blue Collar Occupation"
drop occagg


// SUMM2TEX

keep if year>=1990 & year<=1998

summ2tex *, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_empl_allsec) replace detail
summ2tex * if balarank==5, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_empl_balrnk5) replace detail
summ2tex * if firm_indexp, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_empl_indexp) replace detail

summ2tex * if inddspl==1, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_dspl_allsec) replace detail
summ2tex * if inddspl==1 & balarank==5, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_dspl_balrnk5) replace detail
summ2tex * if inddspl==1 & firm_indexp, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_dspl_indexp) replace detail

summ2tex * if indhire==1, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_hire_allsec) replace detail
summ2tex * if indhire==1 & balarank==5, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_hire_balrnk5) replace detail
summ2tex * if indhire==1 & firm_indexp, c(mean sd N p50) path(brazrloc/tex/v4/natl/cohortstats) name(summ_hire_indexp) replace detail


// ARRANGE INTO SINGLE TABLE

foreach smpl in empl dspl hire {
  foreach sec in allsec balrnk5 indexp {
    matload summ_`smpl'_`sec'_tbl, path(brazrloc/tex/v4/natl/cohortstats) over dropall
    matorder summ_`smpl'_`sec'_tbl, m(`smpl'_`sec'_b) ifc(mean)
    matorder summ_`smpl'_`sec'_tbl, m(`smpl'_`sec'_se) ifc(sd)
    matorder summ_`smpl'_`sec'_tbl, m(`smpl'_`sec'_e) ifc(N)
    mat drop summ_`smpl'_`sec'_tbl
    local rows = rowsof(`smpl'_`sec'_se)
    forvalues i = 1/`rows' {
      mat `smpl'_`sec'_se[`i',1] = `smpl'_`sec'_se[`i',1]/sqrt(`smpl'_`sec'_e[`i',1])
      }
    matorder `smpl'_`sec'_e, m(`smpl'_`sec'_e) ifr(wid) over
    }
  }
foreach type in b se e {
  mat cohort_`type' = empl_allsec_`type' , empl_balrnk5_`type' , empl_indexp_`type' , dspl_allsec_`type' , dspl_balrnk5_`type' , dspl_indexp_`type' , hire_allsec_`type' , hire_balrnk5_`type' , hire_indexp_`type'
  mat drop empl_allsec_`type' empl_balrnk5_`type' empl_indexp_`type' dspl_allsec_`type' dspl_balrnk5_`type' dspl_indexp_`type' hire_allsec_`type' hire_balrnk5_`type' hire_indexp_`type'
  matrix colnames cohort_`type' = empl:allsec empl:balrnk5 empl:indexp dspl:allsec dspl:balrnk5 dspl:indexp hire:allsec hire:balrnk5 hire:indexp
  }
mat rownames cohort_e = r(N)

est2extlbl, addto(cohort) intex($root/brazrloc/%stata/rowlbl-brazrloc) p(brazrloc/tex/v4/natl/cohortstats) replace
est2tex cohort, replace p(brazrloc/tex/v4/natl/cohortstats) fancy digits(2) dropall extracols(3 6)


* Clean up
foreach type in b se e tbl {
  capture mat drop cohort_`type'
  }

log close
