version 8
set more off
set virtual on
clear
set trace off

cd "$root"

capture mkdir "brazrloc/graphs/v4/natl-maleprime"
capture mkdir "brazrloc/tex/v4/natl-maleprime"
capture mkdir "brazrloc/graphs/v4/natl-maleprime/duration"
capture mkdir "brazrloc/tex/v4/natl-maleprime/duration"

capture log close
log using "brazrloc/logs/durations-natl-maleprime.log", replace

* COUNTS OF LACKING REALLOCATIONS AFTER 12, 48 AND 60 MONHTS

foreach dur in 12 48 60 {

use wid ano mes_adm mes_deslig identificad caus_desl_tc fx_etaria sexo occagg grau_instr rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
qui gen byte indany   = 1
label var indany   "Indic.: Full sample"
qui gen byte indskloc = (occagg < 4)
label var indskloc "Indic.: White collar"

* potential experience
qui gen workrage = 12 if fx_etaria==1
qui replace workrage =   16 if fx_etaria==2
qui replace workrage =   21 if fx_etaria==3
qui replace workrage =   27 if fx_etaria==4
qui replace workrage = 34.5 if fx_etaria==5
qui replace workrage = 44.5 if fx_etaria==6
qui replace workrage =   57 if fx_etaria==7
qui replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
qui gen potexper     = workrage -  6 if grau_instr==1
qui replace potexper = workrage -  7 if grau_instr==2
qui replace potexper = workrage - 10 if grau_instr==3
qui replace potexper = workrage - 11 if grau_instr==4
qui replace potexper = workrage - 14 if grau_instr==5
qui replace potexper = workrage - 15 if grau_instr==6
qui replace potexper = workrage - 18 if grau_instr==7
qui replace potexper = workrage - 19 if grau_instr==8
qui replace potexper = workrage - 22 if grau_instr==9
qui label var potexper "Potential labor force experience"
qui gen byte indyoung = (potexper < 10)
label var indyoung "Indic.: 10 yrs or less exprienc."
drop workrage fx_etaria potexper

* education indicators
qui gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
qui gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
qui gen byte indcoll = (grau_instr==8 | grau_instr==9)
label var indcoll "College Education"
drop grau_instr

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
sort wid ano mes_adm mes_deslig identificad

* identify displacement and month of first rehiring
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
by wid: gen str7 morehir = string(mes_adm[_n+1]) + "/" + string(ano[_n+1]) if inddspl==1
label var inddspl "Indic.: Displacement"
label var morehir "Month of first rehiring"

* calculate months from displacement to first rehiring, if within 48 or 60 months
gen mo2rehir = (int(real(substr(morehir,-4,4))) - ano)*12 + (int(real(substr(morehir,1,index(morehir,"/")-1))) - mes_desl)
replace mo2rehir = 0 if int(real(substr(morehir,-4,4)))==ano & int(real(substr(morehir,1,index(morehir,"/")-1)))<mes_desl
replace mo2rehir = . if mo2rehir>`dur'
label var mo2rehir "Months to re-employment"

* summarize indicator variables
disp
disp in gr "Lacking realloction for " in ye `dur' in gr " months"
disp
summ ind*
disp

* assign indicator to workers not reemployed within 48 and 60 months
drop if inddspl==0
gen byte indnorloc = (mo2rehir > `dur' | mo2rehir==.)
keep ano indnorloc indyoung indskloc indprim indhigh indcoll indany mes_desl rem_media
label var indnorloc "Indic.: No reall. in `dur' months"
sort ano mes ind*

* table of means and t-test results by skill group and year
local tabrows "any young skloc prim high coll"
preserve
foreach group in `tabrows' {
  restore, preserve
  collapse (mean) indnorloc rem_media (sd) se_indnorloc=indnorloc (count) n_indnorloc=indnorloc, by(ano ind`group') fast
  if `dur'==60  keep if ano<=1996
  if `dur'==48  keep if ano<=1997
  if `dur'==12  keep if ano<=2000
  replace se_indnorloc=se_indnorloc/sqrt(n_indnorloc)
  keep if ind`group'
  qui reshape wide indnorloc rem_media se_indnorloc n_indnorloc, i(ind`group') j(ano)
  mkmat indnorloc*, mat(_norloc_`group'_b)
  mkmat se_indnorloc*, mat(_norloc_`group'_se)
  mkmat n_indnorloc*, mat(_norloc_`group'_e1)
  mkmat rem_media*, mat(_norloc_`group'_e2)
  mat _norloc_`group'_e = _norloc_`group'_e1 \ _norloc_`group'_e2
  mat drop _norloc_`group'_e1 _norloc_`group'_e2
  }
restore
foreach type in b se e {
  mat indnorloc`dur'mbygrp_`type' = _norloc_any_`type' \ _norloc_young_`type' \ _norloc_skloc_`type' \ _norloc_prim_`type' \ _norloc_high_`type' \ _norloc_coll_`type'
  if "`type'"~="e"  matrix rownames indnorloc`dur'mbygrp_`type' = any:r(mean) young:r(mean) skloc:r(mean) prim:r(mean) high:r(mean) coll:r(mean)
  if "`type'"=="e"  matrix rownames indnorloc`dur'mbygrp_`type' = any:r(N) any:mean_rem_media young:r(N) young:mean_rem_media skloc:r(N) skloc:mean_rem_media prim:r(N) prim:mean_rem_media high:r(N) high:mean_rem_media coll:r(N) coll:mean_rem_media
  mat drop _norloc_any_`type' _norloc_young_`type' _norloc_skloc_`type' _norloc_prim_`type' _norloc_high_`type' _norloc_coll_`type'
  }
foreach group in `tabrows' {
  if `dur'==60  local cols 11
  if `dur'==48  local cols 12
  if `dur'==12  local cols 15
  matrix _norloc_`group'_r = J(3,`cols',.)
  matrix rownames _norloc_`group'_r = r(p) r(t) r(df_t)
  if `dur'==60  local lastano 1996
  if `dur'==48  local lastano 1997
  if `dur'==12  local lastano 2000
  local j 0
  forvalues ano = 1986(1)`lastano' {
    local j = `j' + 1
    matname _norloc_`group'_r ttest`ano', columns(`j') explicit
    if "`group'"~="any" {
      qui ttest indnorloc if ano==`ano', by(ind`group') unequal
      mat _norloc_`group'_r[1,`j']=`r(p)'
      mat _norloc_`group'_r[2,`j']=`r(t)'
      mat _norloc_`group'_r[3,`j']=`r(df_t)'
      }
    }
  }
local type "r"
  mat indnorloc`dur'mbygrp_`type' = _norloc_any_`type' \ _norloc_young_`type' \ _norloc_skloc_`type' \ _norloc_prim_`type' \ _norloc_high_`type' \ _norloc_coll_`type'
  matrix roweq indnorloc`dur'mbygrp_`type' = any any any young young young skloc skloc skloc prim prim prim high high high coll coll coll
  mat drop _norloc_any_`type' _norloc_young_`type' _norloc_skloc_`type' _norloc_prim_`type' _norloc_high_`type' _norloc_coll_`type'
est2tex indnorloc`dur'mbygrp, replace dropall preserve p(brazrloc/tex/v4/natl-maleprime/duration) fancy digits(3)
drop rem_media

* graphs
collapse (mean) indnorloc, by(ano mes_desl) fast
if `dur'==60  keep if ano<=1996
if `dur'==48  keep if ano<=1997
if `dur'==12  keep if ano<=2000
gen day = mdy(mes_desl,1,ano) 
label var day "Month of displacement"
format day %dm/CY
graph twoway connected indnorloc day, ytitle("") legend( label(1 "Share of non-reallocated") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl-maleprime/duration/indnorloc`dur'm.eps", replace
graph twoway connected indnorloc day, ytitle("") legend( label(1 "Share of non-reallocated") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
graph export "brazrloc/graphs/v4/natl-maleprime/duration/indnorloc`dur'm-color.eps", replace

* table by year
collapse (mean) indnorloc, by(ano) fast
gen str7 _rowname = string(ano)
drop ano
order _rowname
sort _rowname
save indnorloc`dur'm_tbl, replace
matload indnorloc`dur'm_tbl, dropall over missing(.)
erase indnorloc`dur'm_tbl.dta
est2tex indnorloc`dur'm, replace dropall preserve ready p(brazrloc/tex/v4/natl-maleprime/duration) fancy digits(3)

}


* DURATIONS OF SUCCESSFUL REALLOCATIONS WITHIN 12, 36 AND 48 MONTHS

foreach dur in 12 36 48 {

use wid ano mes_adm mes_deslig identificad caus_desl_tc fx_etaria sexo occagg grau_instr rem_media using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
qui gen byte indany   = 1
label var indany   "Indic.: Full sample"
qui gen byte indskloc = (occagg < 4)
label var indskloc "Indic.: White collar"

* potential experience
qui gen workrage = 12 if fx_etaria==1
qui replace workrage =   16 if fx_etaria==2
qui replace workrage =   21 if fx_etaria==3
qui replace workrage =   27 if fx_etaria==4
qui replace workrage = 34.5 if fx_etaria==5
qui replace workrage = 44.5 if fx_etaria==6
qui replace workrage =   57 if fx_etaria==7
qui replace workrage =   .  if fx_etaria==8
label var workrage "Mid-point age in age group"
qui gen potexper     = workrage -  6 if grau_instr==1
qui replace potexper = workrage -  7 if grau_instr==2
qui replace potexper = workrage - 10 if grau_instr==3
qui replace potexper = workrage - 11 if grau_instr==4
qui replace potexper = workrage - 14 if grau_instr==5
qui replace potexper = workrage - 15 if grau_instr==6
qui replace potexper = workrage - 18 if grau_instr==7
qui replace potexper = workrage - 19 if grau_instr==8
qui replace potexper = workrage - 22 if grau_instr==9
qui label var potexper "Potential labor force experience"
qui gen byte indyoung = (potexper < 10)
label var indyoung "Indic.: 10 yrs or less exprienc."
drop workrage fx_etaria potexper

* education indicators
qui gen byte indprim = (grau_instr==1 | grau_instr==2 | grau_instr==3 | grau_instr==4 | grau_instr==5)
label var indprim "Primary or Middle School Educ."
qui gen byte indhigh = (grau_instr==6 | grau_instr==7)
label var indhigh "High School Education"
qui gen byte indcoll = (grau_instr==8 | grau_instr==9)
label var indcoll "College Education"
drop grau_instr

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
sort wid ano mes_adm mes_deslig identificad

* identify displacement and month of first rehiring
gen byte inddspl = (mes_deslig < 13 & caus_desl~=0 & caus_desl~=6 & caus_desl~=7 & caus_desl~=8)
by wid: gen str7 morehir = string(mes_adm[_n+1]) + "/" + string(ano[_n+1]) if inddspl==1
label var inddspl "Indic.: Displacement"
label var morehir "Month of first rehiring"

* discard rehirings if plant missing in year before rehiring
sort identificad ano
merge identificad ano using "brazrloc/data/rais-cnpj-list-natl"
tab _m
keep if _m==3
keep wid ano mes_adm mes_deslig identificad inddspl morehir indabsyr1 caus_desl_tc indyoung indskloc indprim indhigh indcoll indany rem_media
sort wid ano mes_adm mes_deslig identificad
by wid: gen inddisc = indabsyr1[_n+1]
label var inddisc "Plant missing year bef. realloc."

* calculate months from displacement to first rehiring, if within 36 or 48 months
gen mo2rehir = (int(real(substr(morehir,-4,4))) - ano)*12 + (int(real(substr(morehir,1,index(morehir,"/")-1))) - mes_desl)
replace mo2rehir = 0 if int(real(substr(morehir,-4,4)))==ano & int(real(substr(morehir,1,index(morehir,"/")-1)))<mes_desl
replace mo2rehir = . if mo2rehir>`dur'
label var mo2rehir "Months to re-employment"

* tabulate months from displacement to first rehiring and t-test by skill group, if within `dur' months but irrespective of plant absence
local tabrows "any young skloc prim high coll"
preserve
foreach group in `tabrows' {
  restore, preserve
  collapse (mean) mo2rehir rem_media (sd) se_mo2rehir=mo2rehir (count) n_mo2rehir=mo2rehir, by(ano ind`group') fast
  if `dur'==12  keep if ano<=2000
  if `dur'==36  keep if ano<=1998
  if `dur'==48  keep if ano<=1997
  replace se_mo2rehir=se_mo2rehir/sqrt(n_mo2rehir)
  keep if ind`group'
  qui reshape wide mo2rehir rem_media se_mo2rehir n_mo2rehir, i(ind`group') j(ano)
  mkmat mo2rehir*, mat(_m2rhr_`group'_b)
  mkmat se_mo2rehir*, mat(_m2rhr_`group'_se)
  mkmat n_mo2rehir*, mat(_m2rhr_`group'_e1)
  mkmat rem_media*, mat(_m2rhr_`group'_e2)
  mat _m2rhr_`group'_e = _m2rhr_`group'_e1 \ _m2rhr_`group'_e2
  mat drop _m2rhr_`group'_e1 _m2rhr_`group'_e2
  }
restore
foreach type in b se e {
  mat mo2rehr`dur'mbygrp_`type' = _m2rhr_any_`type' \ _m2rhr_young_`type' \ _m2rhr_skloc_`type' \ _m2rhr_prim_`type' \ _m2rhr_high_`type' \ _m2rhr_coll_`type'
  if "`type'"~="e"  matrix rownames mo2rehr`dur'mbygrp_`type' = any:r(mean) young:r(mean) skloc:r(mean) prim:r(mean) high:r(mean) coll:r(mean)
  if "`type'"=="e"  matrix rownames mo2rehr`dur'mbygrp_`type' = any:r(N) any:mean_rem_media young:r(N) young:mean_rem_media skloc:r(N) skloc:mean_rem_media prim:r(N) prim:mean_rem_media high:r(N) high:mean_rem_media coll:r(N) coll:mean_rem_media
  mat drop _m2rhr_any_`type' _m2rhr_young_`type' _m2rhr_skloc_`type' _m2rhr_prim_`type' _m2rhr_high_`type' _m2rhr_coll_`type'
  }
foreach group in `tabrows' {
  if `dur'==12  local cols 15
  if `dur'==36  local cols 13
  if `dur'==48  local cols 12
  matrix _m2rhr_`group'_r = J(3,`cols',.)
  matrix rownames _m2rhr_`group'_r = r(p) r(t) r(df_t)
  if `dur'==12  local lastano 2000
  if `dur'==36  local lastano 1998
  if `dur'==48  local lastano 1997
  local j 0
  forvalues ano = 1986(1)`lastano' {
    local j = `j' + 1
    matname _m2rhr_`group'_r ttest`ano', columns(`j') explicit
    if "`group'"~="any" {
      qui ttest mo2rehir if ano==`ano', by(ind`group') unequal
      mat _m2rhr_`group'_r[1,`j']=`r(p)'
      mat _m2rhr_`group'_r[2,`j']=`r(t)'
      mat _m2rhr_`group'_r[3,`j']=`r(df_t)'
      }
    }
  }
local type "r"
  mat mo2rehr`dur'mbygrp_`type' = _m2rhr_any_`type' \ _m2rhr_young_`type' \ _m2rhr_skloc_`type' \ _m2rhr_prim_`type' \ _m2rhr_high_`type' \ _m2rhr_coll_`type'
  matrix roweq mo2rehr`dur'mbygrp_`type' = any any any young young young skloc skloc skloc prim prim prim high high high coll coll coll
  mat drop _m2rhr_any_`type' _m2rhr_young_`type' _m2rhr_skloc_`type' _m2rhr_prim_`type' _m2rhr_high_`type' _m2rhr_coll_`type'
est2tex mo2rehr`dur'mbygrp, replace dropall preserve p(brazrloc/tex/v4/natl-maleprime/duration) fancy digits(3)
drop rem_media

* graph and tabulate months from displacement to first rehiring, if within `dur' months but irrespective of plant absence
preserve
  if `dur'==12  keep if ano<=2000
  if `dur'==36  keep if ano<=1998
  if `dur'==48  keep if ano<=1997
  keep ano mes_desl mo2rehir
  collapse (mean) mo2rehir (median) medmo2rehir=mo2rehir, by(ano mes_desl) fast
  gen day = mdy(mes_desl,1,ano) 
  label var day "Month of displacement"
  label var mo2rehir "Mean months to re-employment"
  label var medmo2rehir "Median months to re-employment"
  format day %dm/CY
  qui regress mo2rehir day if day > mdy(1,1,1986) & day <= mdy(12,31,1989)
  predict mo2rehir_per1 if day <= mdy(12,31,1989), xb
  qui regress mo2rehir day if day > mdy(12,31,1989) & day <= mdy(12,31,1992)
  predict mo2rehir_per2 if day > mdy(12,31,1989) & day <= mdy(12,31,1992), xb
  qui regress mo2rehir if day > mdy(12,31,1992)
  predict mo2rehir_per3 if day > mdy(12,31,1992), xb
  graph twoway connected mo2rehir mo2rehir_per1 mo2rehir_per2 mo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/natl-maleprime/duration/mo2rehr`dur'm.eps", replace
  graph twoway connected mo2rehir mo2rehir_per1 mo2rehir_per2 mo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/natl-maleprime/duration/mo2rehr`dur'm-color.eps", replace
  qui regress medmo2rehir day if day > mdy(1,1,1986) & day <= mdy(12,31,1989)
  predict medmo2rehir_per1 if day <= mdy(12,31,1989), xb
  qui regress medmo2rehir day if day > mdy(12,31,1989) & day <= mdy(12,31,1992)
  predict medmo2rehir_per2 if day > mdy(12,31,1989) & day <= mdy(12,31,1992), xb
  qui regress medmo2rehir if day > mdy(12,31,1992)
  predict medmo2rehir_per3 if day > mdy(12,31,1992), xb
  graph twoway connected medmo2rehir medmo2rehir_per1 medmo2rehir_per2 medmo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/natl-maleprime/duration/medmo2rehr`dur'm.eps", replace
  graph twoway connected medmo2rehir medmo2rehir_per1 medmo2rehir_per2 medmo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/natl-maleprime/duration/medmo2rehr`dur'm-color.eps", replace
  collapse (mean) mo2rehir, by(ano) fast
  gen str7 _rowname = string(ano)
  drop ano
  order _rowname
  sort _rowname
  save mo2rehr`dur'm_tbl, replace
  matload mo2rehr`dur'm_tbl, dropall over missing(.)
  erase mo2rehr`dur'm_tbl.dta
  est2tex mo2rehr`dur'm, replace dropall preserve ready p(brazrloc/tex/v4/natl-maleprime/duration) fancy digits(3)
restore, preserve

* graph and tabulate months from displacement to first rehiring, if within `dur' months and plant does not exhibit absence
  replace mo2rehir = . if mo2rehir>`dur' | inddisc==1
  if `dur'==12  keep if ano>=1987 & ano<=2000
  if `dur'==36  keep if ano>=1987 & ano<=1998
  if `dur'==48  keep if ano>=1987 & ano<=1997
  keep ano mes_desl mo2rehir
  collapse (mean) mo2rehir (median) medmo2rehir=mo2rehir, by(ano mes_desl) fast
  gen day = mdy(mes_desl,1,ano) 
  label var day "Month of displacement"
  label var mo2rehir "Mean months to re-employment"
  label var medmo2rehir "Median months to re-employment"
  format day %dm/CY
  qui regress mo2rehir day if day > mdy(1,1,1986) & day <= mdy(12,31,1989)
  predict mo2rehir_per1 if day <= mdy(12,31,1989), xb
  qui regress mo2rehir day if day > mdy(12,31,1989) & day <= mdy(12,31,1992)
  predict mo2rehir_per2 if day > mdy(12,31,1989) & day <= mdy(12,31,1992), xb
  qui regress mo2rehir if day > mdy(12,31,1992)
  predict mo2rehir_per3 if day > mdy(12,31,1992), xb
  graph twoway connected mo2rehir mo2rehir_per1 mo2rehir_per2 mo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/natl-maleprime/duration/mo2rehr`dur'm-contplants.eps", replace
  graph twoway connected mo2rehir mo2rehir_per1 mo2rehir_per2 mo2rehir_per3 day, ytitle("") legend( label(1 "Months to re-employment") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/natl-maleprime/duration/mo2rehr`dur'm-contplants-color.eps", replace
  collapse (mean) mo2rehir, by(ano) fast
  gen str7 _rowname = string(ano)
  drop ano
  order _rowname
  sort _rowname
  save mo2rehr`dur'm_cntplnts_tbl, replace
  matload mo2rehr`dur'm_cntplnts_tbl, dropall over missing(.)
  erase mo2rehr`dur'm_cntplnts_tbl.dta
  est2tex mo2rehr`dur'm_cntplnts, replace dropall preserve ready p(brazrloc/tex/v4/natl-maleprime/duration) fancy digits(3)
restore  

* calculate half life of worker pool to be reallocated
sort ano mes_deslig mo2rehir wid mes_adm identificad
by ano mes_deslig: gen _halfreloc = mo2rehir if _n==int(_N/2)
egen halflife = max(_halfreloc), by(ano mes_deslig)
drop _halfreloc
label var halflife "Half life of realloc. pool"
sort wid ano mes_adm mes_deslig identificad

* graph and tabulate half life of displaced cohorts, if reallocation within `dur' months but irrespective of plant absence
preserve
  if `dur'==12  keep if ano<=2000
  if `dur'==36  keep if ano<=1998
  if `dur'==48  keep if ano<=1997
  keep ano mes_desl halflife
  collapse (mean) halflife, by(ano mes_desl) fast
  gen day = mdy(mes_desl,1,ano) 
  label var day "Month of displacement"
  label var halflife "Half life of reallocation pool"
  format day %dm/CY
  qui regress halflife day if day > mdy(1,1,1986) & day <= mdy(12,31,1989)
  predict halflife_per1 if day <= mdy(12,31,1989), xb
  qui regress halflife day if day > mdy(12,31,1989) & day <= mdy(12,31,1992)
  predict halflife_per2 if day > mdy(12,31,1989) & day <= mdy(12,31,1992), xb
  qui regress halflife if day > mdy(12,31,1992)
  predict halflife_per3 if day > mdy(12,31,1992), xb
  graph twoway connected halflife halflife_per1 halflife_per2 halflife_per3 day, ytitle("") legend( label(1 "Half life in months") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/natl-maleprime/duration/halflife`dur'm.eps", replace
  graph twoway connected halflife halflife_per1 halflife_per2 halflife_per3 day, ytitle("") legend( label(1 "Half life in months") label(2 "Linear pred. 1/86-12/89") label(3 "Linear pred. 1/90-12/92") label(4 "Linear pred. 1/93-12/98") ) graphregion(color(white)) scheme(sj) clcolor(sienna dkgreen) mcolor(sienna dkgreen) msymbol(T i i i) clpattern(solid dash_dot solid dash)
  graph export "brazrloc/graphs/v4/natl-maleprime/duration/halflife`dur'm-color.eps", replace
  collapse (mean) halflife, by(ano) fast
  gen str7 _rowname = string(ano)
  drop ano
  order _rowname
  sort _rowname
  save halflife`dur'm_tbl, replace
  matload halflife`dur'm_tbl, dropall over missing(.)
  erase halflife`dur'm_tbl.dta
  est2tex halflife`dur'm, replace dropall preserve ready p(brazrloc/tex/v4/natl-maleprime/duration) fancy digits(3)
restore

}

log close
cd "$root"
