version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/graphs/v4/natl"
capture mkdir "brazrloc/tex/v4/natl"
capture mkdir "brazrloc/graphs/v4/natl/laborstats"
capture mkdir "brazrloc/tex/v4/natl/laborstats"

capture mkdir "brazrloc/graphs/v4/natl-maleprime"
capture mkdir "brazrloc/tex/v4/natl-maleprime"
capture mkdir "brazrloc/graphs/v4/natl-maleprime/laborstats"
capture mkdir "brazrloc/tex/v4/natl-maleprime/laborstats"

capture mkdir "brazrloc/graphs/v4/metromale"
capture mkdir "brazrloc/tex/v4/metromale"
capture mkdir "brazrloc/graphs/v4/metromale/laborstats"
capture mkdir "brazrloc/tex/v4/metromale/laborstats"

capture mkdir "brazrloc/graphs/v4/metromale-prime"
capture mkdir "brazrloc/tex/v4/metromale-prime"
capture mkdir "brazrloc/graphs/v4/metromale-prime/laborstats"
capture mkdir "brazrloc/tex/v4/metromale-prime/laborstats"


capture log close
log using "brazrloc/logs/empl-stats.log", replace


// RAIS: METROPOLITAN MALE WORKERS, 5-PERCENT SAMPLE

* METROPOLITAN PRIME-AGE MALES 5-PERCENT SAMPLE, BY AGG SECTOR
mat form_metromale_prime_tbl = J(2,7,.)
mat form_metromale_prime_98_tbl = J(2,7,.)
use wid ano identificad subs_ibge emp_em_31_12 fx_etaria using "brazrloc/data/wid-draw-workers-metro-male", clear
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
drop fx_etaria
* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
drop if emp_em_31_12~=1
drop identificad emp_em_31_12
rename ano year
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
collapse (count) n_pis=wid, by(aggsec year) fast  // counts multiple jobs of same worker as one employment each
egen tot_pis = sum(n_pis), by(year)
gen empl_share = n_pis/tot_pis
preserve
local yrrow 0
foreach year in 1990 1997 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 20  // factor 20 scales 5% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_metromale_prime_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_metromale_prime_tbl tot_millions, columns(7) explicit
    else         matname form_metromale_prime_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_metromale_prime_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_metromale_prime_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
local yrrow 0
foreach year in 1990 1998 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 20  // factor 20 scales 5% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_metromale_prime_98_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_metromale_prime_98_tbl tot_millions, columns(7) explicit
    else         matname form_metromale_prime_98_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_metromale_prime_98_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_metromale_prime_98_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
restore
est2tex form_metromale_prime, replace dropall preserve ready p(brazrloc/tex/v4/metromale-prime/laborstats) fancy digits(3)
est2tex form_metromale_prime_98, replace dropall preserve ready p(brazrloc/tex/v4/metromale-prime/laborstats) fancy digits(3)

* METROPOLITAN MALES 5-PERCENT SAMPLE, BY AGG SECTOR
mat form_metromale_tbl = J(2,7,.)
mat form_metromale_98_tbl = J(2,7,.)
use wid ano identificad subs_ibge emp_em_31_12 using "brazrloc/data/wid-draw-workers-metro-male", clear
* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
drop if emp_em_31_12~=1
drop identificad emp_em_31_12
rename ano year
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
collapse (count) n_pis=wid, by(aggsec year) fast  // counts multiple jobs of same worker as one employment each
egen tot_pis = sum(n_pis), by(year)
gen empl_share = n_pis/tot_pis
preserve
local yrrow 0
foreach year in 1990 1997 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 20  // factor 20 scales 5% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_metromale_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_metromale_tbl tot_millions, columns(7) explicit
    else         matname form_metromale_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_metromale_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_metromale_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
local yrrow 0
foreach year in 1990 1998 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 20  // factor 20 scales 5% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_metromale_98_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_metromale_98_tbl tot_millions, columns(7) explicit
    else         matname form_metromale_98_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_metromale_98_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_metromale_98_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
restore
est2tex form_metromale, replace dropall preserve ready p(brazrloc/tex/v4/metromale/laborstats) fancy digits(3)
est2tex form_metromale_98, replace dropall preserve ready p(brazrloc/tex/v4/metromale/laborstats) fancy digits(3)

* SAO PAULO CITY MALES 5-PERCENT SAMPLE, BY AGG SECTOR
mat form_metromale_sp_tbl = J(2,7,.)
mat form_metromale_sp_98_tbl = J(2,7,.)
use wid ano identificad subs_ibge emp_em_31_12 municipio using "brazrloc/data/wid-draw-workers-metro-male", clear
* keep Sao Paulo city only
sort municipio
merge municipio using "rais/auxil/metro-pme", nokeep
drop _m municipio metro
keep if rm=="007"
drop rm
* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
drop if emp_em_31_12~=1
drop identificad emp_em_31_12
rename ano year
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
collapse (count) n_pis=wid, by(aggsec year) fast  // counts multiple jobs of same worker as one employment each
egen tot_pis = sum(n_pis), by(year)
gen empl_share = n_pis/tot_pis
preserve
local yrrow 0
foreach year in 1990 1997 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 20  // factor 20 scales 5% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_metromale_sp_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_metromale_sp_tbl tot_millions, columns(7) explicit
    else         matname form_metromale_sp_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_metromale_sp_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_metromale_sp_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
local yrrow 0
foreach year in 1990 1998 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 20  // factor 20 scales 5% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_metromale_sp_98_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_metromale_sp_98_tbl tot_millions, columns(7) explicit
    else         matname form_metromale_sp_98_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_metromale_sp_98_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_metromale_sp_98_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
restore
est2tex form_metromale_sp, replace dropall preserve ready p(brazrloc/tex/v4/metromale/laborstats) fancy digits(3)
est2tex form_metromale_sp_98, replace dropall preserve ready p(brazrloc/tex/v4/metromale/laborstats) fancy digits(3)


// RAIS: NATIONAL 1-PERCENT SAMPLE

* NATIONAL 1-PERCENT SAMPLE, BY AGG SECTOR
mat form_natl_tbl = J(2,7,.)
mat form_natl_98_tbl = J(2,7,.)
use wid ano identificad subs_ibge emp_em_31_12 using "brazrloc/data/wid-draw-workers-natl", clear
* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
drop if emp_em_31_12~=1
drop identificad emp_em_31_12
rename ano year
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
collapse (count) n_pis=wid, by(aggsec year) fast  // counts multiple jobs of same worker as one employment each
egen tot_pis = sum(n_pis), by(year)
gen empl_share = n_pis/tot_pis
preserve
local yrrow 0
foreach year in 1990 1997 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 100  // factor 100 scales 1% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_natl_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_natl_tbl tot_millions, columns(7) explicit
    else         matname form_natl_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_natl_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_natl_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
local yrrow 0
foreach year in 1990 1998 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 100  // factor 100 scales 1% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_natl_98_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_natl_98_tbl tot_millions, columns(7) explicit
    else         matname form_natl_98_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_natl_98_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_natl_98_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
restore
est2tex form_natl, replace dropall preserve ready p(brazrloc/tex/v4/natl/laborstats) fancy digits(3)
est2tex form_natl_98, replace dropall preserve ready p(brazrloc/tex/v4/natl/laborstats) fancy digits(3)

* NATIONAL 1-PERCENT SAMPLE OF PRIME-AGE MALE WORKERS, BY AGG SECTOR
mat form_natl_maleprime_tbl = J(2,7,.)
mat form_natl_maleprime_98_tbl = J(2,7,.)
use wid ano identificad subs_ibge emp_em_31_12 sexo fx_etaria using "brazrloc/data/wid-draw-workers-natl", clear
drop if sexo==2  // drop female workers
drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
drop fx_etaria sexo
* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
drop if emp_em_31_12~=1
drop identificad emp_em_31_12
rename ano year
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
collapse (count) n_pis=wid, by(aggsec year) fast  // counts multiple jobs of same worker as one employment each
egen tot_pis = sum(n_pis), by(year)
gen empl_share = n_pis/tot_pis
preserve
local yrrow 0
foreach year in 1990 1997 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 100  // factor 100 scales 1% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_natl_maleprime_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_natl_maleprime_tbl tot_millions, columns(7) explicit
    else         matname form_natl_maleprime_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_natl_maleprime_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_natl_maleprime_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
local yrrow 0
foreach year in 1990 1998 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 100  // factor 100 scales 1% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_natl_maleprime_98_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_natl_maleprime_98_tbl tot_millions, columns(7) explicit
    else         matname form_natl_maleprime_98_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_natl_maleprime_98_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_natl_maleprime_98_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
restore
est2tex form_natl_maleprime, replace dropall preserve ready p(brazrloc/tex/v4/natl-maleprime/laborstats) fancy digits(3)
est2tex form_natl_maleprime_98, replace dropall preserve ready p(brazrloc/tex/v4/natl-maleprime/laborstats) fancy digits(3)

* SAO PAULO STATE 1-PERCENT SAMPLE, BY AGG SECTOR
mat form_sp_tbl = J(2,7,.)
mat form_sp_98_tbl = J(2,7,.)
use wid ano identificad subs_ibge emp_em_31_12 municipio using "brazrloc/data/wid-draw-workers-natl", clear
* keep Sao Paulo state only
keep if int(municipio/10000)==35
drop municipio
* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.
drop if emp_em_31_12~=1
drop identificad emp_em_31_12
rename ano year
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
collapse (count) n_pis=wid, by(aggsec year) fast  // counts multiple jobs of same worker as one employment each
egen tot_pis = sum(n_pis), by(year)
gen empl_share = n_pis/tot_pis
preserve
local yrrow 0
foreach year in 1990 1997 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 100  // factor 100 scales 1% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_sp_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_sp_tbl tot_millions, columns(7) explicit
    else         matname form_sp_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_sp_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_sp_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
local yrrow 0
foreach year in 1990 1998 {
  restore, preserve
  replace tot_pis = (tot_pis / 1000000) * 100  // factor 100 scales 1% sample to population
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_sp_98_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_sp_98_tbl tot_millions, columns(7) explicit
    else         matname form_sp_98_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_sp_98_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_sp_98_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
restore
est2tex form_sp, replace dropall preserve ready p(brazrloc/tex/v4/natl/laborstats) fancy digits(3)
est2tex form_sp_98, replace dropall preserve ready p(brazrloc/tex/v4/natl/laborstats) fancy digits(3)


// RAIS POPULATION

* RAIS POPULATION, BY AGG SECTOR
mat form_pop_tbl = J(2,7,.)
mat form_pop_98_tbl = J(2,7,.)
insheet using "rais/base-agg/subsibge/aggsec.csv", comma clear
keep subs_ibge ano n_pis
rename ano year
label var subs_ibge "Sector (IBGE)"
label var year "Calendar year"
label var n_pis "Number of workers"
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
collapse (sum) n_pis, by(aggsec year) fast  // counts multiple jobs of same worker as one employment each
egen tot_pis = sum(n_pis), by(year)
gen empl_share = n_pis/tot_pis
preserve
local yrrow 0
foreach year in 1990 1997 {
  restore, preserve
  replace tot_pis = tot_pis / 1000000
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_pop_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_pop_tbl tot_millions, columns(7) explicit
    else         matname form_pop_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_pop_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_pop_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
local yrrow 0
foreach year in 1990 1998 {
  restore, preserve
  replace tot_pis = tot_pis / 1000000
  keep if year==`year'
  local yrrow = `yrrow' + 1
  matname form_pop_98_tbl `year', rows(`yrrow') explicit
  sort aggsec
  forvalues sec=1/7 {
    local seclbl : label aggsec `sec'
    local seclbl = substr(lower("`seclbl'"),1,6)
    if `sec'==7  matname form_pop_98_tbl tot_millions, columns(7) explicit
    else         matname form_pop_98_tbl `seclbl', columns(`sec') explicit
    if `sec'==7  mat form_pop_98_tbl[`yrrow',7] = tot_pis[1]
    else         mat form_pop_98_tbl[`yrrow',`sec'] = empl_share[`sec']
    }
  }
restore
est2tex form_pop, replace dropall preserve ready p(brazrloc/tex/v4/natl/laborstats) fancy digits(3)
est2tex form_pop_98, replace dropall preserve ready p(brazrloc/tex/v4/natl/laborstats) fancy digits(3)

* RAIS POPULATION, BY SUBS_IBGE
mat emplshare_pop_tbl = J(27,3,.)
insheet using "rais/base-agg/subsibge/aggsec.csv", comma clear
keep subs_ibge ano n_pis
rename ano year
label var subs_ibge "Sector (IBGE)"
label var year "Calendar year"
label var n_pis "Number of workers"
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
collapse (sum) n_pis, by(subs_ibge aggsec year) fast  // counts multiple jobs of same worker as one employment each
egen tot_pis = sum(n_pis), by(year)
gen empl_share = n_pis/tot_pis
preserve
local yrcol 0
foreach year in 1986 1990 1997 {
  restore, preserve
  replace tot_pis = tot_pis / 1000000
  keep if year==`year'
  local yrcol = `yrcol' + 1
  matname emplshare_pop_tbl y`year', columns(`yrcol') explicit
  sort subs_ibge
  forvalues sec=1/27 {
    local secnum = substr("00",1,2-length("`sec'")) + "`sec'"
    local aggsec = aggsec[`sec']
    local seclbl : label aggsec `aggsec'
    * local seclbl = substr(lower("`seclbl'"),1,6) + ":`secnum'"
    local seclbl = `secnum'
    if `sec'==27  matname emplshare_pop_tbl tot_millions, rows(27) explicit
    else          matname emplshare_pop_tbl `seclbl', rows(`sec') explicit
    if `sec'==27  mat emplshare_pop_tbl[27,`yrcol'] = tot_pis[1]
    else          mat emplshare_pop_tbl[`sec',`yrcol'] = empl_share[`sec']
    }
  }
restore
qui label save ibge using "brazrloc/tex/v4/natl/laborstats/ibge", replace
est2tex emplshare_pop, replace dropall preserve ready vallabel(ibge) p(brazrloc/tex/v4/natl/laborstats) fancy digits(3)


* RAIS POPULATION, BY QUINTILE/NONTRADED
insheet using "rais/base-agg/subsibge/aggsec.csv", comma clear  // counts multiple jobs of same worker as one employment each on dec 31
keep subs_ibge ano n_pis
rename ano year
label var subs_ibge "Sector (IBGE)"
label var year "Calendar year"
label var n_pis "Number of workers"
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
rename subs_ibge subsibge
sort subsibge 
merge subsibge using "brazaux/intl/balassa-compadv-subsibge", nokeep keep(balarank)
drop _m
rename subsibge subs_ibge
keep if year==1986 | year==1990 | year==1992 | year==1994 | year==1998
gen byte tradsec = 7 if aggsec>3
forvalues i=1/5 {
  replace tradsec = `i' if balarank==`i'
  }
label var tradsec "Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values tradsec tradsec
tabl2tex n_pis, type(sum) r(year) c(tradsec) p(brazrloc/tex/v4/natl/laborstats) name(empl_aerrr) fancy replace over nolog thousep scale(1.000e-03)  // thousands of workers
local rows = rowsof(empl_aerrr_tbl)
local cols = colsof(empl_aerrr_tbl)
local colnames : colfullnames empl_aerrr_tbl
mat emplshare_aerrr_tbl = empl_aerrr_tbl , empl_aerrr_tbl[1...,`cols']
mat colnames emplshare_aerrr_tbl = `colnames' _Tot_Count
forvalues i = 1/`rows' {
  forvalues j = 1/`cols' {
    mat emplshare_aerrr_tbl[`i',`j'] = ( emplshare_aerrr_tbl[`i',`j']/emplshare_aerrr_tbl[`i',`cols'] ) * 100
    }
  }
est2tex emplshare_aerrr, replace dropall preserve ready p(brazrloc/tex/v4/natl/laborstats) fancy digits(1) thousep


log close
