version 8.2
clear
set logtype text
set more off
set matsize 200
tempfile pia

capture mkdir "brazrloc/tex/v4"
capture mkdir "brazrloc/tex/v4/natl-maleprime"
capture mkdir "brazrloc/tex/v4/natl-maleprime/laborstats"
capture mkdir "brazrloc/tex/v4/metromale-prime"
capture mkdir "brazrloc/tex/v4/metromale-prime/laborstats"
capture mkdir "brazrloc/graphs/v4/natl-maleprime"
capture mkdir "brazrloc/graphs/v4/natl-maleprime/laborstats"
capture mkdir "brazrloc/graphs/v4/metromale-prime"
capture mkdir "brazrloc/graphs/v4/metromale-prime/laborstats"

capture log close
log using "brazrloc/logs/emplcomp-stats.log", replace

// PRIME-AGE MALES NATIONWIDE and METROPOLITAN, SUBSECTOR IBGE DATA 

foreach sample in "natl-maleprime" "metromale-prime" {

foreach sector in "" "trad" "nont" {

if "`sample'"=="natl-maleprime" {
  use wid ano identificad subs_ibge occagg rem_media grau_instr sexo fx_etaria using "brazrloc/data/wid-draw-workers-natl", clear
  drop if sexo==2  // drop female workers
  drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
  drop sexo fx_etaria
  sort wid ano
  }
if "`sample'"=="metromale-prime" {
  use wid ano identificad subs_ibge occagg rem_media grau_instr sexo fx_etaria using "brazrloc/data/wid-draw-workers-metro-male", clear
  drop if fx_etaria < 4 | fx_etaria > 7  // drop workers younger than 25 years or older than 64 years
  }

* make compatible with population aggregates (rais/%sas/%3extracts/agg-to-sectors-subsibge.sas)
drop if identificad==.
drop if ano==.

* generate years of schooling proxy
gen int schooling =  0 if grau_instr==1
replace schooling =  1 if grau_instr==2
replace schooling =  4 if grau_instr==3
replace schooling =  5 if grau_instr==4
replace schooling =  8 if grau_instr==5
replace schooling =  9 if grau_instr==6
replace schooling = 12 if grau_instr==7
replace schooling = 13 if grau_instr==8
replace schooling = 16 if grau_instr==9
label var schooling "Years of schooling"

* generate five education levels
gen byte edulvl = 1 if grau_instr==1 | grau_instr==2
replace  edulvl = 2 if grau_instr==3 | grau_instr==4
replace  edulvl = 3 if grau_instr==5 | grau_instr==6
replace  edulvl = 4 if grau_instr==7 | grau_instr==8
replace  edulvl = 5 if grau_instr==9
label define edulvl 1 "Illiterate or Primary School Dropout" 2 "Primary School Graduate or Middle School Dropout" 3 "Middle School Graduate or High School Dropout" 4 "High School Graduate or College Dropout" 5 "College Graduate", add
label values edulvl edulvl
label var edulvl "Schooling"
drop grau_instr

* transform to efficiency units, summing to unity by year
collapse (count) n_pis=rem_media (sum) rem_media, by(ano subs_ibge occagg edulvl schooling) fast
sort ano subs_ibge occagg schooling edulvl
drop if subs_ibge==. | occagg==. | schooling==. | edulvl==.
fillin ano subs_ibge occagg schooling
summ _fillin
rename rem_media effunits                             // E_jkt
label var effunits "Efficienty units"
replace effunits = 0 if _fillin
drop _fillin
egen double _et  = sum(effunits), by(ano)             // E_t
gen double stdeffunits = (effunits/_et)               // E_jkt
label var stdeffunits "Stand'zd efficiency units [1]"
drop _et

* save for loop
tempfile forloop
save `forloop'

foreach timespan in "1990 1998" "1986 2001" {

if "`timespan'"=="1990 1998"  local xlabl "1990(1)1998"
if "`timespan'"=="1990 1998"  local xtick "1990(1)1998"
if "`timespan'"=="1986 2001"  local xlabl "1986(2)1998 2001"
if "`timespan'"=="1986 2001"  local xtick "1986(1)2001"

tokenize `timespan'
local year0 = `1'
local year1 = `2'
local yr0 = substr("`1'",-2,2)
local yr1 = substr("`2'",-2,2)


// schooling content of occupations

* across all occupations (labor supply)
tempfile allnpis
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=n_pis], by(ano) fast
gen byte occagg = 9
label define occagg 9 "Overall", add
label values occagg occagg
save `allnpis'
tempfile alleffu
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=n_pis], by(ano) fast
gen byte occagg = 9
label define occagg 9 "Overall", add
label values occagg occagg
save `alleffu'
tempfile allstdeffu
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=n_pis], by(ano) fast
gen byte occagg = 9
label define occagg 9 "Overall", add
label values occagg occagg
save `allstdeffu'

* by occupation (labor demand, omitting overall)
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=n_pis], by(ano occagg) fast
gen str mschool = string(int(schooling*10)/10) if ano==1986 | ano==1990 | ano==1997 | ano==2001
qui replace mschool = mschool + ".0" if index(mschool,".")==0 & mschool~=""
qui replace mschool = subinstr(mschool,"-.","-0.",1)
qui replace mschool = "0" + mschool if substr(mschool,1,1)=="."
reshape wide schooling mschool, i(ano) j(occagg)
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 ano, xlabel(`xlabl') xtick(`xtick') ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1) mlabposition(5 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + X) clpattern(solid dash_dot solid dash longdash_dot) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/school-npis-`yr0'`yr1'`sector'.eps", replace
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=effunits], by(ano occagg) fast
gen str mschool = string(int(schooling*10)/10) if ano==1986 | ano==1990 | ano==1997 | ano==2001
qui replace mschool = mschool + ".0" if index(mschool,".")==0 & mschool~=""
qui replace mschool = subinstr(mschool,"-.","-0.",1)
qui replace mschool = "0" + mschool if substr(mschool,1,1)=="."
reshape wide schooling mschool, i(ano) j(occagg)
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 ano, xlabel(`xlabl') xtick(`xtick') ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1) mlabposition(5 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + X) clpattern(solid dash_dot solid dash longdash_dot) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/school-effu-`yr0'`yr1'`sector'.eps", replace
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=stdeffunits], by(ano occagg) fast
gen str mschool = string(int(schooling*10)/10) if ano==1986 | ano==1990 | ano==1997 | ano==2001
qui replace mschool = mschool + ".0" if index(mschool,".")==0 & mschool~=""
qui replace mschool = subinstr(mschool,"-.","-0.",1)
qui replace mschool = "0" + mschool if substr(mschool,1,1)=="."
reshape wide schooling mschool, i(ano) j(occagg)
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 ano, xlabel(`xlabl') xtick(`xtick') ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1) mlabposition(5 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + X) clpattern(solid dash_dot solid dash longdash_dot) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/school-stdeffu-`yr0'`yr1'`sector'.eps", replace

* by occupation (labor demand, including overall)
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=n_pis], by(ano occagg) fast
append using `allnpis'
gen str mschool = string(int(schooling*10)/10) if ano==1986 | ano==1990 | ano==1997 | ano==2001
qui replace mschool = mschool + ".0" if index(mschool,".")==0 & mschool~=""
qui replace mschool = subinstr(mschool,"-.","-0.",1)
qui replace mschool = "0" + mschool if substr(mschool,1,1)=="."
reshape wide schooling mschool, i(ano) j(occagg)
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 schooling9 ano, xlabel(`xlabl') xtick(`xtick') ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1 mschool9) mlabposition(5 1 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + p) clpattern(solid dash_dot solid dash longdash_dot solid) clwidth(medium medium medium medium medium medthick) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") label(6 "Overall") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/schoolov-npis-`yr0'`yr1'`sector'.eps", replace
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=effunits], by(ano occagg) fast
append using `alleffu'
gen str mschool = string(int(schooling*10)/10) if ano==1986 | ano==1990 | ano==1997 | ano==2001
qui replace mschool = mschool + ".0" if index(mschool,".")==0 & mschool~=""
qui replace mschool = subinstr(mschool,"-.","-0.",1)
qui replace mschool = "0" + mschool if substr(mschool,1,1)=="."
reshape wide schooling mschool, i(ano) j(occagg)
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 schooling9 ano, xlabel(`xlabl') xtick(`xtick') ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1 mschool9) mlabposition(5 1 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + p) clpattern(solid dash_dot solid dash longdash_dot solid) clwidth(medium medium medium medium medium medthick) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") label(6 "Overall") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/schoolov-effu-`yr0'`yr1'`sector'.eps", replace
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=stdeffunits], by(ano occagg) fast
append using `allstdeffu'
gen str mschool = string(int(schooling*10)/10) if ano==1986 | ano==1990 | ano==1997 | ano==2001
qui replace mschool = mschool + ".0" if index(mschool,".")==0 & mschool~=""
qui replace mschool = subinstr(mschool,"-.","-0.",1)
qui replace mschool = "0" + mschool if substr(mschool,1,1)=="."
reshape wide schooling mschool, i(ano) j(occagg)
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 schooling9 ano, xlabel(`xlabl') xtick(`xtick') ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1 mschool9) mlabposition(5 1 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + p) clpattern(solid dash_dot solid dash longdash_dot solid) clwidth(medium medium medium medium medium medthick) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") label(6 "Overall") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/schoolov-stdeffu-`yr0'`yr1'`sector'.eps", replace

* by occupation (labor demand, difference to overall)
use `forloop', clear
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=n_pis], by(ano occagg) fast
append using `allnpis'
gen _mschool = schooling if ano==1986 | ano==1990 | ano==1997 | ano==2001
reshape wide schooling _mschool, i(ano) j(occagg)
forvalues i = 1/5 { 
  qui replace schooling`i' = schooling`i' - schooling9
  qui gen str mschool`i' = string( int( (_mschool`i'-_mschool9) *10)/10 ) if (_mschool`i'-_mschool9)~=.
  qui replace mschool`i' = mschool`i' + ".0" if index(mschool`i',".")==0 & mschool`i'~=""
  qui replace mschool`i' = subinstr(mschool`i',"-.","-0.",1)
  qui replace mschool`i' = "0" + mschool`i' if substr(mschool`i',1,1)=="."
 }
drop schooling9 _msch*
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 ano, xlabel(`xlabl') xtick(`xtick') ylabel(-4(2)6) ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1) mlabposition(5 1 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + p) clpattern(solid dash_dot solid dash longdash_dot solid) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") label(6 "Overall") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/schooldif-npis-`yr0'`yr1'`sector'.eps", replace
use `forloop', clear
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=effunits], by(ano occagg) fast
append using `alleffu'
gen _mschool = schooling if ano==1986 | ano==1990 | ano==1997 | ano==2001
reshape wide schooling _mschool, i(ano) j(occagg)
forvalues i = 1/5 { 
  qui replace schooling`i' = schooling`i' - schooling9
  qui gen str mschool`i' = string( int( (_mschool`i'-_mschool9) *10)/10 ) if (_mschool`i'-_mschool9)~=.
  qui replace mschool`i' = mschool`i' + ".0" if index(mschool`i',".")==0 & mschool`i'~=""
  qui replace mschool`i' = subinstr(mschool`i',"-.","-0.",1)
  qui replace mschool`i' = "0" + mschool`i' if substr(mschool`i',1,1)=="."
  }
drop schooling9 _msch*
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 ano, xlabel(`xlabl') xtick(`xtick') ylabel(-4(2)6) ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1) mlabposition(5 1 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + p) clpattern(solid dash_dot solid dash longdash_dot solid) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") label(6 "Overall") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/schooldif-effu-`yr0'`yr1'`sector'.eps", replace
use `forloop', clear
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
collapse (mean) schooling [w=stdeffunits], by(ano occagg) fast
append using `allstdeffu'
gen _mschool = schooling if ano==1986 | ano==1990 | ano==1997 | ano==2001
reshape wide schooling _mschool, i(ano) j(occagg)
forvalues i = 1/5 { 
  qui replace schooling`i' = schooling`i' - schooling9
  qui gen str mschool`i' = string( int( (_mschool`i'-_mschool9) *10)/10 ) if (_mschool`i'-_mschool9)~=.
  qui replace mschool`i' = mschool`i' + ".0" if index(mschool`i',".")==0 & mschool`i'~=""
  qui replace mschool`i' = subinstr(mschool`i',"-.","-0.",1)
  qui replace mschool`i' = "0" + mschool`i' if substr(mschool`i',1,1)=="."
  }
drop schooling9 _msch*
graph twoway connected schooling5 schooling4 schooling3 schooling2 schooling1 ano, xlabel(`xlabl') xtick(`xtick') ylabel(-4(2)6) ytitle("Years of Schooling") mlabel(mschool5 mschool4 mschool3 mschool2 mschool1) mlabposition(5 1 1 1 1 1) graphregion(color(white)) scheme(sj) msymbol(O D T S + p) clpattern(solid dash_dot solid dash longdash_dot solid) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") label(6 "Overall") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/schooldif-stdeffu-`yr0'`yr1'`sector'.eps", replace


// schooling category profile of labor force
use `forloop', clear
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
label define ano 1986 "1986" 1987 "87" 1988 "88" 1989 "89" 1990 "90" 1991 "91" 1992 "92" 1993 "93" 1994 "94" 1995 "95" 1996 "96" 1997 "97" 1998 "98" 1999 "99" 2000 "2000" 2001 "01", modify
if "`timespan'"=="1986 2001"  label values ano ano
drop if edulvl==.
collapse (sum) n_pis effunits stdeffunits, by(ano edulvl) fast
reshape wide n_pis effunits stdeffunits, i(ano) j(edulvl)
graph bar (mean) n_pis1 n_pis2 n_pis3 n_pis4 n_pis5, over(ano) percentage stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.1fc)) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs8)) legend( label(1 "Illit. or Prim. Dropout") label(2 "Prim. School Grad.") label(3 "Middle Sch. Grad.") label(4 "High Sch. Grad.") label(5 "College Grad.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/edulvl-npis-`yr0'`yr1'`sector'.eps", replace
graph bar (mean) effunits1 effunits2 effunits3 effunits4 effunits5, over(ano) percentage stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.1fc)) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs8)) legend( label(1 "Illit. or Prim. Dropout") label(2 "Prim. School Grad.") label(3 "Middle Sch. Grad.") label(4 "High Sch. Grad.") label(5 "College Grad.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/edulvl-effu-`yr0'`yr1'`sector'.eps", replace
graph bar (mean) stdeffunits1 stdeffunits2 stdeffunits3 stdeffunits4 stdeffunits5, over(ano) percentage stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.1fc)) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs8)) legend( label(1 "Illit. or Prim. Dropout") label(2 "Prim. School Grad.") label(3 "Middle Sch. Grad.") label(4 "High Sch. Grad.") label(5 "College Grad.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/edulvl-stdeffu-`yr0'`yr1'`sector'.eps", replace


// occupation profile of workforces
use `forloop'
keep if ano>=`year0' & ano<=`year1'
if "`sector'"=="trad"  keep if subs_ibge<=13 | subs_ibge==25
if "`sector'"=="nont"  drop if subs_ibge<=13 | subs_ibge==25
label define ano 1986 "1986" 1987 "87" 1988 "88" 1989 "89" 1990 "90" 1991 "91" 1992 "92" 1993 "93" 1994 "94" 1995 "95" 1996 "96" 1997 "97" 1998 "98" 1999 "99" 2000 "2000" 2001 "01", modify
if "`timespan'"=="1986 2001"  label values ano ano
collapse (sum) n_pis effunits stdeffunits, by(ano occagg) fast
reshape wide n_pis effunits stdeffunits, i(ano) j(occagg)
graph bar (mean) n_pis5 n_pis4 n_pis3 n_pis2 n_pis1, over(ano) percentage stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.1fc)) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs8)) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/occ-npis-`yr0'`yr1'`sector'.eps", replace
graph bar (mean) effunits5 effunits4 effunits3 effunits2 effunits1, over(ano) percentage stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.1fc)) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs8)) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/occ-effu-`yr0'`yr1'`sector'.eps", replace
graph bar (mean) stdeffunits5 stdeffunits4 stdeffunits3 stdeffunits2 stdeffunits1, over(ano) percentage stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.1fc)) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs8)) legend( label(1 "Unskilled Bl. Collar") label(2 "Skilled Bl. Collar") label(3 "Unskilled Wh. Collar") label(4 "Tech'l. or Superv.") label(5 "Prof. or Manag'l.") ) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/`sample'/laborstats/occ-stdeffu-`yr0'`yr1'`sector'.eps", replace


}  // close `timespan' loop

}  // close `sector' loop

}  // close `sample' loop

log close
