version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/graphs/v4/pme"

capture log close
log using "brazrloc/logs/pme-stats-aerrr.log", replace


// PME: METROPOLITAN WORKERS OF ANY GENDER AND AGE

use t48 year dsubs* using "brazrloc/pme/pme-aerrr-pseudo.dta", clear
label var year "Calendar Year"
decode t48, generate(t48str)
gen str status4str = substr(t48str,1,index(t48str,"_")-1)
encode status4str, generate(status4) label(status)
label var status4 "PME Work Status"
drop t48str status4str
gen byte subs_ibge =.
forvalues i = 1/26 {  // 26 subs_ibge sectors
  capture confirm numeric variable dsubs`i'
  if !_rc {
    replace subs_ibge = `i' if dsubs`i'==1
    drop dsubs`i'
    }
  }
label var subs_ibge "Subsector IBGE"
qui do "rais/cnae/ibge.do"
label values subs_ibge ibge
sort subs_ibge 
merge subs_ibge using "brazrloc/auxil/subsibge2aggsec"
drop _m
rename subs_ibge subsibge
sort subsibge 
merge subsibge using "brazaux/intl/balassa-compadv-subsibge", nokeep keep(balarank)
drop _m
rename subsibge subs_ibge
gen byte tradsec = 7 if aggsec>3
forvalues i=1/5 {
  replace tradsec = `i' if balarank==`i'
  }
label var tradsec "Trade Sectors"
qui do "brazrloc/auxil/tradsec.do"
label values tradsec tradsec
qui tab status4, gen(dstatus)
foreach var of varlist dstatus* {
  local lbl : variable label `var'
  if substr("`lbl'",index("`lbl'","==")+2,length("`lbl'"))=="F"   rename `var' formal_workers
  if substr("`lbl'",index("`lbl'","==")+2,length("`lbl'"))=="I"   rename `var' informal_worker 
  if substr("`lbl'",index("`lbl'","==")+2,length("`lbl'"))=="CP"  rename `var' self_employed_workers
  }
label var formal_worker        "Indic.: status F"
label var informal_worker      "Indic.: status I"
label var self_employed_worker "Indic.: status CP"


* (A) BAR CHART WORK STATUS OVER TIME

graph bar (mean) formal_worker informal_worker self_employed_worker, over(year) stack ytitle("Share") blabel(bar, position(base) color(black) format(%9.3fc)) legend( label(1 "Formally employed") label(2 "Informally employed") label(3 "Self-employed") label(4 "Unemployed") label(5 "Withdrawn") ) graphregion(color(white)) scheme(sj) bar(1, bcolor(gs9)) bar(2, bcolor(gs14)) bar(3, bcolor(gs12)) bar(4, bcolor(gs10)) bar(5, bcolor(gs13)) /* clcolor(sienna dkgreen) mcolor(sienna dkgreen) */
graph export "brazrloc/graphs/v4/pme/workstatus-bar-86-98-manf-inlbf.eps", replace


* (B) INFORMALITY/SELF-EMPLOYMENT SHARE AMONG IN-LABOR-FORCE MANUFACTURING WORKERS 1990-98   // remove manufacturing restriction

summ2tex *, c(mean sd N p50) path(brazrloc/estmat/v4/pme) name(summ_allsec) replace detail
summ2tex * if balarank==1, c(mean sd N p50) path(brazrloc/estmat/v4/pme) name(summ_balrnk1) replace detail
summ2tex * if balarank==3, c(mean sd N p50) path(brazrloc/estmat/v4/pme) name(summ_balrnk3) replace detail
summ2tex * if balarank==5, c(mean sd N p50) path(brazrloc/estmat/v4/pme) name(summ_balrnk5) replace detail
* further processing in %04tex/reg-aer-tab.do


* (C) INFORMALITY/SELF-EMPLOYMENT SHARE BY TRADE SECTOR AMONG IN-LABOR-FORCE MANUFACTURING WORKERS 1990-98

* Load variable names and save for est2tex
preserve
est2extlbl, addto(emplshare_manfinlbf_90) intex($root/brazrloc/%stata/rowlbl-brazrloc) p(brazrloc/tex/v4/pme) replace dropall
est2extlbl, addto(emplshare_manfinlbf_94) retain p(brazrloc/tex/v4/pme) replace
est2extlbl, addto(emplshare_manfinlbf_98) retain p(brazrloc/tex/v4/pme) replace
est2extlbl, addto(emplshare_nowoodinlbf_90) retain p(brazrloc/tex/v4/pme) replace
est2extlbl, addto(emplshare_nowoodinlbf_94) retain p(brazrloc/tex/v4/pme) replace
est2extlbl, addto(emplshare_nowoodinlbf_98) retain p(brazrloc/tex/v4/pme) replace
est2extlbl, addto(emplshare_manfinlbf_subs_90) retain p(brazrloc/tex/v4/pme) replace
est2extlbl, addto(emplshare_manfinlbf_subs_94) retain p(brazrloc/tex/v4/pme) replace
est2extlbl, addto(emplshare_manfinlbf_subs_98) retain p(brazrloc/tex/v4/pme) replace

restore, preserve
tabl2tex t48 if year==90 & aggsec<=3, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_manfinlbf_90) fancy replace over nolog scale(100) digits(1)
restore, preserve
tabl2tex t48 if year==94 & aggsec<=3, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_manfinlbf_94) fancy replace over nolog scale(100) digits(1)
restore, preserve
tabl2tex t48 if year==98 & aggsec<=3, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_manfinlbf_98) fancy replace over nolog scale(100) digits(1)
restore, preserve
tabl2tex t48 if year==90 & aggsec<=3 & subs_ibge~=7, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_nowoodinlbf_90) fancy replace over nolog scale(100) digits(1) // omit wood products and furniture
restore, preserve
tabl2tex t48 if year==94 & aggsec<=3 & subs_ibge~=7, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_nowoodinlbf_94) fancy replace over nolog scale(100) digits(1) // omit wood products and furniture
restore, preserve
tabl2tex t48 if year==98 & aggsec<=3 & subs_ibge~=7, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_nowoodinlbf_98) fancy replace over nolog scale(100) digits(1) // omit wood products and furniture
restore, preserve
tabl2tex t48 if year==90 & subs_ibge~=., type(cfreq) r(status) c(subs_ibge) p(brazrloc/tex/v4/pme) name(emplshare_manfinlbf_subs_90) fancy replace over nolog scale(100) digits(1)
restore, preserve
tabl2tex t48 if year==94 & subs_ibge~=., type(cfreq) r(status) c(subs_ibge) p(brazrloc/tex/v4/pme) name(emplshare_manfinlbf_subs_94) fancy replace over nolog scale(100) digits(1)
restore, preserve
tabl2tex t48 if year==98 & subs_ibge~=., type(cfreq) r(status) c(subs_ibge) p(brazrloc/tex/v4/pme) name(emplshare_manfinlbf_subs_98) fancy replace over nolog scale(100) digits(1)
restore


* (D) INFORMALITY/SELF-EMPLOYMENT SHARE BY TRADE SECTOR AMONG IN-LABOR-FORCE WORKERS 1990-98, ANY SECTOR   // remove manufacturing restriction

* Load variable names and save for est2tex
preserve
est2extlbl, addto(emplshare_inlbf_90) intex($root/brazrloc/%stata/rowlbl-brazrloc) p(brazrloc/tex/v4/pme) replace dropall
est2extlbl, addto(emplshare_inlbf_94) retain p(brazrloc/tex/v4/pme) replace
est2extlbl, addto(emplshare_inlbf_98) retain p(brazrloc/tex/v4/pme) replace

restore, preserve
tabl2tex t48 if year==90, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_inlbf_90) fancy replace over nolog scale(100) digits(1)
restore, preserve
tabl2tex t48 if year==94, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_inlbf_94) fancy replace over nolog scale(100) digits(1)
restore, preserve
tabl2tex t48 if year==98, type(cfreq) r(status) c(tradsec) p(brazrloc/tex/v4/pme) name(emplshare_inlbf_98) fancy replace over nolog scale(100) digits(1)
restore


log close
