clear
clear matrix
set mem 100m
set mat 800

capture mkdir "brazrloc/estmat/v4"
capture mkdir "brazrloc/estmat/v4/pme"

capture log close
log using "brazrloc/logs/pme-aerrr.log", replace

use "brazrloc/pme/pme-aer-v92", clear
order year t48 tf tinf subs_tarfoutp subs_tarfintm ntarout ntarint subs_secrealx subs_fdiflw subs_fdistk subs_reffpen subs_herfsale subs_indunsklb subs_indprown_pis idade* ded* dy* duf* dsubs*
replace year = 1900 + year
compress
label var year "Calendar year"
label var t48  "Work status trans. 4th-8th intv."
label var tf   "Formality 4 months prior"
label var tinf "Informality 4 months prior"
gen byte duf6 = 1 - (duf1 + duf2 + duf3 + duf4 + duf5)
local i 0
foreach uf in RJ SP RS MG PE BA {
  local i = `i' + 1
  label var duf`i' "`uf'"
  }
qui count if duf6~=0
if `r(N)'==0  drop duf6
label var idade  "Age"
label var idade2 "Age squared"
label var ded2   "Education  8-11 yrs."
label var ded3   "Education 12-14 yrs."
label var ded4   "Education  >=15 yrs."
label var ntarint "Ann. Industry Intm. Input Tariff"
label var ntarout "Ann. Industry Output Tariff"
forvalues i = 2/13 {
  label var dsubs`i' "Subsector IBGE `i'"
  }
local i 1
forvalues yr = 88(2)98 {
  local i = `i' + 1
  label var dy`i' "Year 19`yr'"
  }

* workforce categories
* F: formal; I: informal; CP: conta-pr�pria (self-employed); D: desempregado (unemployed); E empregador (employer); ForaPEA (out of labor force)
tab t48

* reduced workforce categories
gen byte t48redx = t48
replace t48redx =  2 if t48redx== 3  // join "to I-CP" in single category
replace t48redx =  7 if t48redx==13  // join "from I-CP" in single category
replace t48redx =  8 if t48redx==14 | t48redx==9 | t48redx==15 // join "from I-CP" in single category
replace t48redx = 10 if t48redx==16  // join "from I-CP" in single category
replace t48redx = 11 if t48redx==17  // join "from I-CP" in single category
replace t48redx = 12 if t48redx==18  // join "from I-CP" in single category
label define ccddrdx 1 "F_F" 2 "F_ICP" 4 "F_D" 5 "F_ForaPEA" 6 "F_E" 7 "ICP_F" 8 "ICP_ICP" 10 "ICP_D" 11 "ICP_ForaPEA" 12 "ICP_E"
label values t48redx ccddrdx
label var t48redx "Work status trns. 4-8th iv. redx"
tab t48redx
order year t48 t48redx

* remove employer category
drop if t48==6 | t48==12 | t48==18

* remove unnecessary variables
drop nt*

* checks on dummies
gen byte ded1 = 1 - (ded2 + ded3 + ded4)
tab ded1
qui count if ded1~=0
if `r(N)'==0  STOP
gen byte dy1 = 1 - (dy2 + dy3 + dy4 + dy5 + dy6 + dy7)
tab dy1
qui count if dy1~=0
if `r(N)'==0  STOP
drop ded1 dy1

// from formality to ...

* regressor list
local varlist "tf subs_tarfoutp subs_tarfintm subs_secrealx subs_fdiflw subs_fdistk subs_reffpen subs_herfsale subs_indunsklb subs_indprown_pis idade idade2 gender ded1 ded2 ded3 ded4 dy1 dy2 dy3 dy4 dy5 dy6 dy7 duf1 duf2 duf3 duf4 duf5 duf6 dsubs1 dsubs2 dsubs3 dsubs4 dsubs5 dsubs6 dsubs2 dsubs3 dsubs4 dsubs5 dsubs6 dsubs7 dsubs8 dsubs9 dsubs10 dsubs11 dsubs12 dsubs13"
local varle : list sizeof varlist
tokenize `varlist'
local eqlist ""
foreach eq in F_I F_CP F_D F_ForaPEA {
  forvalues i = 1/`varle' {
    local eqlist "`eqlist' `eq':``i''"
    }
  }
* disp "`eqlist'"

* main regression with sector-fixed effects
mlogit t48 tf subs_tarfoutp subs_tarfintm idade* ded2-ded4 duf1-duf5 dy2-dy7 dsubs2-dsubs12
est2vec mlogitrr_tf, e(N r2_p chi2 df_m) name(main_secfe) vars(`eqlist')

* main regression without sector-fixed effects
mlogit t48 tf subs_tarfoutp subs_tarfintm idade* ded2-ded4 duf1-duf5 dy2-dy7
est2vec mlogitrr_tf, addto(mlogitrr_tf) name(main)

* full set of regressors, sector fixed effects
mlogit t48 tf subs_tarfoutp subs_tarfintm subs_reffpen subs_secrealx subs_fdiflw subs_fdistk subs_herfsale subs_indunsklb subs_indprown_pis idade* ded2-ded4 duf1-duf5 dy2-dy7 dsubs3-dsubs13
est2vec mlogitrr_tf, addto(mlogitrr_tf) name(fullspec_secfe)

* full set of regressors, no sector fixed effects
mlogit t48 tf subs_tarfoutp subs_tarfintm subs_reffpen subs_secrealx subs_fdiflw subs_fdistk subs_herfsale subs_indunsklb subs_indprown_pis idade* ded2-ded4 duf1-duf5 dy2-dy7
est2vec mlogitrr_tf, addto(mlogitrr_tf) name(fullspec_nosecfe)

* t48-redux and fine sector fixed effect
mlogit t48redx tf subs_tarfoutp subs_tarfintm idade* ded2-ded4 duf1-duf5 dy2-dy7 dsubs3-dsubs13
* est2vec mlogitrr_tf, addto(mlogitrr_tf) name(redx_secfe)

* t48 Naercio regressions w/out secfe
mlogit t48 tf subs_tarfoutp subs_tarfintm subs_secrealx subs_fdiflw subs_herfsale ded2-ded4 duf1-duf5 dy2-dy7 idade idade2 gender
est2vec mlogitrr_tf, addto(mlogitrr_tf) name(naercio_nosecfe)

* t48 Naercio regressions with secfe
mlogit t48 tf subs_tarfoutp subs_tarfintm subs_secrealx subs_fdiflw subs_herfsale ded2-ded4 duf1-duf5 dy2-dy7 idade idade2 gender dsubs2-dsubs13
est2vec mlogitrr_tf, addto(mlogitrr_tf) name(naercio_secfe)


// from informality to ...

* regressor list
local varlist "tinf subs_tarfoutp subs_tarfintm subs_secrealx subs_fdiflw subs_fdistk subs_reffpen subs_herfsale subs_indunsklb subs_indprown_pis idade idade2 gender ded1 ded2 ded3 ded4 dy1 dy2 dy3 dy4 dy5 dy6 dy7 duf1 duf2 duf3 duf4 duf5 duf6 dsubs1 dsubs2 dsubs3 dsubs4 dsubs5 dsubs6 dsubs2 dsubs3 dsubs4 dsubs5 dsubs6 dsubs7 dsubs8 dsubs9 dsubs10 dsubs11 dsubs12 dsubs13"
local varle : list sizeof varlist
tokenize `varlist'
local eqlist ""
foreach eq in I_F I_CP I_D I_ForaPEA {
  forvalues i = 1/`varle' {
    local eqlist "`eqlist' `eq':``i''"
    }
  }
* disp "`eqlist'"

* main regression with sector-fixed effects
mlogit t48 tinf subs_tarfoutp subs_tarfintm idade* ded2-ded4 duf1-duf5 dy2-dy7 dsubs2-dsubs12
est2vec mlogitrr_tinf, e(N r2_p chi2 df_m) name(main_secfe) vars(`eqlist')

* main regression without sector-fixed effects
mlogit t48 tinf subs_tarfoutp subs_tarfintm idade* ded2-ded4 duf1-duf5 dy2-dy7
est2vec mlogitrr_tinf, addto(mlogitrr_tinf) name(main)

* full set of regressors, sector fixed effects
mlogit t48 tinf subs_tarfoutp subs_tarfintm subs_reffpen subs_secrealx subs_fdiflw subs_fdistk subs_herfsale subs_indunsklb subs_indprown_pis idade* ded2-ded4 duf1-duf5 dy2-dy7 dsubs3-dsubs13
est2vec mlogitrr_tinf, addto(mlogitrr_tinf) name(fullspec_secfe)

* full set of regressors, no sector fixed effects
mlogit t48 tinf subs_tarfoutp subs_tarfintm subs_reffpen subs_secrealx subs_fdiflw subs_fdistk subs_herfsale subs_indunsklb subs_indprown_pis idade* ded2-ded4 duf1-duf5 dy2-dy7
est2vec mlogitrr_tinf, addto(mlogitrr_tinf) name(fullspec_nosecfe)

* t48-redux and fine sector fixed effect
mlogit t48redx tinf subs_tarfoutp subs_tarfintm idade* ded2-ded4 duf1-duf5 dy2-dy7 dsubs3-dsubs13
* est2vec mlogitrr_tinf, addto(mlogitrr_tinf) name(redx_secfe)

* t48 Naercio regressions w/out secfe
mlogit t48 tinf subs_tarfoutp subs_tarfintm subs_secrealx subs_fdiflw subs_herfsale ded2-ded4 duf1-duf5 dy2-dy7 idade idade2 gender
est2vec mlogitrr_tinf, addto(mlogitrr_tinf) name(naercio_nosecfe)

* t48 Naercio regressions with secfe
mlogit t48 tinf subs_tarfoutp subs_tarfintm subs_secrealx subs_fdiflw subs_herfsale ded2-ded4 duf1-duf5 dy2-dy7 idade idade2 gender dsubs2-dsubs13
est2vec mlogitrr_tinf, addto(mlogitrr_tinf) name(naercio_secfe)


// matrix output
foreach type in b se e {
  matsave mlogitrr_tf_`type', p(brazrloc/estmat/v4/pme) replace dropall
  matsave mlogitrr_tinf_`type', p(brazrloc/estmat/v4/pme) replace dropall
  }


log close
