version 8.2
clear
set logtype text
set more off
set matsize 200

capture mkdir "brazrloc/estmat/v4/reg"
capture mkdir "brazrloc/estmat/v4/reg/natl"

capture log close
log using "brazrloc/logs/separations-accessions-aer-natl-rr.log", replace

local maxiter $maxiter

capture program drop ivreplc
program define ivreplc
  foreach reg in $regdef {
    replace imp_`reg' = imp_`reg' * ini_lnempl
    }
end

// AUXILIARY ANNUAL DATA

tempfile auxdat
insheet using "brazrloc/auxil/origs/pib.csv", clear
keep ano populacao pib_corrente_usd
rename ano year
label var year "Calendar Year"
rename populacao population
label var population "Population [mio]"
rename pib_corrente_usd gdp_usd
replace gdp_usd = gdp_usd/1000000
label var gdp_usd "GDP [current USD bio]"
keep if year>=1986 & year<=1998
sort year
merge year using "brazrloc/auxil/globfin-annual", nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m
keep year __brl_d population _ibx50d
sort year
save `auxdat'


// SUBSIBGE REGRESSIONS

local basendog "subs_tarfoutp subs_tarfintm firm_indexp"  // cut: subs_reffpen
local secexog  "subs_balcadv"
local secexo90 "subs_balcadv_90"
local secalt90 "subs_volrcadv_90"
local exoglst  "subs_secrealx subs_fdiflw subs_herfsale"
local cntrlfrm "plant_lnempl plant_indhigh plant_indcoll plant_indwhittot"
local ivlst    "subs_ppieu subs_ppinam imp_APD imp_CEE imp_NAM imp_ODV imp_OIN imp_WEU"
local intract1 "subs_tarfoutp_indexp subs_tarfintm_indexp"
local intract2 "subs_tarfoutp_balcadv subs_tarfintm_balcadv"
local intract3 "subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv"
local intract4 "subs_tarfoutp_notindprim subs_tarfintm_notindprim"  // if ~indprim
local intract5 "subs_tarfoutp_indyoung subs_tarfintm_indyoung"  // if potexper < 10
local intract6 "subs_tarfoutp_indwhite subs_tarfintm_indwhite"  // if indprof | indtech | indwhit
local addlreg  "subs_indprown_pis occ_indoutsrc"
local auxyr    "__brl_d population _ibx50d"


* separations natl

local cntrlwrk "tenuryr potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/separations-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf indlayoff indquit
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"
drop subs_ibge

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"

* regressions

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_balcadv_90 subs_volrcadv_90 subs_reffpen subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indcoll plant_indhigh plant_indwhittot firm_lnlp tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv subs_tarfoutp_notindprim subs_tarfintm_notindprim subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_nofe)
est2vec subsdspl_aerrr, r(F p df df_r) name(clogit_nofe)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_yrfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_yrfe)

clogit inddspl `basendog' `secexo90' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_yrfe_exo90)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_yrfe_exo90)

clogit inddspl `basendog' `secalt90' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_yrfe_exalt)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_yrfe_exalt)

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_secyrfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_secyrfe)

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' `auxyr' indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_secfe_auxyr)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_secfe_auxyr)

logit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990 & indsmpl, robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(logit_secyrfe_smpl0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(logit_secyrfe_smpl0)

logit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(logit_secyrfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(logit_secyrfe0)

clogit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_secyrfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_secyrfe0)

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_secyrtrdfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_secyrtrdfe)

clogit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_secyrtrdfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_secyrtrdfe0)

xtreg inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl & year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xt_secyrfe_smpl)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xt_secyrfe_smpl)

xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl & year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xt_secyrfe_smpl0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xt_secyrfe_smpl0)

xtreg inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xt_secyrfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xt_secyrfe)

xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xt_secyrfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xt_secyrfe0)
predict u_dspl if e(sample), u
preserve
  keep wid u_dspl
  keep if e(sample)
  duplicates drop
  sort wid
  save "brazrloc/estmat/v4/reg/natl/subsdspl_u.dta", replace
restore
corr u_dspl subs_tarfoutp subs_tarfintm
drop u_dspl

xtreg inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xt_secyrtrdfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xt_secyrtrdfe)

xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xt_secyrtrdfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xt_secyrtrdfe0)

xtivreg inddspl `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv_secyrfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv_secyrfe)

xtivreg inddspl `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv_secyrfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv_secyrfe0)
gen byte indivsmpl = e(sample)
label var indivsmpl "Indic.: In xtivreg sample"
tab year if indivsmpl

xtivreg inddspl `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv_secyrtrdfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv_secyrtrdfe)

xtivreg inddspl `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv_secyrtrdfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv_secyrtrdfe0)

xtivreg inddspl `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv_secfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv_secfe)

xtivreg inddspl `exoglst' `cntrlfrm' `cntrlwrk' indsubs* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv_secfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv_secfe0)

xtivreg inddspl `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv_yrfe)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv_yrfe)

xtivreg inddspl `exoglst' `cntrlfrm' `cntrlwrk' indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv_yrfe0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv_yrfe0)

xtivreg inddspl `secexog' `exoglst' `cntrlfrm' `cntrlwrk' (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv)

xtivreg inddspl `exoglst' `cntrlfrm' `cntrlwrk' (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtiv0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtiv0)

xtreg firm_indexp `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(first_indexp)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(first_indexp)

xtreg firm_indexp `ivlst' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(first_indexp0)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(first_indexp0)

xtreg subs_balcadv `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(subs_balcadv)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(subs_balcadv)

xtreg subs_tarfoutp `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(first_tarfoutp)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(first_tarfoutp)

xtreg subs_tarfoutp `ivlst' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(first_tarfoutp0)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(first_tarfoutp0)

xtreg subs_tarfintm `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(first_tarfintm)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(first_tarfintm)

xtreg subs_tarfintm `ivlst' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(first_tarfintm0)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(first_tarfintm0)

xtreg subs_reffpen `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(first_reffpen)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(first_reffpen)

xtreg subs_reffpen `ivlst' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(first_reffpen0)
test `ivlst'
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(first_reffpen0)

clogit inddspl `basendog' `secexog' `intract1' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract1)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract1)

clogit inddspl `basendog' `intract1' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract10)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract10)

clogit inddspl `basendog' `secexog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract2)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract2)

clogit inddspl `basendog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract20)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract20)

clogit inddspl `basendog' `secexog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract3)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract3)

clogit inddspl `basendog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract30)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract30)

clogit inddspl `basendog' `secexog' `intract4' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract4)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract4)

clogit inddspl `basendog' `intract4' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract40)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract40)

clogit inddspl `basendog' `secexog' `intract5' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract5)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract5)

clogit inddspl `basendog' `intract5' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract50)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract50)

clogit inddspl `basendog' `secexog' `intract6' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract6)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract6)

clogit inddspl `basendog' `intract6' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_intract60)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_intract60)

clogit inddspl firm_lnlp `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_lnlp)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_lnlp)

clogit inddspl firm_lnlp `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_lnlp0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_lnlp0)
gen byte indpia = e(sample)
label var indpia "Indic.: In PIA (lnlp) sample"

clogit inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_ifpia)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_ifpia)

clogit inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, group(wid) robust iterate(`maxiter')
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(clogit_ifpia0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(clogit_ifpia0)

xtreg inddspl firm_lnlp `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtreg_lnlp)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtreg_lnlp)

xtreg inddspl firm_lnlp `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtreg_lnlp0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtreg_lnlp0)
replace indpia = e(sample)
label var indpia "Indic.: In PIA (lnlp) sample"

xtreg inddspl `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtreg_ifpia)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtreg_ifpia)

xtreg inddspl `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, fe i(wid)
est2vec subsdspl_aerrr, addto(subsdspl_aerrr) name(xtreg_ifpia0)
est2vec subsdspl_aerrr, raddto(subsdspl_aerrr) name(xtreg_ifpia0)


* accessions natl

local cntrlwrk "potexper indprof indtech indwhit indsklb"

use if ~indexcl using "brazrloc/data/accessions-natl-subsibge.dta", clear
drop indexcl subs_balcadv_tarf subs_balcadv_indexp subs_balcadv_indexp_tarf
forvalues i = 1/13 {
  local year = 1985 + `i'
  label var indyr_`i' "Indic.: Year `year'"
  }
forvalues i = 1/26 {
  label var indsubs_`i' "Indic.: Subsector `i'"
  }

* redefinitions
gen plant_indcoll = 1 - plant_indhigh - plant_indprim
label var plant_indcoll "Share: College education"
drop plant_indprim

* obtain alternative instrumental variables
gen byte subs_ibge = .
forvalues i = 1/26 {
  qui replace subs_ibge = `i' if indsubs_`i'==1
  }
drop imp_*
sort subs_ibge year
merge subs_ibge year using "brazrloc/auxil/wtf-subsibge-data.dta", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop _m
egen ini_lnempl = mean(plant_lnempl) if year<=1990, by(cnpj_radic)
egen _spread = min(ini_lnempl), by(cnpj_radic)
replace ini_lnempl = _spread if ini_lnempl==.
drop _spread
label var ini_lnempl "Firm Log Employment 1986-90"

* obtain alternative revealed comparative-advantage measure
rename subs_ibge subsibge
sort subsibge year
merge subsibge year using "brazaux/intl/vollrath-compadv-subsibge.dta", nokeep keep(volrcadv)
qui count if _m~=3 & ( subsibge<=13 | subsibge==25)
if `r(N)'>0  STOP
drop _m
rename subsibge subs_ibge
rename volrcadv subs_volrcadv

* annual trend
gen byte trend = year - 1990
label var trend "Annual Trend"
forvalues i=1/26 {
  gen byte trd_indsubs_`i' = indsubs_`i' * trend
  label var trd_indsubs_`i' "Subsector `i' trend"
  }

* reference year 1998
drop indyr_13

* auxiliary annual data
sort year
merge year using `auxdat', nokeep
qui count if _m~=3
if `r(N)'~=0  STOP  // incomplete data
drop _m

* subs_balcadv_90 and subs_volrcadv_90
foreach var in subs_balcadv subs_volrcadv {
  gen _`var'_90 = `var' if year==1990
  egen `var'_90 = max(_`var'_90), by(subs_ibge)
  drop _`var'_90
  }
label var subs_balcadv_90 "Balassa (1965) comp. adv. 1990"
label var subs_volrcadv_90 "Vollrath (1992) comp. adv. 1990"
drop subs_ibge

* interactions
gen subs_tarfoutp_indexp = subs_tarfoutp * firm_indexp
label var subs_tarfoutp_indexp "tarfoutp * indexp"
gen subs_tarfintm_indexp = subs_tarfintm * firm_indexp
label var subs_tarfintm_indexp "tarfintm * indexp"
gen subs_tarfoutp_balcadv = subs_tarfoutp * subs_balcadv
label var subs_tarfoutp_balcadv "tarfoutp * balcadv"
gen subs_tarfintm_balcadv = subs_tarfintm * subs_balcadv
label var subs_tarfintm_balcadv "tarfintm * balcadv"
gen subs_tarfoutp_indexp_balcadv = subs_tarfoutp * firm_indexp * subs_balcadv
label var subs_tarfoutp_indexp_balcadv "tarfoutp * indexp * balcadv"
gen subs_tarfintm_indexp_balcadv = subs_tarfintm * firm_indexp * subs_balcadv
label var subs_tarfintm_indexp_balcadv "tarfintm * indexp * balcadv"
gen subs_tarfoutp_notindprim = subs_tarfoutp * (~indprim) // if ~indprim
label var subs_tarfoutp_notindprim "tarfoutp * (~indprim)"
gen subs_tarfintm_notindprim = subs_tarfintm * (~indprim) // if ~indprim
label var subs_tarfintm_notindprim "tarfintm * (~indprim)"
gen subs_tarfoutp_indyoung = subs_tarfoutp * (potexper<10) // if potexper < 10
label var subs_tarfoutp_indyoung "subs_tarfoutp * (potexper<10)"
gen subs_tarfintm_indyoung = subs_tarfintm * (potexper<10) // if potexper < 10
label var subs_tarfintm_indyoung "subs_tarfintm * (potexper<10)"
gen subs_tarfoutp_indwhite = subs_tarfoutp * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfoutp_indwhite "subs_tarfoutp * (indwhit+)"
gen subs_tarfintm_indwhite = subs_tarfintm * (indprof|indtech|indwhit) // if indprof | indtech | indwhit
label var subs_tarfintm_indwhite "subs_tarfintm * (indwhit+)"

* regressions

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, vars(subs_tarfoutp subs_tarfintm firm_indexp subs_balcadv subs_balcadv_90 subs_volrcadv_90 subs_reffpen subs_secrealx subs_fdiflw subs_herfsale plant_lnempl plant_indcoll plant_indhigh plant_indwhittot firm_lnlp tenuryr potexper indprof indtech indwhit indsklb indunsklb subs_tarfoutp_indexp subs_tarfintm_indexp subs_tarfoutp_balcadv subs_tarfintm_balcadv subs_tarfoutp_indexp_balcadv subs_tarfintm_indexp_balcadv subs_tarfoutp_notindprim subs_tarfintm_notindprim subs_tarfoutp_indyoung subs_tarfintm_indyoung subs_tarfoutp_indwhite subs_tarfintm_indwhite subs_tarfoutp_indfemal subs_tarfintm_indfemal subs_indprown_pis occ_indoutsrc subs_dollar subs_ppieu subs_ppinam imp_APD imp_CEE imp_LAC imp_NAM imp_ODV imp_OIN imp_WEU indyr_1 indyr_2 indyr_3 indyr_4 indyr_5 indyr_6 indyr_7 indyr_8 indyr_9 indyr_10 indyr_11 indyr_12 indyr_13 indsubs_1 indsubs_2 indsubs_3 indsubs_4 indsubs_5 indsubs_6 indsubs_7 indsubs_8 indsubs_9 indsubs_10 indsubs_11 indsubs_12 indsubs_13 indsubs_14 indsubs_15 indsubs_16 indsubs_17 indsubs_18 indsubs_19 indsubs_20 indsubs_21 indsubs_22 indsubs_23 indsubs_24 indsubs_25 indsubs_26 trd_indsubs_1 trd_indsubs_2 trd_indsubs_3 trd_indsubs_4 trd_indsubs_5 trd_indsubs_6 trd_indsubs_7 trd_indsubs_8 trd_indsubs_9 trd_indsubs_10 trd_indsubs_11 trd_indsubs_12 trd_indsubs_13 trd_indsubs_14 trd_indsubs_15 trd_indsubs_16 trd_indsubs_17 trd_indsubs_18 trd_indsubs_19 trd_indsubs_20 trd_indsubs_21 trd_indsubs_22 trd_indsubs_23 trd_indsubs_24 trd_indsubs_25 trd_indsubs_26) e(N ll chi2 p df_m r2 r2_p rc ic) name(clogit_nofe)
est2vec subshire_aerrr, r(F p df df_r) name(clogit_nofe)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In clogit sample"
tab year if indsmpl

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_yrfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_yrfe)

clogit indhire `basendog' `secexo90' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_yrfe_exo90)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_yrfe_exo90)

clogit indhire `basendog' `secalt90' `exoglst' `cntrlfrm' `cntrlwrk' indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_yrfe_exalt)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_yrfe_exalt)

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_secyrfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_secyrfe)

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' `auxyr' indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_secfe_auxyr)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_secfe_auxyr)

logit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990 & indsmpl, robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(logit_secyrfe_smpl0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(logit_secyrfe_smpl0)

logit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(logit_secyrfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(logit_secyrfe0)

clogit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_secyrfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_secyrfe0)

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_secyrtrdfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_secyrtrdfe)

clogit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_secyrtrdfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_secyrtrdfe0)

xtreg indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl & year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xt_secyrfe_smpl)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xt_secyrfe_smpl)

xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indsmpl & year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xt_secyrfe_smpl0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xt_secyrfe_smpl0)

xtreg indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xt_secyrfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xt_secyrfe)

xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xt_secyrfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xt_secyrfe0)
predict u_hire if e(sample), u
preserve
  keep wid u_hire
  keep if e(sample)
  duplicates drop
  sort wid
  save "brazrloc/estmat/v4/reg/natl/subshire_u.dta", replace
restore
corr u_hire subs_tarfoutp subs_tarfintm
drop u_hire

xtreg indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xt_secyrtrdfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xt_secyrtrdfe)

xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xt_secyrtrdfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xt_secyrtrdfe0)

xtivreg indhire `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv_secyrfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv_secyrfe)

xtivreg indhire `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv_secyrfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv_secyrfe0)
gen byte indivsmpl = e(sample)
label var indivsmpl "Indic.: In xtivreg sample"
tab year if indivsmpl

xtivreg indhire `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv_secyrtrdfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv_secyrtrdfe)

xtivreg indhire `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* trd_indsubs* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv_secyrtrdfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv_secyrtrdfe0)

xtivreg indhire `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv_secfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv_secfe)

xtivreg indhire `exoglst' `cntrlfrm' `cntrlwrk' indsubs* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv_secfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv_secfe0)

xtivreg indhire `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv_yrfe)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv_yrfe)

xtivreg indhire `exoglst' `cntrlfrm' `cntrlwrk' indyr* (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv_yrfe0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv_yrfe0)

xtivreg indhire `secexog' `exoglst' `cntrlfrm' `cntrlwrk' (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv)

xtivreg indhire `exoglst' `cntrlfrm' `cntrlwrk' (`basendog' = `ivlst') if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtiv0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtiv0)

xtreg firm_indexp `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(first_indexp)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(first_indexp)

xtreg firm_indexp `ivlst' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(first_indexp0)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(first_indexp0)

xtreg subs_balcadv `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(subs_balcadv)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(subs_balcadv)

xtreg subs_tarfoutp `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(first_tarfoutp)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(first_tarfoutp)

xtreg subs_tarfoutp `ivlst' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(first_tarfoutp0)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(first_tarfoutp0)

xtreg subs_tarfintm `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(first_tarfintm)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(first_tarfintm)

xtreg subs_tarfintm `ivlst' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(first_tarfintm0)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(first_tarfintm0)

xtreg subs_reffpen `ivlst' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(first_reffpen)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(first_reffpen)

xtreg subs_reffpen `ivlst' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indivsmpl, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(first_reffpen0)
test `ivlst'
est2vec subshire_aerrr, raddto(subshire_aerrr) name(first_reffpen0)

clogit indhire `basendog' `secexog' `intract1' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract1)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract1)

clogit indhire `basendog' `intract1' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract10)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract10)

clogit indhire `basendog' `secexog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract2)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract2)

clogit indhire `basendog' `intract1' `intract2' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract20)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract20)

clogit indhire `basendog' `secexog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract3)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract3)

clogit indhire `basendog' `intract1' `intract2' `intract3' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract30)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract30)

clogit indhire `basendog' `secexog' `intract4' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract4)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract4)

clogit indhire `basendog' `intract4' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract40)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract40)

clogit indhire `basendog' `secexog' `intract5' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract5)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract5)

clogit indhire `basendog' `intract5' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract50)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract50)

clogit indhire `basendog' `secexog' `intract6' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract6)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract6)

clogit indhire `basendog' `intract6' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_intract60)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_intract60)

clogit indhire firm_lnlp `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_lnlp)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_lnlp)

clogit indhire firm_lnlp `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_lnlp0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_lnlp0)
gen byte indpia = e(sample)
label var indpia "Indic.: In PIA (lnlp) sample"

clogit indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_ifpia)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_ifpia)

clogit indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, group(wid) robust iterate(`maxiter')
est2vec subshire_aerrr, addto(subshire_aerrr) name(clogit_ifpia0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(clogit_ifpia0)

xtreg indhire firm_lnlp `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtreg_lnlp)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtreg_lnlp)

xtreg indhire firm_lnlp `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if year>=1990, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtreg_lnlp0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtreg_lnlp0)
replace indpia = e(sample)
label var indpia "Indic.: In PIA (lnlp) sample"

xtreg indhire `basendog' `secexog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtreg_ifpia)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtreg_ifpia)

xtreg indhire `basendog' `exoglst' `cntrlfrm' `cntrlwrk' indsubs* indyr* if indpia, fe i(wid)
est2vec subshire_aerrr, addto(subshire_aerrr) name(xtreg_ifpia0)
est2vec subshire_aerrr, raddto(subshire_aerrr) name(xtreg_ifpia0)


// Save results

foreach type in b se e r {
  matsave subsdspl_aerrr_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  matsave subshire_aerrr_`type', p(brazrloc/estmat/v4/reg/natl) t(double) replace dropall
  }

log close
