version 8.2
clear
set more off
set matsize 200

capture mkdir "brazrloc/tex/v4/gdp"

capture log close
log using "brazrloc/logs/gdp-impact.log", replace

capture program drop rowlbl
program define rowlbl
  args mat neweq
  local rownames : rowfullnames `mat'
  local rows : word count `rownames'
  local rownewnames ""
  tokenize `rownames'
  forvalues i = 1/`rows' {
    local ipls1 = `i' + 1
    * disp "``i''"
    if index("``i''",":r(mean)")>0  local `i' = "`neweq':" + substr("``i''",1,index("``i''",":")-1)
    local rownewnames "`rownewnames' ``i''"
    }
  mat rownames `mat' = `rownewnames'
end


/* REALLOCATION DURATIONS AND FAILURES BY SKILL GROUP */

matload mo2rehr12mbygrp_tbl, p(brazrloc/tex/v4/natl-maleprime/duration) dropall missing(.) over
matorder mo2rehr12mbygrp_tbl, m(_rlocsucc_paper_tbl) ifc(mo2rehir1986 mo2rehir1990 mo2rehir1992 mo2rehir1994 mo2rehir1998)
mat _rlocsucc_paper_tbl = _rlocsucc_paper_tbl[1..4,1...] \ _rlocsucc_paper_tbl[7..8,1...]  \ _rlocsucc_paper_tbl[11..12,1...]
rowlbl _rlocsucc_paper_tbl  mo2rehr
matload indnorloc12mbygrp_tbl, p(brazrloc/tex/v4/natl-maleprime/duration) dropall missing(.) over
matorder indnorloc12mbygrp_tbl, m(rlocsucc_paper_tbl) ifc(indnorloc1986 indnorloc1990 indnorloc1992 indnorloc1994 indnorloc1998)
rowlbl rlocsucc_paper_tbl indnorloc
mat rlocsucc_paper_tbl = rlocsucc_paper_tbl[1..4,1...] \ rlocsucc_paper_tbl[7..8,1...]  \ rlocsucc_paper_tbl[11..14,1...]
mat rlocsucc_paper_tbl = _rlocsucc_paper_tbl \ rlocsucc_paper_tbl
mat drop indnorloc12mbygrp_tbl mo2rehr12mbygrp_tbl _rlocsucc_paper_tbl
mat colnames rlocsucc_paper_tbl = y1986 y1990 y1992 y1994 y1998
foreach yr in 86 90 92 94 98 {  // from 1% random sample to population numbers
  mat rlocsucc_paper_tbl[rownumb(rlocsucc_paper_tbl,"any:r(N)"),colnumb(rlocsucc_paper_tbl,"y19`yr'")] = rlocsucc_paper_tbl[rownumb(rlocsucc_paper_tbl,"any:r(N)"),colnumb(rlocsucc_paper_tbl,"y19`yr'")]*100
  }
est2tex rlocsucc_paper, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3) level(90 95 99) mark(starse)


/* LOAD MATRICES */

matload indnorloc12mbygrp_tbl, p(brazrloc/tex/v4/natl-maleprime/duration) dropall missing(.) over
matload mo2rehr12mbygrp_tbl, p(brazrloc/tex/v4/natl-maleprime/duration) dropall missing(.) over
matorder indnorloc12mbygrp_tbl, m(multsal_indnorloc) ifr(any:mean_rem_media)
mat multsal_indnorloc = multsal_indnorloc '
matrix coleq multsal_indnorloc = indnorloc
matorder mo2rehr12mbygrp_tbl, m(multsal_mo2rehr) ifr(any:mean_rem_media)
mat multsal_mo2rehr = multsal_mo2rehr '
matrix coleq multsal_mo2rehr = mo2rehr
mat multsal_comp = multsal_indnorloc , multsal_mo2rehr
mat list multsal_comp
mat drop multsal_comp multsal_mo2rehr


/* TRADE-RELATED PREDICTIONS OF SEPARATION AND ACCESSION RATE CHANGES */

foreach margin in dspl hire {
  foreach mat in _coef _tradvars90 _tradvars92 _tradvars94 _tradvars98 {
    matload subs`margin'`mat'_tbl, dropall p(brazrloc/tex/v4/gdp) over missing(.)
    }
  }
foreach margin in dspl hire {
  local phat`margin' = subs`margin'_tradvars90_tbl[rownumb(subs`margin'_tradvars90_tbl,"phat"),colnumb(subs`margin'_tradvars90_tbl,"yr90_allsec")]
  local phatnoyr`margin' = subs`margin'_tradvars90_tbl[rownumb(subs`margin'_tradvars90_tbl,"phatnoyr"),colnumb(subs`margin'_tradvars90_tbl,"yr90_allsec")]
  disp in gr "Estimated phat*(1-phat) at " in ye "`margin'" in gr " margin: " in ye %9.3f `phat`margin'' * (1-`phat`margin'')
  disp in gr "Estimated phatnoyr*(1-phatnoyr) at " in ye "`margin'" in gr " margin: " in ye %9.3f `phatnoyr`margin'' * (1-`phatnoyr`margin'')
  matorder subs`margin'_coef_tbl, m(subs`margin'_coef_tbl) ifc(clogit_paper clogit_secfe clogit_noyreff xt xtiv) over
  mat subs`margin'_meff_tbl = subs`margin'_coef_tbl[1...,1..2] * `phat`margin'' * (1-`phat`margin'') , subs`margin'_coef_tbl[1...,3] * `phatnoyr`margin'' * (1-`phatnoyr`margin'') , subs`margin'_coef_tbl[1...,4..5]
  mat drop subs`margin'_coef_tbl
  foreach yr in 92 94 98 {
    mat `margin'_tradvdif`yr'90 = subs`margin'_tradvars`yr'_tbl[1..4,1...] - subs`margin'_tradvars90_tbl[1..4,1...]
    mat `margin'_predrfpen`yr'90 = subs`margin'_meff_tbl[rownumb(subs`margin'_meff_tbl,"subs_reffpen"),1...] ' * `margin'_tradvdif`yr'90[rownumb(`margin'_tradvdif`yr'90,"subs_reffpen"),1...]
    mat `margin'_predtarfs`yr'90 = subs`margin'_meff_tbl[rownumb(subs`margin'_meff_tbl,"subs_tarfoutp")..rownumb(subs`margin'_meff_tbl,"subs_tarfintm"),1...] ' * `margin'_tradvdif`yr'90[rownumb(`margin'_tradvdif`yr'90,"subs_tarfoutp")..rownumb(`margin'_tradvdif`yr'90,"subs_tarfintm"),1...]
    mat `margin'_predsec`yr'90 = subs`margin'_meff_tbl[rownumb(subs`margin'_meff_tbl,"subs_tarfoutp")..rownumb(subs`margin'_meff_tbl,"subs_reffpen"),1...] ' * `margin'_tradvdif`yr'90[rownumb(`margin'_tradvdif`yr'90,"subs_tarfoutp")..rownumb(`margin'_tradvdif`yr'90,"subs_reffpen"),1...]
    mat `margin'_predall`yr'90 = subs`margin'_meff_tbl ' * `margin'_tradvdif`yr'90
    }
  }

// Table of predicted displacement effects
matload labstat_tbl, dropall p(brazrloc/tex/v4/labor) over missing(.)
matorder labstat_tbl, m(labstat_tbl) ifr(1986 1990 1992 1994 1998)
matorder labstat_tbl, m(labstat_tbl) ifc(natl_manuf_inddspl natl_manuf_indhire)
mat turnpred_tbl =  labstat_tbl ' \ J(2,5,.)
mat drop labstat_tbl
mat rownames turnpred_tbl = dspl:pop hire:pop dspl:chg hire:chg
mat colnames turnpred_tbl = y1986 y1990 y1992 y1994 y1998
foreach yr in 90 92 94 98 {
  mat turnpred_tbl[3,colnumb(turnpred_tbl,"y19`yr'")] = turnpred_tbl[1,colnumb(turnpred_tbl,"y19`yr'")] - turnpred_tbl[1,colnumb(turnpred_tbl,"y1990")]
  mat turnpred_tbl[4,colnumb(turnpred_tbl,"y19`yr'")] = turnpred_tbl[2,colnumb(turnpred_tbl,"y19`yr'")] - turnpred_tbl[2,colnumb(turnpred_tbl,"y1990")]
  }
foreach margin in dspl hire {
  mat _tradlvl`margin' = J(4,5,.)
  mat _tradchg`margin' = J(4,5,.)
  mat _tradeff`margin' = J(12,5,.)
  mat rownames _tradlvl`margin' = `margin':subs_tarfoutp_lvl `margin':subs_tarfintm_lvl `margin':subs_reffpen_lvl `margin':firm_indexp_lvl
  mat rownames _tradchg`margin' = `margin':subs_tarfoutp `margin':subs_tarfintm `margin':subs_reffpen `margin':firm_indexp
  mat rownames _tradeff`margin' = `margin':predrfpen_noyr `margin':predtarfs_noyr `margin':predsec_noyr `margin':predall_noyr `margin':predrfpen `margin':predtarfs `margin':predsec `margin':predall `margin':predrfpen_secfe `margin':predtarfs_secfe `margin':predsec_secfe `margin':predall_secfe
  mat colnames _tradchg`margin' = y1986 y1990 y1992 y1994 y1998
  mat colnames _tradlvl`margin' = y1986 y1990 y1992 y1994 y1998
  mat colnames _tradeff`margin' = y1986 y1990 y1992 y1994 y1998
  foreach var in subs_tarfoutp subs_tarfintm subs_reffpen firm_indexp {
    mat _tradlvl`margin'[rownumb(_tradlvl`margin',"`var'_lvl"),colnumb(_tradlvl`margin',"y1990")] = subs`margin'_tradvars90_tbl[rownumb(subs`margin'_tradvars90_tbl,"`var'"),colnumb(subs`margin'_tradvars90_tbl,"yr90_allsec")]
    mat _tradchg`margin'[rownumb(_tradchg`margin',"`var'"),colnumb(_tradchg`margin',"y1990")] = 0
    foreach yr in 92 94 98 {
      mat _tradchg`margin'[rownumb(_tradchg`margin',"`var'"),colnumb(_tradchg`margin',"y19`yr'")] = `margin'_tradvdif`yr'90[rownumb(dspl_tradvdif`yr'90,"`var'"),colnumb(dspl_tradvdif`yr'90,"yr90_allsec")]
      mat _tradlvl`margin'[rownumb(_tradlvl`margin',"`var'_lvl"),colnumb(_tradlvl`margin',"y19`yr'")] = subs`margin'_tradvars`yr'_tbl[rownumb(subs`margin'_tradvars`yr'_tbl,"`var'"),colnumb(subs`margin'_tradvars`yr'_tbl,"yr`yr'_allsec")]
      }
    }
  foreach eff in predrfpen predtarfs predsec predall {
    foreach spec in "" "_noyr" "_secfe" {
      mat _tradeff`margin'[rownumb(_tradeff`margin',"`eff'`spec'"),colnumb(_tradeff`margin',"y1990")] = 0
      foreach yr in 92 94 98 {
        if "`spec'"==""        mat _tradeff`margin'[rownumb(_tradeff`margin',"`eff'`spec'"),colnumb(_tradeff`margin',"y19`yr'")] = `margin'_`eff'`yr'90[rownumb(`margin'_`eff'`yr'90,"clogit_paper"),colnumb(`margin'_`eff'`yr'90,"yr90_allsec")]
        if "`spec'"=="_noyr"   mat _tradeff`margin'[rownumb(_tradeff`margin',"`eff'`spec'"),colnumb(_tradeff`margin',"y19`yr'")] = `margin'_`eff'`yr'90[rownumb(`margin'_`eff'`yr'90,"clogit_noyreff"),colnumb(`margin'_`eff'`yr'90,"yr90_allsec")]
        if "`spec'"=="_secfe"  mat _tradeff`margin'[rownumb(_tradeff`margin',"`eff'`spec'"),colnumb(_tradeff`margin',"y19`yr'")] = `margin'_`eff'`yr'90[rownumb(`margin'_`eff'`yr'90,"clogit_secfe"),colnumb(`margin'_`eff'`yr'90,"yr90_allsec")]
        }
      }
    }
  }
* mat turnpred_tbl = turnpred_tbl \ _tradlvldspl \ _tradlvlhire \ _tradchgdspl \ _tradchghire // displacement and hiring figures for sector variables similar
mat turnpred_tbl = turnpred_tbl \ _tradlvldspl \ _tradchgdspl
mat rownames turnpred_tbl = dspl:pop hire:pop dspl:chg hire:chg seclvl:subs_tarfoutp seclvl:subs_tarfintm seclvl:subs_reffpen seclvl:firm_indexp secchg:subs_tarfoutp secchg:subs_tarfintm secchg:subs_reffpen secchg:firm_indexp
mat drop _tradlvldspl _tradlvlhire _tradchgdspl _tradchghire
mat turnpred_tbl = turnpred_tbl \ _tradeffdspl \ _tradeffhire
mat drop _tradeffdspl _tradeffhire

// list trade effects by sector (tariff and penetration, not exporting status)
disp
foreach margin in dspl hire {
  foreach yr in 98 {
    disp
    * disp in gr "Effect of " in ye "subs_tarfoutp" in gr " and " in ye "_tarfintm" in gr " changes between 1990 and " in ye "19`yr'" in gr " on " in ye "`margin'" in gr " probability: " in ye %9.3f `margin'_predtarfs`yr'90[rownumb(`margin'_predtarfs`yr'90,"clogit_noyr"),colnumb(`margin'_predtarfs`yr'90,"yr90_allsec")]
    disp in gr "Effect of trade variable changes between 1990 and " in ye "19`yr'" in gr " on " in ye "`margin'" in gr " probability: " in ye %9.3f `margin'_predsec`yr'90[rownumb(`margin'_predsec`yr'90,"clogit_noyr"),colnumb(`margin'_predsec`yr'90,"yr90_allsec")]
    mat _`margin'_predsec`yr'90 = `margin'_predsec`yr'90[rownumb(`margin'_predsec`yr'90,"clogit_noyr"),colnumb(`margin'_predsec`yr'90,"yr90_sec02")..colnumb(`margin'_predsec`yr'90,"yr90_sec13")]
    mat list _`margin'_predsec`yr'90
    mat drop _`margin'_predsec`yr'90
    disp
    }
  }
disp

// labor productivity at accession margin
matload ollpak_alt_tbl, p(brazrloc/tex/v4/tfp) over missing(.)
matorder ollpak_alt_tbl, m(ollpak_alt_tbl) ifr(90 92 94 98) over
matorder ollpak_alt_tbl, m(ollpak_alt_tbl) ifc(agglnlp) over
mat ollpak_alt_tbl = ollpak_alt_tbl ' - J(1,4,1)  // 1990: 1
matload paper_frmlnlp_tbl, p(brazrloc/tex/v4/natl-maleprime/reg) over missing(.)
matorder paper_frmlnlp_tbl, m(paper_frmlnlp_tbl) ifr(firm_lnlp) over
matorder paper_frmlnlp_tbl, m(paper_frmlnlp_tbl) ifc(hire_clogit_lnlp) over
local lnlpcoef = paper_frmlnlp_tbl[1,1]
mat hire_predlnlp = J(1,1,.) , ollpak_alt_tbl * `lnlpcoef' * `phathire'*(1-`phathire')
matrix colnames hire_predlnlp = y1986 y1990 y1992 y1994 y1998
matrix rownames hire_predlnlp = hire:predlp_lnlp
mat turnpred_tbl = turnpred_tbl \ hire_predlnlp

// prediction table output
est2tex turnpred, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)
matorder turnpred_tbl, m(turnpred_paper_tbl) ifc(y1990 y1992 y1994 y1998)
est2tex turnpred_paper, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)

// keep turnover prediction matrix for later use, drop other matrices
matorder turnpred_paper_tbl, m(turnpred) ifr(dspl:predrfpen_noyr dspl:predsec_noyr hire:predrfpen_noyr hire:predsec_noyr hire:predlp_lnlp)
foreach margin in dspl hire {
  foreach yr in 92 94 98 {
    mat drop `margin'_predtarfs`yr'90 `margin'_predrfpen`yr'90 `margin'_predsec`yr'90 `margin'_predall`yr'90 `margin'_tradvdif`yr'90 subs`margin'_tradvars`yr'_tbl
    }
  mat drop subs`margin'_tradvars90_tbl
  }
mat drop subsdspl_meff_tbl subshire_meff_tbl


/* AUXILIARY DATA */

// Monthly Minimum Wage in USD
tempfile minwage
use "brazaux/auxil/minwage.dta", clear
gen int ano = year(day)
gen int mo = month(day)
keep ano mo salusd
sort ano mo
collapse (mean) salusd, by(ano)
label var ano "Calendar year"
label var salusd "Minimum Wage in USD (nom. rate)"
keep if ano>1985 & ano<2002
sort ano
save `minwage'

// Annual GDP and Minimum Wage in USD
tempfile gdpwage
insheet using "brazrloc/auxil/origs/pib.csv", comma clear
keep ano pib_corrente_usd pib_pc_corrente_usd
rename pib_corrente_usd gdpusd
rename pib_pc_corrente_usd gdppcusd
label var ano "Calendar year"
label var gdpusd "GDP in USD (nom. rate)"
label var gdppcusd "GDP p.c. in USD (nom. rate)"
keep if ano>1985 & ano<2002
sort ano
merge ano using `minwage'
qui count if _m~=3
if `r(N)'~=0  STOP
drop _m
replace salusd = salusd*12
label var salusd "Ann. Min. Wage in USD (nom. rate)"
gen gdppc_sal_ratio = gdppcusd/salusd
label var gdppc_sal_ratio "GDP p.c./Ann. Min. Wage"
sort ano
preserve
  gen str _rowname = "y" + string(ano)
  drop ano
  save "brazrloc/tex/v4/gdp/gdpwage_tbl.dta", replace
  matload gdpwage_tbl, dropall over missing(.) p(brazrloc/tex/v4/gdp)
  mat gdpwage_tbl = gdpwage_tbl , ( multsal_indnorloc \ J(1,1,.) )
  mat drop multsal_indnorloc
  est2tex gdpwage, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)
restore
drop gdppcusd gdppc_sal_ratio
sort ano
save `gdpwage'


/* TRANSITIONS FROM FORMAL EMPLOYMENT TO STATUS OUTSIDE FORMALITY */

use "brazrloc/tex/v4/pme/tabelas", clear
keep year formal_informal formal_formal formal_self_employment formal_unemployed_fora_da_pea 
drop if year<1986
order year formal_formal formal_informal formal_self_employment formal_unemployed_fora_da_pea
foreach var in formal informal self_employment unemployed_fora_da_pea {
  replace formal_`var' = formal_`var'/100
  }
gen str7 _rowname = string(year)
forvalues yr=86/98 {
  local yr1 = `yr' + 1
  replace _rowname = "y" + _rowname + "_`yr1'" if _rowname=="19`yr'"
  }
* report
drop year
replace formal_informal = formal_informal/(1-formal_formal)
replace formal_self_employment = formal_self_employment/(1-formal_formal)
replace formal_unemployed_fora_da_pea = formal_unemployed_fora_da_pea/(1-formal_formal)
drop formal_formal
egen _chk = rsum(formal_informal formal_self_employment formal_unemployed_fora_da_pea)
qui summ _chk
qui count if _chk<.99 | _chk>1.01
if `r(N)'>0  STOP
drop _chk
save "brazrloc/tex/v4/pme/form2nonform_86_99_tbl.dta", replace
matload form2nonform_86_99_tbl, dropall over missing(.) p(brazrloc/tex/v4/pme)
mat form2nonform_86_99_tbl = form2nonform_86_99_tbl '
est2tex form2nonform_86_99, replace dropall ready p(brazrloc/tex/v4/pme) fancy digits(3)


/* WAGE-BILL LOSS IN GDP FROM REALLOCATION DURATIONS AND FAILED REALLOCATIONS */

matorder gdpwage_tbl, m(gdpwage_tbl) over ifc(gdpusd salusd)
matorder gdpwage_tbl, m(gdpwage_tbl) over ifr(y1990 y1991 y1992 y1993 y1994 y1995 y1996 y1997 y1998)
mat gdpwage_tbl = gdpwage_tbl '
local colyrs : colnames gdpwage_tbl
matorder indnorloc12mbygrp_tbl, m(indnorloc_gdp) ifr(any:r(mean) any:r(N) any:mean_rem_media)
matorder indnorloc_gdp, m(indnorloc_gdp) ifc(indnorloc1990 indnorloc1991 indnorloc1992 indnorloc1993 indnorloc1994 indnorloc1995 indnorloc1996 indnorloc1997 indnorloc1998) over
mat drop indnorloc12mbygrp_tbl
matorder mo2rehr12mbygrp_tbl, m(mo2rehr_gdp) ifr(any:r(mean))
matorder mo2rehr_gdp, m(mo2rehr_gdp) ifc(mo2rehir1990 mo2rehir1991 mo2rehir1992 mo2rehir1993 mo2rehir1994 mo2rehir1995 mo2rehir1996 mo2rehir1997 mo2rehir1998) over
mat drop mo2rehr12mbygrp_tbl
mat gdploss = J(4,9,.)
matrix rownames gdploss = chg:indnorloc chg:mo2rehr tbr:indnorloc tbr:mo2rehr
matrix colnames gdploss = `colyrs'
local j 0
forvalues ano = 1990/1998 {
  local j = `j' + 1
  mat gdploss[1,`j'] = ( (indnorloc_gdp[1,`j']-indnorloc_gdp[1,1]) )
  mat gdploss[2,`j'] = ( ((mo2rehr_gdp[1,`j']-mo2rehr_gdp[1,1])/12) )
  mat gdploss[3,`j'] = ( (indnorloc_gdp[1,`j']-indnorloc_gdp[1,1]) * indnorloc_gdp[2,`j']*100 * indnorloc_gdp[3,`j']*12 * gdpwage_tbl[2,`j'] / 1000000 ) / gdpwage_tbl[1,`j']
  mat gdploss[4,`j'] = ( ((mo2rehr_gdp[1,`j']-mo2rehr_gdp[1,1])/12) * indnorloc_gdp[2,`j']*100 * indnorloc_gdp[3,`j']*12 * gdpwage_tbl[2,`j'] / 1000000 ) / gdpwage_tbl[1,`j']
  }
mat _gdploss = J(2,9,.)
matrix rownames _gdploss = idle:indnorloc idle:mo2rehr
matrix colnames _gdploss = `colyrs'
foreach ano in 1990 1992 1994 1996 1998 {
  forvalues row = 1/2 {
    local anopl1 = `ano' + 1 - 1900
    mat _gdploss[`row',colnumb(_gdploss,"y`ano'")] = gdploss[`row'+2,colnumb(gdploss,"y`ano'")] * form2nonform_86_99_tbl[rownumb(form2nonform_86_99_tbl,"formal_unemployed_fora_da_pea"),colnumb(form2nonform_86_99_tbl,"y`ano'_`anopl1'")]
    }
  }
mat gdploss = gdploss \ _gdploss
mat drop _gdploss
mat rename gdploss gdploss_tbl
est2tex gdploss, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)


/* OVERALL TABLE */

matload mo2rehr12mbygrp_tbl, p(brazrloc/tex/v4/natl-maleprime/duration) dropall missing(.) over
matorder mo2rehr12mbygrp_tbl, m(mo2rehr12mbygrp_tbl) ifc(mo2rehir1986 mo2rehir1990 mo2rehir1992 mo2rehir1994 mo2rehir1998) over
matorder mo2rehr12mbygrp_tbl, m(mo2rehr12mbygrp_tbl) ifr(any:r(mean)) over
mat rownames mo2rehr12mbygrp_tbl = mo2rehr
matload indnorloc12mbygrp_tbl, p(brazrloc/tex/v4/natl-maleprime/duration) dropall missing(.) over
matorder indnorloc12mbygrp_tbl, m(indnorloc12mbygrp_tbl) ifc(indnorloc1986 indnorloc1990 indnorloc1992 indnorloc1994 indnorloc1998) over
matorder indnorloc12mbygrp_tbl, m(indnorloc12mbygrp_tbl) ifr(any:r(mean) any:r(N)) over
foreach yr in 86 90 92 94 98 {  // scale to population size
  mat indnorloc12mbygrp_tbl[rownumb(indnorloc12mbygrp_tbl,"any:r(N)"),colnumb(indnorloc12mbygrp_tbl,"indnorloc19`yr'")] = indnorloc12mbygrp_tbl[rownumb(indnorloc12mbygrp_tbl,"any:r(N)"),colnumb(indnorloc12mbygrp_tbl,"indnorloc19`yr'")] * 100
  }
mat rownames indnorloc12mbygrp_tbl = indnorloc r(N)
mat _gdp_turnov_tbl = mo2rehr12mbygrp_tbl \ indnorloc12mbygrp_tbl
mat drop mo2rehr12mbygrp_tbl indnorloc12mbygrp_tbl
matorder _gdp_turnov_tbl, m(_gdp_turnov_tbl) over ifr(any:indnorloc any:mo2rehr any:r(N))
matorder rlocsucc_paper_tbl, m(rlocsucc_paper_tbl) ifr(mo2rehr:any mo2rehr:young mo2rehr:coll indnorloc:any indnorloc:young indnorloc:coll)
mat _gdp_turnov_tbl = _gdp_turnov_tbl \ rlocsucc_paper_tbl
matorder _gdp_turnov_tbl, m(_gdp_turnov_tbl) over ifr(indnorloc:any indnorloc:young indnorloc:coll mo2rehr:any mo2rehr:young mo2rehr:coll any:r(N))

matorder gdploss_tbl, m(gdp_turnov_tbl) ifc(y1990 y1992 y1994 y1998)
mat gdp_turnov_tbl = gdp_turnov_tbl \ turnpred
local rownames : rowfullnames gdp_turnov_tbl
mat gdp_turnov_tbl = J(11,1,.) , gdp_turnov_tbl
mat rownames gdp_turnov_tbl = `rownames'
mat gdp_turnov_tbl = _gdp_turnov_tbl \ gdp_turnov_tbl
mat drop _gdp_turnov_tbl
mat colnames gdp_turnov_tbl = y1986 y1990 y1992 y1994 y1998
matorder gdp_turnov_tbl, m(gdp_turnov_tbl) ifr(mo2rehr:any mo2rehr:young mo2rehr:coll chg:mo2rehr tbr:mo2rehr idle:mo2rehr indnorloc:any indnorloc:young indnorloc:coll chg:indnorloc tbr:indnorloc idle:indnorloc any:r(N) dspl:predrfpen_noyr dspl:predsec_noyr hire:predrfpen_noyr hire:predsec_noyr hire:predlp_lnlp) over
est2tex gdp_turnov, replace dropall ready p(brazrloc/tex/v4/gdp) fancy digits(3)


* Clean Up
mat drop rlocsucc_paper_tbl ollpak_alt_tbl paper_frmlnlp_tbl turnpred form2nonform_86_99_tbl gdpwage_tbl indnorloc_gdp mo2rehr_gdp gdploss_tbl gdp_turnov_tbl


log close
