!* BRAZRLOC v4

program drop _all

// check temporary directory
! export STATATMP=/data/tmp
tempfile findout
* disp "`findout'"
if substr("`findout'",1,10)~="/data/tmp/"  STOP  // default /tmp/ too small to use

// soft symbolic links for linux
* ln -s /data/rais /home/muendler/data/rais
* ln -s /data/brazaux /home/muendler/data/brazaux
* ln -s /data/secex /home/muendler/data/secex

global root "/home/muendler/data"
global home "/home/muendler/data"
global extdata "/home/muendler/data"
global srvdata "/home/muendler/data"

clear
clear matrix
set more off
set virtual on
* set trace on
set matsize 150
global maxiter 20

cd "$root"
adopath + "brazrloc/%stata/ado"
qui do "brazrloc/%stata/ado/%Read-tabl2tex.do"

capture mkdir "brazrloc/logs"
capture mkdir "brazrloc/data"
capture mkdir "brazrloc/estmat"
capture mkdir "brazrloc/estmat/v4"
capture mkdir "brazrloc/graphs"
capture mkdir "brazrloc/graphs/v4"
capture mkdir "brazrloc/tex"
capture mkdir "brazrloc/tex/v4"

global regdef "APD CEE LAC NAM ODV OIN WEU"
global reghomdef "APD CEE HOM LAC NAM ODV OIN WEU"

* set memory
set mem 40g

* 1. DATA PREPARATION
*--------------------

* do "brazrloc/%stata/%1prep-data/sector-list.do"
    /* PREPARE AGGREGATE SECTOR LIST BEYOND MANUFACTURING */
    /* INPUT:  "brazrloc/auxil/subsector-aggsector.csv"
               "rais/cnae/cnae2subsibge.dta"
               "rais/cnae/ibge.do" */
    /* OUTPUT: "brazrloc/auxil/subsibge2aggsec.dta"
               "brazrloc/auxil/aggsec.do" */
    /*   Logs: "brazrloc/logs/sector-list.log" */ 

* do "brazrloc/%stata/%1prep-data/metro-list.do"
    /* PREPARE MUNICIPALITY LIST WITH METROPOLITAN AREAS */
    /* INPUT:  "rais/auxil/origs/05 05 2005 base dados ajustada pib dos municipios 1999-2002.csv" */
    /* OUTPUT: "brazrloc/auxil/metro-list.dta"
               "brazrloc/auxil/metro-list.csv" */
    /*   Logs: "brazrloc/logs/metro-list.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-data-natl.do"
    /* PREPARE NATIONWIDE RAIS WORKER DATA */
    /* INPUT:  "rais/draws/natl/wid-draw-workers-natl.csv"
               "rais/cbo/cbostr2num.dta" */
    /*     DO: "rais/auxil/`lblfile'.do" (`lblfile' in sexo instr vinc desl nacional etaria adm estbl jurid)
               "rais/cnae/`lblfile'.do" (`lblfile' in ibge cnae_95)
               "rais/cbo/`lblfile'.do" (`lblfile' in cbogrp) */
    /* OUTPUT: "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/wid-draw-workers-natl-cnpj.dta" */
    /*   Logs: "brazrloc/logs/rais-data-natl.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-data-natl-10pct.do"
    /* PREPARE NATIONWIDE RAIS WORKER DATA */
    /* INPUT:  "rais/draws/natl10pct/wid-draw-workers-natl-10pct.csv"
               "rais/cbo/cbostr2num.dta" */
    /*     DO: "rais/auxil/`lblfile'.do" (`lblfile' in sexo instr vinc desl nacional etaria adm estbl jurid)
               "rais/cnae/`lblfile'.do" (`lblfile' in ibge cnae_95)
               "rais/cbo/`lblfile'.do" (`lblfile' in cbogrp) */
    /* OUTPUT: "brazrloc/data/wid-draw-workers-natl-10pct.dta"
               "brazrloc/data/wid-draw-workers-natl-cnpj-10pct.dta" */
    /*   Logs: "brazrloc/logs/rais-data-natl-10pct.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-data-metro.do"
    /* PREPARE METROPOLITAN RAIS WORKER DATA */
    /* INPUT:  "rais/draws/metro/wid-draw-workers-metro-male.csv"
               "rais/cbo/cbostr2num.dta" */
    /*     DO: "rais/auxil/`lblfile'.do" (`lblfile' in sexo instr vinc desl nacional etaria adm estbl jurid)
               "rais/cnae/`lblfile'.do" (`lblfile' in ibge cnae_95)
               "rais/cbo/`lblfile'.do" (`lblfile' in cbogrp) */
    /* OUTPUT: "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-cnpj.dta" */
    /*   Logs: "brazrloc/logs/rais-data-metro-male.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-data-metro-subsample.do"
    /* RANDOM SUBSAMPLE OF METROPOLITAN RAIS WORKER DATA */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta" */
    /* OUTPUT: "brazrloc/data/wid-draw-workers-metro-male-subsample.dta" */
    /*   Logs: "brazrloc/logs/rais-data-metro-male-subsample.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-list-natl.do"
    /* PREPARE RAIS PLANT DATA FOR ANNUAL PRESENCE LIST */
    /* INPUT:  "rais/base-cnpj/rais-catalog-cnpj.dta"
               "brazrloc/data/wid-draw-workers-natl-cnpj.csv" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-list-natl.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-list-natl.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-list-natl-10pct.do"
    /* PREPARE RAIS PLANT DATA FOR ANNUAL PRESENCE LIST */
    /* INPUT:  "rais/base-cnpj/rais-catalog-cnpj.dta"
               "brazrloc/data/wid-draw-workers-natl-cnpj-10pct.csv" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-list-natl-10pct.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-list-natl-10pct.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-list-metro.do"
    /* PREPARE RAIS PLANT DATA FOR ANNUAL PRESENCE LIST */
    /* INPUT:  "rais/base-cnpj/rais-catalog-cnpj-metro.dta"
               "brazrloc/data/wid-draw-workers-metro-male-cnpj.csv" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-list-metro.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-list-metro.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpjradic-cnae95.do"
    /* FIRM-LEVEL CNAE SECTOR INFORMATION 1995 (FOR TABLES, GRAPHS AND REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpjradic/aggcnpj_`ext'.dta" (where `ext' in A through J)
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-list-metro.dta"
               "brazrloc/data/rais-cnpj-list-natl-10pct.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-metro-86-98.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpjradic-cnae95.log" */ 

* do "brazrloc/%stata/%1prep-data/niv100-agg.do"
    /* PREPARE NIV100 SECTOR DATA BASED ON PIA AND RAIS INFORMATION (FOR TABLES AND GRAPHS) */
    /* INPUT:  "brazaux/Xpia/firms-86-98.dta" 
               "brazaux/pia/prodcoeff-brazprod.dta"
               "brazcomp/filters/cnae2niv100.dta"
               "rais/cnae/niv100.do"
               "rais/cnae/niv50.do" */
    /* OUTPUT: "brazrloc/auxil/niv100-agg.dta"
               "brazrloc/auxil/niv50-agg.dta" */
    /*   Logs: "brazrloc/logs/niv100-agg.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-data-metro.do"
    /* PREPARE METROPOLITAN PLANT DATA (FOR REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpj/aggcnpj_`ext'.dta" (where `ext' in a b c d e f g h i j)
               "brazrloc/data/rais-cnpj-list-metro.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-data-metro.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-data-metro.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-data-natl.do"
    /* PREPARE NATIONAL PLANT DATA (FOR REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpj/aggcnpj_`ext'.dta" (where `ext' in a b c d e f g h i j) 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-list-natl-10pct.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl-10pct.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-data-natl.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-data-metro-nber.do"
    /* PREPARE METROPOLITAN PLANT DATA (FOR REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpj/aggcnpj_`ext'.dta" (where `ext' in a b c d e f g h i j)
               "brazrloc/data/rais-cnpj-list-metro.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-data-metro-nber.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-data-metro-nber.log" */ 

* do "brazrloc/%stata/%1prep-data/rais-cnpj-data-natl-nber.do"
    /* PREPARE METROPOLITAN PLANT DATA (FOR REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnpj/aggcnpj_`ext'.dta" (where `ext' in a b c d e f g h i j)
               "brazrloc/data/rais-cnpj-list-natl.dta" */
    /* OUTPUT: "brazrloc/data/rais-cnpj-data-natl-nber.dta" */
    /*   Logs: "brazrloc/logs/rais-cnpj-data-natl-nber.log" */ 

* do "brazrloc/%stata/%1prep-data/pia-data.do"
    /* PREPARE PIA DATA (FOR REGRESSIONS) */
    /* INPUT:  "brazaux/pia/random-3firm-rndmnr.dta"
               "brazaux/pia/random-3firm-firmlist-rndmnr.dta"
               "brazaux/pia/prodcoeff-brazprod.dta" */
    /* OUTPUT: "brazrloc/data/pia-data.dta" */
    /*   Logs: "brazrloc/logs/pia-data.log" */ 

* do "brazrloc/%stata/%1prep-data/pia-Xdata.do"
    /* PREPARE PIA DATA (FOR REGRESSIONS) */
    /* INPUT:  "brazaux/Xpia/firms-86-98.dta"
               "brazaux/pia/prodcoeff-brazprod.dta" */
    /* OUTPUT: "brazrloc/data/pia-Xdata.dta" */
    /*   Logs: "brazrloc/logs/pia-Xdata.log" */ 

* do "brazrloc/%stata/%1prep-data/pia-niv50.do"
    /* PREPARE NIV100 SECTOR DATA BY FIRM (FOR CLUSTERED REGRESSIONS IN PIA SUBSAMPLE) */
    /* INPUT:  "brazaux/pia/random-3firm-firmlist-rndmnr.dta"
               "rais/cnae/niv50.do" */
    /* OUTPUT: "brazrloc/data/pia-niv50.dta" */
    /*   Logs: "brazrloc/logs/pia-niv50.log" */ 

* do "brazrloc/%stata/%1prep-data/sector-data.do"
    /* PREPARE AGGREGATE SECTOR DATA (FOR IV REGRESSIONS) */
    /* INPUT:  "rais/base-agg/cnae/aggsec.csv"
               "rais/base-agg/subsibge/aggsec.csv"
               "brazaux/auxil/seclvl.dta"
               "brazaux/auxil/seclvl-cnae.dta"
               "brazrloc/auxil/manual/niv50-subsibge-manual.csv" */
    /* OUTPUT: "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/sector-subsibge-moredata.dta" */
    /*   Logs: "brazrloc/logs/sector-data.log" */ 

* do "brazrloc/%stata/%1prep-data/secex90-subsibge-expval.do"
    /* MAP SECEX FIRMS AND THEIR EXPORTS BY COUNTRY TO RAIS-SUBSIBGE SECTORS */
    /* INPUT:  "rais/base-agg/cnpjradic/aggcnpj_`file'.dta" (where `file' in a through j)
               "secex/csv/exp90.csv" */
    /* OUTPUT: "brazrloc/auxil/subsibge-country-exp90.dta" */
    /*   Logs: "brazrloc/logs/secex90-subsibge-expval.log" */ 

* do "brazrloc/%stata/%1prep-data/wtf-data.do"
    /* PREPARE WTF-NBER DATA (FOR IV REGRESSIONS) */
    /* INPUT:  "brazaux/conc/countries/country-table.dta"
               "brazaux/intl/nber/wtf_bilat.dta"
               "brazrloc/auxil/subsibge-country-exp90.dta" */
    /* OUTPUT: "brazrloc/auxil/wtf-data.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /*   Logs: "brazrloc/logs/wtf-data.log" */ 

* do "brazrloc/%stata/%1prep-data/wtf-data-by-sitc4.do"
    /* PREPARE WTF-NBER DATA (FOR REFINED IV REGRESSIONS) */
    /* INPUT:  "brazaux/conc/sec/sitc2subsibge.dta"
               "brazaux/conc/countries/country-table.dta"
               "brazaux/intl/nber/wtf`yr'.dta" (where `yr' in 86 87 ... 99 00) */
    /* OUTPUT: "brazrloc/auxil/wtf-data-by-sitc4.dta" */
    /*   Logs: "brazrloc/logs/wtf-data-by-sitc4.log" */ 

* do "brazrloc/%stata/%1prep-data/subsibge-ivs.do"
    /* PREPARE IVS WITH SUBSIBGE VARIATION */
    /* INPUT:  "brazprod/addl/ivs/ppi-us/us-ppi.dta"
               "brazrloc/auxil/wtf-data-by-sitc4.dta" */
    /* OUTPUT: "brazrloc/auxil/subsibge-ivs.dta" */
    /*   Logs: "brazrloc/logs/subsibge-ivs.log" */ 

* do "brazrloc/%stata/%1prep-data/globfindata.do"
    /* PREPARE TIME-VARYING MACRO VARIABLES */
    /* INPUT:  "brazrloc/auxil/gfd/`series'.csv" (where `series' in __brl_d cpbram wpbram idbrasd imbrad itbra3d _ibx50d sybraym) */
    /* OUTPUT: "brazrloc/auxil/globfin-annual.dta" */
    /*   Logs: "brazrloc/logs/globfindata.log" */ 


* 2. TABLES AND GRAPHS
*---------------------

* do "brazrloc/%stata/%2tab-graph/empl-stats.do"
    /* CONVENTIONAL LABOR MARKET STATISTICS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/auxil/subsibge2aggsec.dta"
               "rais/base-agg/subsibge/aggsec.csv" 
               "rais/auxil/metro-pme.dta" */
    /* OUTPUT: none */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/metromale-prime/laborstats/form_metromale_prime.tex"
               "brazrloc/tex/v4/metromale/laborstats/form_metromale.tex"
               "brazrloc/tex/v4/metromale/laborstats/form_metromale_sp.tex"
               "brazrloc/tex/v4/natl/laborstats/form_natl.tex"
               "brazrloc/tex/v4/natl/laborstats/form_natl_maleprime.tex"
               "brazrloc/tex/v4/natl/laborstats/form_sp.tex"
               "brazrloc/tex/v4/natl/laborstats/form_pop.tex" 
               "brazrloc/tex/v4/natl/laborstats/emplshare_pop.tex"
               "brazrloc/tex/v4/natl/laborstats/emplshare_aerrr.tex" */
    /*   Logs: "brazrloc/logs/empl-stats.log" */

* do "brazrloc/%stata/%2tab-graph/durations-natl.do"
    /* DURATIONS OF REALLOCATION FOR ANY WORKER IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-list.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl/duration/indnorloc`dur'm.eps" (where `dur' in 12 48 60)
               "brazrloc/graphs/v4/natl/duration/indnorloc`dur'm-color.eps" (where `dur' in 12 48 60)
               "brazrloc/graphs/v4/natl/duration/mo2rehir`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl/duration/mo2rehir`dur'-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl/duration/medmo2rehir`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl/duration/medmo2rehir`dur'-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl/duration/mo2rehir`dur'-contplants.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl/duration/mo2rehir`dur'-contplants-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl/duration/halflife`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl/duration/halflife`dur'-color.eps" (where `dur' in 12 36 48)
          TeX: "brazrloc/tex/v4/natl/duration/indnorloc`dur'mbygrp.tex" (where `dur' in 12 48 60)
               "brazrloc/tex/v4/natl/duration/mo2rehr`dur'mbygrp.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl/duration/indnorloc`dur'm.tex" (where `dur' in 12 48 60)
               "brazrloc/tex/v4/natl/duration/mo2rehr`dur'm.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl/duration/mo2rehr`dur'm_cntplnts.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl/duration/halflife`dur'm.tex" (where `dur' in 12 36 48) */
    /*   Logs: "brazrloc/logs/durations-natl.log" */

* do "brazrloc/%stata/%2tab-graph/durations-natl-maleprime.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-list.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl-maleprime/duration/indnorloc`dur'm.eps" (where `dur' in 12 48 60)
               "brazrloc/graphs/v4/natl-maleprime/duration/indnorloc`dur'm-color.eps" (where `dur' in 12 48 60)
               "brazrloc/graphs/v4/natl-maleprime/duration/mo2rehir`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/duration/mo2rehir`dur'-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/duration/medmo2rehir`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/duration/medmo2rehir`dur'-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/duration/mo2rehir`dur'-contplants.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/duration/mo2rehir`dur'-contplants-color.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/duration/halflife`dur'.eps" (where `dur' in 12 36 48)
               "brazrloc/graphs/v4/natl-maleprime/duration/halflife`dur'-color.eps" (where `dur' in 12 36 48)
          TeX: "brazrloc/tex/v4/natl-maleprime/duration/indnorloc`dur'mbygrp.tex" (where `dur' in 12 48 60)
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr`dur'mbygrp.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl-maleprime/duration/indnorloc`dur'm.tex" (where `dur' in 12 48 60)
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr`dur'm.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr`dur'm_cntplnts.tex" (where `dur' in 12 36 48)
               "brazrloc/tex/v4/natl-maleprime/duration/halflife`dur'm.tex" (where `dur' in 12 36 48) */
    /*   Logs: "brazrloc/logs/durations-natl-maleprime.log" */

* do "brazrloc/%stata/%2tab-graph/durations-metromale.do"
    /* DURATIONS OF REALLOCATION FOR METROPOLITAN MALES */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/rais-cnpj-list.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/metromale/duration/indnorloc`dur'm.eps" (where `dur' in 48 and 60)
               "brazrloc/graphs/v4/metromale/duration/indnorloc`dur'm-color.eps" (where `dur' in 48 and 60)
               "brazrloc/graphs/v4/metromale/duration/mo2rehir`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/duration/mo2rehir`dur'm-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/duration/medmo2rehir`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/duration/medmo2rehir`dur'm-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/duration/mo2rehir`dur'm-contplants.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/duration/mo2rehir`dur'm-contplants-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/duration/halflife`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale/duration/halflife`dur'm-color.eps" (where `dur' in 36 and 48)
          TeX: "brazrloc/tex/v4/metromale/duration/indnorloc`dur'm.tex" (where `dur' in 48 and 60)
               "brazrloc/tex/v4/metromale/duration/mo2rehr`dur'm.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/metromale/duration/mo2rehr`dur'm_cntplnts.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/metromale/duration/halflife`dur'm.tex" (where `dur' in 36 and 48) */
    /*   Logs: "brazrloc/logs/durations-metromale.log" */

* do "brazrloc/%stata/%2tab-graph/durations-metromale-prime.do"
    /* DURATIONS OF REALLOCATION FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/rais-cnpj-list.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/metromale-prime/duration/indnorloc`dur'm.eps" (where `dur' in 12, 24, 36, 48 and 60)
               "brazrloc/graphs/v4/metromale-prime/duration/indnorloc`dur'm-color.eps" (where `dur' in 12, 24, 36, 48 and 60)
               "brazrloc/graphs/v4/metromale-prime/duration/mo2rehir`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/duration/mo2rehir`dur'm-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/duration/medmo2rehir`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/duration/medmo2rehir`dur'm-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/duration/mo2rehir`dur'm-contplants.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/duration/mo2rehir`dur'm-contplants-color.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/duration/halflife`dur'm.eps" (where `dur' in 36 and 48)
               "brazrloc/graphs/v4/metromale-prime/duration/halflife`dur'm-color.eps" (where `dur' in 36 and 48)
          TeX: "brazrloc/tex/v4/metromale-prime/duration/indnorloc`dur'm.tex" (where `dur' in 12, 24, 36, 48 and 60)
               "brazrloc/tex/v4/metromale-prime/duration/mo2rehr`dur'm.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/metromale-prime/duration/mo2rehr`dur'm_cntplnts.tex" (where `dur' in 36 and 48)
               "brazrloc/tex/v4/metromale-prime/duration/halflife`dur'm.tex" (where `dur' in 36 and 48) */
    /*   Logs: "brazrloc/logs/durations-metromale-prime.log" */

* do "brazrloc/%stata/%2tab-graph/labmkt-stats.do"
    /* LABOR MARKET EXPERIENCE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-natl.dta" 
               "rais/auxil/metro-pme.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/metromale-prime/laborstats/labmkttrns-86-98.eps"
               "brazrloc/graphs/v4/metromale-prime/laborstats/labmktexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/metromale/laborstats/labmktexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/metromale/laborstats/labmktexp-sp-`period'.eps" (where `period' in 86-93, 90-97)
               "brazrloc/graphs/v4/natl-maleprime/laborstats/labmkttrns-86-98.eps"
               "brazrloc/graphs/v4/natl-maleprime/laborstats/labmktexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/natl/laborstats/labmktexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/natl/laborstats/labmktexp-sp-`period'.eps" (where `period' in 86-93, 90-97)
          TeX: "brazrloc/tex/v4/metromale-prime/laborstats/labmkttrns_86_98.tex"
               "brazrloc/tex/v4/metromale-prime/laborstats/labmktexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01)
               "brazrloc/tex/v4/metromale/laborstats/labmktexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01) 
               "brazrloc/tex/v4/metromale/laborstats/labmktexp_sp_`period'.tex" (where `period' in 86_93, 90_97) 
               "brazrloc/tex/v4/natl-maleprime/laborstats/labmkttrns_86_98.tex"
               "brazrloc/tex/v4/natl-maleprime/laborstats/labmktexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01)
               "brazrloc/tex/v4/natl/laborstats/labmktexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01) 
               "brazrloc/tex/v4/natl/laborstats/labmktexp_sp_`period'.tex" (where `period' in 86_93, 90_97) */
    /*   Logs: "brazrloc/logs/labmkt-stats.log" */

* do "brazrloc/%stata/%2tab-graph/labocc-stats.do"
    /* OCCUPATIONAL EXPERIENCE (NATIONAL SAMPLE ONLY) */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl-maleprime/laborstats/labmkttrns-86-98.eps"
               "brazrloc/graphs/v4/natl-maleprime/laborstats/laboccexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/natl/laborstats/laboccexp-`period'.eps" (where `period' in 86-93, 90-97, 94-01)
               "brazrloc/graphs/v4/natl/laborstats/laboccexp-sp-`period'.eps" (where `period' in 86-93, 90-97)
          TeX: "brazrloc/tex/v4/natl-maleprime/laborstats/labmkttrns_86_98.tex"
               "brazrloc/tex/v4/natl-maleprime/laborstats/laboccexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01)
               "brazrloc/tex/v4/natl/laborstats/laboccexp_`period'.tex" (where `period' in 86_93, 90_97, 94_01) 
               "brazrloc/tex/v4/natl/laborstats/laboccexp_sp_`period'.tex" (where `period' in 86_93, 90_97) */
    /*   Logs: "brazrloc/logs/labocc-stats.log" */

* do "brazrloc/%stata/%2tab-graph/transitions.do"
    /* SECTOR TRANSITIONS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpjradic-cnae95-metro-86-98.dta"
               "brazrloc/auxil/subsibge2aggsec.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta"
               "rais/auxil/metro-pme.dta" */
    /* OUTPUT: none */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/`sampl'/trans/expsec_empl.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/expsec_empl_col.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_aggsec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_aggsec_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_aggsec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_aggsec_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_86_90.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_90_94.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_94_98.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_4yr.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_vr4yr.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_4yr_`grp'.tex" (where `sampl' in "natl", `grp' in "all" "femal" "nonprim" "young") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_86_90.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_90_94.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_94_98.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_unac.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_unac_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_unac_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_cnaesec_unac_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_indexp.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_indexp_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_indexp_insec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xtcs_indexp_num_insec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_num_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_num_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_insec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_num_insec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_manf.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_manf_num.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_manf_num_90_91.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_indexp_manf_num_96_97.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               */
    /*   Logs: "brazrloc/logs/transitions.log" */

* do "brazrloc/%stata/%2tab-graph/transitions-eigvec.do"
    /* EIGENVALUES OF SECTOR TRANSITIONS */
    /* INPUT:  "brazrloc/pme/pme-revision.dta"
               "brazrloc/pme/t48-year.dta"
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_4yr_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_vr4yr_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_8690_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_9094_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_9098_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_86_90_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_90_94_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_94_98_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_90_91_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_96_97_tbl.dta" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") */
    /* OUTPUT: "brazrloc/math/v4/`sampl'/xts`mat'.tab" (where `mat' in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr", `sampl' in "metromale-prime" "natl-maleprime" "natl")
               "brazrloc/math/v4/`sampl'/xts`mat'_eigvec.dat" (where `mat' in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr", `sampl' in "metromale-prime" "natl-maleprime" "natl")
               "brazrloc/math/v4/`sampl'/xts`mat'.tex" (where `mat' in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr", `sampl' in "metromale-prime" "natl-maleprime" "natl")
               "brazrloc/math/v4pmeadj/`sampl'/xts`mat'.tab" (where `mat' in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr", `sampl' in "metromale-prime" "natl-maleprime" "natl")
               "brazrloc/math/v4pmeadj/`sampl'/xts`mat'_eigvec.dat" (where `mat' in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr", `sampl' in "metromale-prime" "natl-maleprime" "natl")
               "brazrloc/math/v4pmeadj/`sampl'/xts`mat'.tex" (where `mat' in "" "_4yr" "_8690" "_9094" "_9498" "_9098" "_86_90" "_90_94" "_94_98" "_90_91" "_96_97" "_vr4yr", `sampl' in "metromale-prime" "natl-maleprime" "natl")
          TeX: "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_4yr_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_vr4yr_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_8690_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_9094_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_9498_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_9098_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_86_90_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_90_94_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_94_98_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_90_91_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_96_97_eigvec.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") */
    /*   Logs: "brazrloc/logs/transitions-eigvec.log" */

* do "brazrloc/%stata/%2tab-graph/braztfp-stats.do"
    /* OLLEY-PAKES AND HALTIWANGER REALLOCATION STATISTICS */
    /* INPUT:  "braztfp/decomp/haltiwanger-op-ipa2-output-notrend-fe-3x.dta"
               "braztfp/decomp/olleypakes-op-ipa2-output-notrend-fe-3x.dta"
               "braztfp/decomp/olleypakes-op-ipa2-output-notrend-fe-3x-1990.dta" 
               "braztfp/tex/rhotab_op_tbl.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/tex/v4/tfp/haltiw_tfp.tex"
               "brazrloc/tex/v4/tfp/haltiw_lp.tex"
               "brazrloc/tex/v4/tfp/haltiw_all.tex"
               "brazrloc/tex/v4/tfp/haltiw_alt.tex"
               "brazrloc/tex/v4/tfp/ollpak.tex"
               "brazrloc/tex/v4/tfp/ollpak_alt.tex"
               "brazrloc/tex/v4/tfp/ollpak_aerrr.tex" */
    /*   Logs: "brazrloc/logs/tfp-stats.log" */

* do "brazrloc/%stata/%2tab-graph/tariff-data.do"
    /* TARIFF AND FIRM SURVIVAL GRAPHS (similar to rais-sp:firmempl.do) */
    /* INPUT:  "brazaux/auxil/tariff-data.dta"
               "brazrloc/auxil/niv50-shortnames.txt"
               "brazrloc/auxil/sector-subsibge-moredata.dta"
               "brazrloc/tex/v4/natl/duration/indnorloc48m_tbl.dta"
               "brazrloc/tex/v4/natl/duration/mo2rehr36m_tbl.dta"
               "brazrloc/tex/v4/natl/duration/mo2rehr48m_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/indnorloc48m_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr36m_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr48m_tbl.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl/laborstats/tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/laborstats/tarfoutp-mo2rehir36-86-98.eps"
               "brazrloc/graphs/v4/natl/laborstats/tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl-maleprime/laborstats/tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl-maleprime/laborstats/tarfoutp-mo2rehir36-86-98.eps"
               "brazrloc/graphs/v4/natl-maleprime/laborstats/tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/ext/tarfoutp-90-97.eps"
               "brazrloc/graphs/v4/ext/tarfintm-90-97.eps"
               "brazrloc/graphs/v4/ext/erp-90-97.eps"
               "brazrloc/graphs/v4/ext/herfsale-90-97.eps"
               "brazrloc/graphs/v4/ext/exits-90.eps" 
               "brazrloc/graphs/v4/ext/exits-97.eps" 
               "brazrloc/graphs/v4/ext/survival-90.eps" 
               "brazrloc/graphs/v4/ext/survival-97.eps" */
    /*   Logs: "brazrloc/logs/tariff-data.log" */

* do "brazrloc/%stata/%2tab-graph/compadv-data.do"
    /* COMPARATIVE ADVANTAGE AND FIRM SURVIVAL GRAPHS (similar to rais-sp:firmempl.do) */
    /* INPUT:  "brazaux/auxil/tariff-data.dta"
               "brazaux/auxil/comp-adv-niv50.dta" 
               "brazaux/intl/balassa-compadv-niv50.dta"
               "brazcomp/niv-cnae/niv50-en-systematic.tex"
               "brazrloc/auxil/niv50-agg.dta"
               "brazrloc/auxil/niv50-shortnames.txt" 
               "rais/cnae/niv50.do"
               "rais/cnae/niv100.do"
               "ca-us/gdf-ifs/ifs/brazil.csv" */
    /* OUTPUT: "brazrloc/estmat/v4/ext/`advtype'pol_`type'.dta" (where `advtype' in comp exp balc, `type' in b se e r)
               "brazrloc/estmat/v4/ext/`advtype'advreg_`type'.dta" (where `advtype' in comp exp balc, `type' in b se e r) */
    /* Graphs: "brazrloc/graphs/v4/ext/balcadv-res-chg-90-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-chg-90-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-res-chg-86-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-chg-86-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-res-chg-90-98.eps"
               "brazrloc/graphs/v4/ext/balcadv-chg-90-98.eps"
               "brazrloc/graphs/v4/ext/balcadv-res-chg-86-98.eps"
               "brazrloc/graphs/v4/ext/balcadv-chg-86-98.eps"
               "brazrloc/graphs/v4/ext/balcadv-expadv-fe-90.eps"
               "brazrloc/graphs/v4/ext/expadv-compadv-fe-90.eps"
               "brazrloc/graphs/v4/ext/balcadv-90.eps"
               "brazrloc/graphs/v4/ext/balcadv-turned-90.eps"
               "brazrloc/graphs/v4/ext/expadv-90.eps"
               "brazrloc/graphs/v4/ext/balcadv-90-97.eps"
               "brazrloc/graphs/v4/ext/expadv-90-97.eps"
               "brazrloc/graphs/v4/ext/balcadvfe-90-97.eps"
               "brazrloc/graphs/v4/ext/expadvfe-90-97.eps"
               "brazrloc/graphs/v4/ext/balcadv-tarif-86.eps"
               "brazrloc/graphs/v4/ext/balcadv-tarif-90.eps"
               "brazrloc/graphs/v4/ext/expadv-tarif-90.eps"
               "brazrloc/graphs/v4/ext/compadv-90-97.eps"
               "brazrloc/graphs/v4/ext/compadv-tarif-90.eps"
               "brazrloc/graphs/v4/ext/compadv-adj-90-97.eps"
               "brazrloc/graphs/v4/ext/compadvadj-expadvfe-90-97.eps"
               "brazrloc/graphs/v4/ext/tb-ca-91-02.eps"
          TeX: "brazrloc/tex/v4/ext/summ/niv5en.tex" 
               "brazrloc/tex/v4/ext/corr/corr_expadv_yrs.tex"
               "brazrloc/tex/v4/ext/corr/corr_balcadv_yrs.tex"
               "brazrloc/tex/v4/ext/corr/corr_adv.tex" */
    /*   Logs: "brazrloc/logs/compadv-data.log" */

* do "brazrloc/%stata/%2tab-graph/pme-stats.do"
    /* PME-BASED LABOR MARKET GRAPHS AND STATISTICS FOR PRIME-AGE MALES IN METROPOLITAN AREAS */
    /* INPUT:  "brazrloc/tex/v4/pme/tabelas.dta" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/pme/labmkttrns-86-98.eps"
               "brazrloc/graphs/v4/pme/emplshare-86-98.eps"
               "brazrloc/graphs/v4/pme/formemplshare-86-98.eps"
               "brazrloc/graphs/v4/pme/workstatus-86-98.eps"
               "brazrloc/graphs/v4/pme/workstatus-bar-86-98.eps"
               "brazrloc/graphs/v4/pme/workstatus-bar-nowithdr-86-98.eps"
               "brazrloc/graphs/v4/pme/formshare-86-98.eps"
               "brazrloc/graphs/v4/pme/formtrans-86-98.eps"
               "brazrloc/graphs/v4/pme/informtrans-86-98.eps"
          TeX: "brazrloc/tex/v4/pme/labmkttrns_86_98.tex"
               "brazrloc/tex/v4/pme/emplshare_86_98.tex"
               "brazrloc/tex/v4/pme/formemplshare_86_98.tex"
               "brazrloc/tex/v4/pme/formtrans_86_98.tex"
               "brazrloc/tex/v4/pme/informtrans_86_98.tex" */
    /*   Logs: "brazrloc/logs/pme-stats.log" */

* do "brazrloc/%stata/%2tab-graph/pme-stats-aerrr.do"
    /* PME-BASED LABOR MARKET GRAPHS AND STATISTICS FOR ALL WORKERS IN METROPOLITAN AREAS */
    /* INPUT:  "brazrloc/tex/v4/pme/pme-aerrr-pseudo.dta" 
               "brazaux/intl/balassa-compadv-subsibge" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/pme/workstatus-bar-86-98-manf-inlbf.eps"
          TeX: "brazrloc/estmat/v4/pme/summ_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5)
               "brazrloc/tex/v4/pme/emplshare_manfinlbf_90.tex" (`yr' in 90 94 98)
               "brazrloc/tex/v4/pme/emplshare_nowoodinlbf_90.tex" (`yr' in 90 94 98)
               "brazrloc/tex/v4/pme/emplshare_manfinlbf_subs_90.tex" (`yr' in 90 94 98)
               "brazrloc/tex/v4/pme/emplshare_inlbf_90.tex" (`yr' in 90 94 98) */
    /*   Logs: "brazrloc/logs/pme-stats-aerrr.log" */

* do "brazrloc/%stata/%2tab-graph/data-by-sec.do"
    /* TABLE OF MAIN REGRESSORS BY SECTOR */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/tex/v4/ext/summ/ibge.do"
          TeX: "brazrloc/tex/v4/ext/summ/subs_natlmaleprime.tex" */
    /*   Logs: "brazrloc/logs/data-by-sec.log" */ 

* do "brazrloc/%stata/%2tab-graph/katz-murphy.do"
    /* TABLES WITH KATZ-MURPHY (QJE 1992) DECOMPOSITIONS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/tex/v4/natl-maleprime/laborstats/katzmurp`span'.tex" (where `span' in "8689" "9098" "9901" "8698" "8601")
               "brazrloc/tex/v4/metromale-prime/laborstats/katzmurp`span'.tex" (where `span' in "8689" "9098" "9901" "8698" "8601") */
    /*   Logs: "brazrloc/logs/katz-murphy.log" */ 

* do "brazrloc/%stata/%2tab-graph/emplcomp-stats.do"
    /* WORKFORCE RECOMPOSITIONS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" */
    /* OUTPUT: .
       Grpahs: "brazrloc/graphs/v4/natl-maleprime/laborstats/occ-npis-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/natl-maleprime/laborstats/occ-effu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/natl-maleprime/laborstats/occ-stdeffu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/natl-maleprime/laborstats/school-npis-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/natl-maleprime/laborstats/school-effu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/natl-maleprime/laborstats/school-stdeffu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/metromale-prime/laborstats/occ-npis-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/metromale-prime/laborstats/occ-effu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/metromale-prime/laborstats/occ-stdeffu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/metromale-prime/laborstats/school-npis-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") 
               "brazrloc/graphs/v4/metromale-prime/laborstats/school-effu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont")
               "brazrloc/graphs/v4/metromale-prime/laborstats/school-stdeffu-`span'`sector'.eps" (where `span' in "8690" "9097" "9701" "8698" "8601", `sector' in "" "trad" "nont") */
    /*   Logs: "brazrloc/logs/emplcomp-stats.log" */ 

* do "brazrloc/%stata/%2tab-graph/cohort-stats.do"
    /* WORKFORCE RECOMPOSITIONS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazaux/secex/brazaux-exporters.dta"
               "brazrloc/data/pia-data.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/tex/v4/natl/cohortstats/cohort.tex" */
    /*   Logs: "brazrloc/logs/cohort-stats.log" */ 

* do "brazrloc/%stata/%2tab-graph/kim-topel.do"
    /* KIM-TOPEL ENTRY COHORT TABULATIONS */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/auxil/subsibge2aggsec.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta"
               "rais/auxil/metro-pme.dta" */
    /* OUTPUT: none */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/natl/cohortstats/yngold_tradsec.tex"
               "brazrloc/tex/v4/natl/cohortstats/kt_tradsec.tex" */
    /*   Logs: "brazrloc/logs/kim-topel.log" */


* 3. REGRESSIONS
*---------------

* do "brazrloc/%stata/%3regress/separations-natl-maleprime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-natl-maleprime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/separations-metromale-prime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-subsample.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-metromale-prime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/separations-natl-maleprime-cnae.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-natl-maleprime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/cnae_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/cnae_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-natl-maleprime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/separations-metromale-prime-cnae.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-subsample.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-metromale-prime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/cnae_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/cnae_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-metromale-prime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/separations-natl-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN WORKER OF ANY GENDER AT ANY AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-natl-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl/subs_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subs_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-natl-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/separations-natl-subsibge-10pct.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS FOR BRAZILIAN WORKER OF ANY GENDER AT ANY AGE, 10-PERCENT RANDOM SAMPLE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl-10pct.dta"
               "brazrloc/data/rais-cnpj-data-natl-10pct.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/separations-natl-subsibge-10pct.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/subs_dspl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/subs_dspl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-natl-subsibge-10pct.log" */ 

* do "brazrloc/%stata/%3regress/accessions-natl-maleprime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-natl-maleprime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/accessions-metromale-prime-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-subsample.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-metromale-prime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/accessions-natl-maleprime-cnae.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-natl-maleprime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/cnae_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/cnae_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-natl-maleprime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/accessions-metromale-prime-cnae.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta"
               "brazrloc/data/wid-draw-workers-metro-male-subsample.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-metromale-prime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/cnae_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/cnae_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-metromale-prime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/accessions-natl-subsibge.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR BRAZILIAN WORKER OF ANY GENDER AT ANY AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-natl-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl/subs_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subs_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-natl-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/accessions-natl-subsibge-10pct.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF ACCESSIONS FOR BRAZILIAN WORKER OF ANY GENDER AT ANY AGE, 10-PERCENT RANDOM SAMPLE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl-10pct.dta"
               "brazrloc/data/rais-cnpj-data-natl-10pct.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/accessions-natl-subsibge-10pct.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/subs_hire_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/subs_hire_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/accessions-natl-subsibge-10pct.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aspme.do"
    /* CLOGIT REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/separations-metromale-prime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-metromale-prime-subsibge.dta"
               "brazrloc/data/separations-natl-maleprime-cnae.dta"
               "brazrloc/data/separations-metromale-prime-cnae.dta"
               "brazrloc/data/accessions-natl-maleprime-cnae.dta"
               "brazrloc/data/accessions-metromale-prime-cnae.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/dsplhire_subs_aspme_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/dsplhire_cnae_aspme_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aspme.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-paper-natl.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subsdspl_paper_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subshire_paper_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-paper-natl.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-ej-natl.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subsdspl_ej_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subshire_ej_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-ej-natl.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, WITH SECTOR EFFECTS (except initial regression) */ */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl/subsdspl_aer_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subshire_aer_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-nosecfe-natl.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, WITHOUT SECTOR EFFECTS (except one regression) */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl/subsdspl_nosecfe_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subshire_nosecfe_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-nosecfe-natl.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-nosec13-natl.do"
    /* CLOGIT AND LOGIT REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, WITHOUT SECTOR EFFECTS (except one regression) */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl/subsdspl_nosec13_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subshire_nosec13_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-nosec13-natl.log" */ 

* do "brazrloc/%stata/%3regress/hazard-durations-natl-maleprime-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/hazard-durations-natl-maleprime-subsibge.dta" (at first run)
       Graphs: "brazrloc/graphs/v4/natl-maleprime/hazard/kaplanmeier`year'.eps" (where `year' in 1986 1990)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/aic_hzrd_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hzrd_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hzrd_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/hazard-durations-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/hazard-nodyr-durations-natl-maleprime-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/hazard-nodyr-durations-natl-maleprime-subsibge.dta" (at first run)
       Graphs: "brazrloc/graphs/v4/natl-maleprime/hazard-nodyr/kaplanmeier`year'-nodyr.eps" (where `year' in 1986 1990)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/aic_hzrdnodyr_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hzrdnodyr_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_hzrdnodyr_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/hazard-nodyr-durations-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/hazard-durations-natl-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/hazard-durations-natl-subsibge.dta" (at first run)
       Graphs: "brazrloc/graphs/v4/natl/hazard/kaplanmeier`year'.eps" (where `year' in 1986 1990)
       Matrix: "brazrloc/estmat/v4/reg/natl/aic_hzrd_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subs_hzrd_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subs_hzrd_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/hazard-durations-natl-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-natl-maleprime-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-natl-maleprime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-metromale-prime-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta" 
               "brazrloc/data/rais-cnpj-list-metro.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-metromale-prime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale prime/subs_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-natl-maleprime-cnae.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-natl-maleprime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/cnae_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/cnae_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-natl-maleprime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-metromale-prime-cnae.do"
    /* DURATIONS OF REALLOCATION FOR METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-metro-male.dta" 
               "brazrloc/data/rais-cnpj-list-metro.dta"
               "brazrloc/data/rais-cnpj-data-metro.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-metromale-prime-cnae.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/cnae_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale prime/cnae_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-metromale-prime-cnae.log" */ 

* do "brazrloc/%stata/%3regress/ordered-durations-natl-subsibge.do"
    /* DURATIONS OF REALLOCATION FOR MALES AT PRIME AGE ANYWHERE IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" 
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/auxil/wtf-data.dta" 
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/ordered-durations-natl-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl/subs_odur_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subs_odur_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/ordered-durations-natl-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/employment-natl-maleprime-subsibge.do"
    /* EMPLOYMENT REGRESSIONS FOR BRAZILIAN MALES AT PRIME AGE NATIONWIDE */
    /* INPUT:  "brazrloc/data/rais-cnpj-data-natl-nber.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-moredata.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/employment-natl-maleprime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_empl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_empl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/employment-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/employment-metromale-prime-subsibge.do"
    /* EMPLOYMENT REGRESSIONS FOR BRAZILIAN MALES AT PRIME AGE IN METROPOLITAN AREAS */
    /* INPUT:  "brazrloc/data/rais-cnpj-data-metro-nber.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/sector-subsibge-moredata.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/secex/brazaux-exporters.dta" */
    /* OUTPUT: "brazrloc/data/employment-metromale-prime-subsibge.dta" (at first run)
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_empl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_empl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/employment-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/labprod-natl-maleprime-subsibge.do"
    /* LABOR PRODUCTIVITY REGRESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/employment-natl-maleprime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_lnlp_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_lnlp_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprod-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/labprod-metromale-prime-subsibge.do"
    /* LABOR PRODUCTIVITY REGRESSIONS FOR BRAZILIAN MALES AT PRIME AGE IN METROPOLITAN AREAS */
    /* INPUT:  "brazrloc/data/employment-metromale-prime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_lnlp_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_lnlp_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprod-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/labprodlvl-natl-maleprime-subsibge.do"
    /* LABOR PRODUCTIVITY REGRESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/employment-natl-maleprime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl-maleprime/subs_lnlplvl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl-maleprime/subs_lnlplvl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprodlvl-natl-maleprime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/labprodlvl-metromale-prime-subsibge.do"
    /* LABOR PRODUCTIVITY REGRESSIONS OF SEPARATIONS FOR BRAZILIAN MALES AT PRIME AGE IN METROPOLITAN AREAS */
    /* INPUT:  "brazrloc/data/employment-metromale-prime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/metromale-prime/subs_lnlplvl_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/metromale-prime/subs_lnlplvl_iv1st_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprodlvl-metromale-prime-subsibge.log" */ 

* do "brazrloc/%stata/%3regress/summary-stats-paper-natlmaleprime.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR PRIME-AGE MALES NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta"
               "brazrloc/data/hazard-durations-natl-maleprime-subsibge.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/estmat/v4/reg/natl-maleprime/summ_dspl_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) 
               "brazrloc/estmat/v4/reg/natl-maleprime/summ_hire_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) 
               "brazrloc/estmat/v4/reg/natl-maleprime/summ_hzrd_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) */
    /*   Logs: "brazrloc/logs/summary-stats-paper-natlmaleprime.log" */ 

* do "brazrloc/%stata/%3regress/summary-stats-paper-natl.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR ALL WORKERS NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/data/hazard-durations-natl-subsibge.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/estmat/v4/reg/natl/summ_dspl_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) 
               "brazrloc/estmat/v4/reg/natl/summ_hire_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) 
               "brazrloc/estmat/v4/reg/natl/summ_hzrd_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) */
    /*   Logs: "brazrloc/logs/summary-stats-paper-natl.log" */ 

* do "brazrloc/%stata/%3regress/summary-stats-nber-natl.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR PRIME-AGE MALES NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/subsdspl_paper_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/subshire_paper_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/summary-stats-nber-natl.log" */ 

* do "brazrloc/%stata/%3regress/summary-stats-aerrr-natl.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR ALL WORKERS NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/estmat/v4/reg/natl/summ_dspl_aerrr_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) 
               "brazrloc/estmat/v4/reg/natl/summ_hire_aerrr_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) */
    /*   Logs: "brazrloc/logs/summary-stats-aerrr-natl.log" */ 

* do "brazrloc/%stata/%3regress/summary-stats-aerrr-natl10pct.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR ALL WORKERS NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/estmat/v4/reg/natl10pct/summ_dspl_aerrr_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) 
               "brazrloc/estmat/v4/reg/natl10pct/summ_hire_aerrr_`cond'.tex" (where `cond' in allsec balrnk1 balrnk3 balrnk5 indexp timevar) */
    /*   Logs: "brazrloc/logs/summary-stats-aerrr-natl10pct.log" */ 

* do "brazrloc/%stata/%3regress/pme-revision.do"
    /* MULTINOMIAL LOGIT ESTIMATES FOR WORK STATUS TRANSITIONS AMONG BRAZILIAN METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/pme/pme-revision.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/pme/mlogit_tf_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/pme/mlogit_tinf_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/pme/pme-revision.log" */

* do "brazrloc/%stata/%3regress/pme-aerrr.do"
    /* MULTINOMIAL LOGIT ESTIMATES FOR WORK STATUS TRANSITIONS AMONG BRAZILIAN METROPOLITAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/pme/pme-aer-v92.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/pme/mlogitrr_tf_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/pme/mlogitrr_tinf_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/pme-aerrr.log" */

* do "brazrloc/%stata/%3regress/pme-aer-final.do"
    /* MULTINOMIAL LOGIT ESTIMATES FOR WORK STATUS TRANSITIONS AMONG BRAZILIAN INDIVIDUALS OF ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/pme/pme-final.dta"
               "brazrloc/pme/tariffs-intm.dta"
               "brazrloc/pme/tariffs-outp.dta" */
    /* OUTPUT: .
       Matrix: . */
    /*   Logs: "brazrloc/logs/pme-aer-final.log" */

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr.do"
    /* CLOGIT AND FE-IV REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl/subsdspl_aerrr_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subshire_aerrr_`type'.dta" (where `type' in b se e)
               "brazrloc/estmat/v4/reg/natl/subsdspl_u.dta"
               "brazrloc/estmat/v4/reg/natl/subshire_u.dta" */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-intract.do"
    /* CLOGIT AND FE-IV REGRESSIONS OF SEPARATIONS AND ACCESSIONS WITH INTERACTIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl/subsdspl_aerrr_intract_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/summ_dspl_intract_tbl.dta"
               "brazrloc/estmat/v4/reg/natl/subshire_aerrr_intract_`type'.dta" (where `type' in b se e)
               "brazrloc/estmat/v4/reg/natl/summ_hire_intract_tbl.dta" */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-intract.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-10pct.do"
    /* CLOGIT AND FE-IV REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/subsdspl_aerrr_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/subshire_aerrr_`type'.dta" (where `type' in b se e)
               "brazrloc/estmat/v4/reg/natl10pct/subsdspl_u.dta"
               "brazrloc/estmat/v4/reg/natl10pct/subshire_u.dta" */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-10pct.log" */ 

* do "brazrloc/%stata/%3regress/reaccessions-aer-natl-rr.do"
    /* CLOGIT REGRESSIONS OF RE-ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/hazard-durations-natl-subsibge.dta"
               "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl/subsrhir_aerrr_`type'.dta" (where `type' in b se e)
               "brazrloc/estmat/v4/reg/natl/subsm2rhr_aerrr_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/reaccessions-aer-natl-rr.log" */ 

* do "brazrloc/%stata/%3regress/mlogit-xttrans-aer-natl-rr.do"
    /* MULTINOMIAL LOGIT REGRESSIONS OF REALLOCATIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta"
               "brazrloc/data/rais-cnpj-list-natl.dta"
               "brazrloc/auxil/subsibge2aggsec.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/secex/brazaux-exporters.dta"
               "brazrloc/estmat/v4/reg/natl/subsdspl_u.dta" */
    /* OUTPUT: "brazrloc/data/mlogit-xttrans-natl-subsibge.dta"
       Matrix: "brazrloc/estmat/v4/reg/natl/ml_xttrans_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/mlogit-xttrans-aer-natl.log" */ 

* do "brazrloc/%stata/%3regress/mlogit-xttrans-aer-natl-rr-10pct.do"
    /* MULTINOMIAL LOGIT REGRESSIONS OF REALLOCATIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl-10pct.dta"
               "brazrloc/data/rais-cnpj-data-natl-10pct.dta"
               "brazrloc/auxil/subsibge2aggsec.dta"
               "brazrloc/auxil/sector-subsibge-data.dta"
               "brazrloc/data/rais-cnpj-data-natl.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/auxil/wtf-data.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazaux/auxil/cbogrp-outsourcing.dta"
               "brazaux/secex/brazaux-exporters.dta"
               "brazrloc/estmat/v4/reg/natl10pct/subsdspl_u.dta" */
    /* OUTPUT: "brazrloc/data/mlogit-xttrans-natl-subsibge-10pct.dta"
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/ml_xttrans_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/mlogit-xttrans-aer-natl-10pct.log" */ 

* do "brazrloc/%stata/%3regress/prediction-stats-paper-natlmaleprime.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR PRIME-AGE MALES NATIONWIDE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" 
               "brazrloc/estmat/v4/reg/natl-maleprime/subsdspl_paper_b.dta"
               "brazrloc/estmat/v4/reg/natl-maleprime/subshire_paper_b.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/tex/v4/gdp/subs`margin'`mat'_tbl.dta" (where `margin' in dspl hire and `mat' in _coef _tradvdif9290 _tradvdif9490 _tradvdif98900) */
    /*   Logs: "brazrloc/logs/prediction-stats-paper-natlmaleprime.log" */ 

* do "brazrloc/%stata/%3regress/prediction-stats-aerrr-natl.do"
    /* SUMMARY STATISTICS ON SEPARATION AND ACCESSION REGRESSIONS FOR ALL WORKERS NATIONWIDE, REVISED SPECIFICATIONS */
    /* INPUT:  "brazaux/intl/balassa-compadv-subsibge"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/estmat/v4/reg/natl/subsdspl_aerrr_b.dta"
               "brazrloc/estmat/v4/reg/natl/subsdspl_aerrr_intract_b.dta"
               "brazrloc/estmat/v4/reg/natl/subshire_aerrr_b.dta"
               "brazrloc/estmat/v4/reg/natl/subshire_aerrr_intract_b.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/tex/v4/gdp/subs`margin'`mat'_aer_tbl.dta" (where `margin' in dspl hire and `mat' in _coef _tradvdif9290 _tradvdif9490 _tradvdif98900) */
    /*   Logs: "brazrloc/logs/prediction-stats-aerrr-natl.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-natl-maleprime-subsibge-cluster.do"
    /* CLUSTERED-ERROR XTREG REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" */
    /* OUTPUT: . */
    /*   Logs: "brazrloc/logs/separations-accessions-natl-maleprime-subsibge-cluster.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-natl-maleprime-subsibge-cluster.do"
    /* CLUSTERED-ERROR XTREG REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" */
    /* OUTPUT: . */
    /*   Logs: "brazrloc/logs/separations-accessions-natl-maleprime-subsibge-cluster.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-natl-maleprime-cnae-cluster.do"
    /* CLUSTERED-ERROR XTREG REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR BRAZILIAN MALES AT PRIME AGE */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-cnae.dta"
               "brazrloc/data/accessions-natl-maleprime-cnae.dta" */
    /* OUTPUT: . */
    /*   Logs: "brazrloc/logs/separations-accessions-natl-maleprime-cnae-cluster.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-cluster.do"
    /* CLUSTERED-ERROR XTREG REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta" */
    /* OUTPUT: .
       Matrix: . */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-cluster.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-intract-cluster.do"
    /* CLUSTERED-ERROR XTREG REGRESSIONS OF SEPARATIONS AND ACCESSIONS WITH INTERACTIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta" */
    /* OUTPUT: .
       Matrix: . */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-intract-cluster.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-loneway.do"
    /* ONE-WAY ANOVA TO ASSESS NECESSITY OF CLUSTERED-ERROR XTREG REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta" */
    /* OUTPUT: .
       Matrix: . */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-loneway.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-comp-cluster.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl/subsdspl_aerrrclst_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl/subshire_aerrrclst_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-comp-cluster.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-comp-cluster-10pct.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/subsdspl_aerrrclst_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/subshire_aerrrclst_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-comp-cluster-10pct.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-comp-cluster-10pct-cnae.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/sector-cnae-data.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_aerrrclst_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_aerrrclst_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-comp-cluster-10pct-cnae.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-comp-cluster-10pct-pianiv50.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta"
               "brazaux/Xpia/firms-86-98.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/niv50dspl_aerrrclst_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/niv50hire_aerrrclst_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-comp-cluster-10pct-pianiv50.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-xt-cluster-10pct.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-niv50.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_aerrrxt_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_aerrrxt_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-xt-cluster-10pct.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-submit-cluster-10pct-ivonly.do"
    /* IV FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/data/pia-niv50.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_ivonly_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_ivonly_`type'.dta" (where `type' in b se e)
               "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_iv1st_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_iv1st_`type'.dta" (where `type' in b se e) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-submit-cluster-10pct-ivonly.log" */ 

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-submit-cluster-10pct.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_aerrrsubm_`type'.dta" (where `type' in b se e r)
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_aerrrsubm_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-submit-cluster-10pct.log" */

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-submit-cluster-10pct-lponly.do"
    /* LABOR PRODUCTIVITY LEVEL REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_lponly_`type'.dta" (where `type' in b se e r)
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_lponly_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-submit-cluster-10pct-lponly.log" */

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-submit-cluster-10pct-secyrtrd.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE, WITH SECTOR YEAR TRENDS */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/data/pia-niv50.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_secyrtrd_`type'.dta" (where `type' in b se e r)
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_secyrtrd_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-submit-cluster-10pct-secyrtrd.log" */

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-submit-cluster-10pct-xpia.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE, FULL PIA DATA */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-Xdata.dta"
               "brazrloc/data/pia-niv50.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_xpia_`type'.dta" (where `type' in b se e r)
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_xpia_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-submit-cluster-10pct-xpia.log" */

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-submit-cluster-10pct-fdlnlp.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE, PRODUCTIVITY CHANGE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-data.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_fdlnlp_`type'.dta" (where `type' in b se e r)
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_fdlnlp_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-submit-cluster-10pct-fdlnlp.log" */

* do "brazrloc/%stata/%3regress/separations-accessions-aer-natl-rr-submit-cluster-10pct-final.do"
    /* CLUSTERED FE REGRESSIONS OF SEPARATIONS AND ACCESSIONS FOR WORKERS ANY GENDER AND ANY AGE, 10-PERCENT SAMPLE, FINAL SET OF REGRESSIONS */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-data.dta"
               "brazrloc/data/pia-niv50.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: .
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnaedspl_aerrrfinl_`type'.dta" (where `type' in b se e r)
               "brazrloc/estmat/v4/reg/natl10pct/cnaehire_aerrrfinl_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/separations-accessions-aer-natl-rr-submit-cluster-10pct-final.log" */

* do "brazrloc/%stata/%3regress/labprodlvl-aer-natl-rr-submit-cluster-10pct.do"
    /* LABOR PRODUCTIVITY REGRESSIONS FOR PIA FIRMS IN 10-PERCENT SAMPLE */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge-10pct.dta"
               "brazrloc/data/accessions-natl-subsibge-10pct.dta"
               "brazrloc/data/rais-cnpjradic-cnae95-natl-86-98-10pct.dta"
               "brazrloc/auxil/wtf-subsibge-data.dta"
               "brazrloc/data/pia-Xdata.dta"
               "brazrloc/data/pia-niv50.dta"
               "brazaux/intl/vollrath-compadv-subsibge.dta"
               "brazaux/auxil/seclvl.dta" */
    /* OUTPUT: "brazrloc/data/labprodlvl-natl-cnaemix-10pct.dta"
       Matrix: "brazrloc/estmat/v4/reg/natl10pct/cnae_lnlplvl_`type'.dta" (where `type' in b se e r) */
    /*   Logs: "brazrloc/logs/labprodlvl-aer-natl-rr-submit-cluster-10pct.log" */


* 4. TABLES WITH STATISTICS AND RESULTS
*--------------------------------------

* do "brazrloc/%stata/%4tex/laborstat-tables.do"
    /* CONVENTIONAL LABOR MARKET STATISTICS */
    /* INPUT:  "brazrloc/tex/v4/metromale-prime/laborstats/form_metromale_prime_98_tbl.dta"
               "brazrloc/tex/v4/pme/formemplshare_86_98_tbl.dta"
               "brazrloc/tex/v4/metromale/laborstats/form_metromale_98_tbl.dta"
               "brazrloc/tex/v4/metromale/laborstats/form_metromale_sp_98_tbl.dta"
               "brazrloc/tex/v4/natl/laborstats/form_natl_98_tbl.dta"
               "brazrloc/tex/v4/natl/laborstats/form_natl_maleprime_98_tbl.dta"
               "brazrloc/tex/v4/natl/laborstats/form_sp_98_tbl.dta"
               "brazrloc/tex/v4/natl/laborstats/form_pop_98_tbl.dta" 
               "brazrloc/tex/v4/metromale-prime/trans/expsec_empl_col_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/trans/expsec_empl_col_tbl.dta"
               "brazrloc/tex/v4/natl/trans/expsec_empl_col_tbl.dta"
               "brazrloc/tex/v4/`sampl'/trans/`mat'_tbl.dta" (where `mat' in xtcs_indexp_num xtcs_indexp_num_insec xts_indexp_num xts_indexp_insec_num xts_indexp_num_90_91 xts_indexp_num_96_97 and `sampl' in "metromale-prime" "natl-maleprime" "natl") 
               "brazrloc/tex/v4/`sampl'/trans/xts_tradsec_unac_4yr_bygrp_tbl.dta" (where `sampl' in "natl")
               "brazrloc/tex/v4/pme/tabelas.dta" */
    /* OUTPUT: none */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/labor/form.tex"
               "brazrloc/tex/v4/labor/forminform.tex" 
               "brazrloc/tex/v4/labor/expsec.tex"
               "brazrloc/tex/v4/`sampl'/trans/xt_indexp.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl")
               "brazrloc/tex/v4/`sampl'/trans/xt_indexp_per.tex" (where `sampl' in "metromale-prime" "natl-maleprime" "natl") */
    /*   Logs: "brazrloc/logs/laborstat-tables.log" */

* do "brazrloc/%stata/%4tex/compadv-by-secagg.do"
    /* COMPARISONS OF COMPARATIVE ADVANTAGE BY SECTOR DEFINITION */
    /* INPUT:  "rais/base-agg/cnae/aggsec.csv"
               "rais/cnae/cnae-x-isic.dta"
               "rais/cnae/cnae2subsibge.dta"
               "brazaux/intl/balassa-compadv-cnae.dta"
               "brazaux/intl/balassa-compadv-niv50.dta"
               "brazaux/intl/balassa-compadv-subsibge.dta"
               "brazcomp/filters/cnae2niv100.dta"
               "brazcomp/filters/cnae2niv100-app-agric.dta"
               "brazcomp/niv-cnae/cnae3d-en.csv"
               "brazcomp/niv-cnae/niv100.do"
               "brazrloc/auxil/manual/cnae2dgt-subsibge-manual.csv"
               "brazrloc/auxil/manual/niv50-subsibge-manual.csv" */
    /* OUTPUT: "brazrloc/auxil/cnae2dgt-subsibge-pseudoconc.csv"
               "brazrloc/auxil/niv50-subsibge-pseudoconc.csv"
               "brazrloc/auxil/cnae2dgt.do" */
    /* Graphs: .
          TeX: "brazrloc/tex/v4/ext/summ/subscnae.tex"
               "brazrloc/tex/v4/ext/summ/subsniv50.tex"
               "brazrloc/tex/v4/ext/summ/tabcnae.do"
               "brazrloc/tex/v4/ext/summ/tabniv50.do" */
    /*   Logs: "brazrloc/logs/compadv-by-secagg.log" */

* do "brazrloc/%stata/%4tex/compadv-tables.do"
    /* OUTPUT TABLES ON COMPARATIVE ADVANTAGE */
    /* INPUT:  "brazrloc/estmat/v4/ext/comppol_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/ext/compadvreg_`type'.dta" (where `type' in b se e)
               "brazrloc/estmat/v4/ext/exppol_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/ext/expadvreg_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/ext/balcpol_`type'.dta" (where `type' in b se e) 
               "brazrloc/estmat/v4/ext/balcadvreg_`type'.dta" (where `type' in b se e)
               "brazaux/intl/rigidity.dta"
               "brazrloc/%stata/rowlbl-brazrloc.tex" */
    /* OUTPUT: none
          TeX: "brazrloc/tex/v4/ext/reg/compadvreg.tex"
               "brazrloc/tex/v4/ext/reg/compadv.tex"
               "brazrloc/tex/v4/ext/reg/expadvreg.tex"
               "brazrloc/tex/v4/ext/reg/expadv.tex"
               "brazrloc/tex/v4/ext/reg/balcadvreg.tex"
               "brazrloc/tex/v4/ext/reg/balcadv.tex" 
               "brazrloc/tex/v4/labor/rigidity.tex" */
    /*   Logs: none */ 

*  do "brazrloc/%stata/%4tex/laborstat-graphs.do"
    /* DISPLACEMENT, HIRING AND DURATION STATISTICS TO COMPLEMENT REGRESSIONS */
    /* INPUT:  "brazrloc/data/separations-natl-maleprime-subsibge.dta"
               "brazrloc/data/separations-metromale-prime-subsibge.dta"
               "brazrloc/data/accessions-natl-maleprime-subsibge.dta" 
               "brazrloc/data/accessions-metromale-prime-subsibge.dta"
               "brazrloc/data/ordered-durations-natl-maleprime-subsibge.dta"
               "brazrloc/data/ordered-durations-metromale-prime-subsibge.dta"
               "brazrloc/data/ordered-durations-natl-maleprime-cnae.dta"
               "brazrloc/data/ordered-durations-metromale-prime-cnae.dta"
               "brazrloc/%stata/rowlbl-brazrloc.tex" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl-maleprime/allsec-dsplhire.eps"
               "brazrloc/graphs/v4/natl-maleprime/manuf-dsplhire.eps"
               "brazrloc/graphs/v4/metromale-prime/allsec-dsplhire.eps"
               "brazrloc/graphs/v4/metromale-prime/manuf-dsplhire.eps"
               "brazrloc/graphs/v4/natl-maleprime/allsec-layoffquithire.eps"
               "brazrloc/graphs/v4/natl-maleprime/manuf-layoffquithire.eps"
               "brazrloc/graphs/v4/natl-maleprime/manuf-layoffquithire-98.eps"
               "brazrloc/graphs/v4/metromale-prime/allsec-layoffquithire.eps"
               "brazrloc/graphs/v4/metromale-prime/manuf-layoffquithire.eps"
          TeX: "brazrloc/tex/v4/labor/labstat_dspl.tex"
               "brazrloc/tex/v4/labor/labstat_hire.tex"
               "brazrloc/tex/v4/natl-maleprime/laborstats/rehircat_natl_subs.tex" 
               "brazrloc/tex/v4/metromale-prime/laborstats/rehircat_metro_subs.tex"
               "brazrloc/tex/v4/natl-maleprime/laborstats/rehircat_natl_cnae.tex"
               "brazrloc/tex/v4/metromale-prime/laborstats/rehircat_metro_cnae.tex"
               "brazrloc/tex/v4/labor/rehircat.tex" */
    /*   Logs: "brazrloc/logs/laborstat-graphs.log" */

*  do "brazrloc/%stata/%4tex/laborstat-graphs-aer.do"
    /* DISPLACEMENT, HIRING AND DURATION STATISTICS TO COMPLEMENT REGRESSIONS */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta" 
               "brazrloc/data/ordered-durations-natl-subsibge.dta"
               "brazrloc/%stata/rowlbl-brazrloc.tex" */
    /* OUTPUT: none */
    /* Graphs: "brazrloc/graphs/v4/natl/allsec-dsplhire.eps"
               "brazrloc/graphs/v4/natl/manuf-dsplhire.eps"
               "brazrloc/graphs/v4/natl/allsec-layoffquithire.eps"
               "brazrloc/graphs/v4/natl/manuf-layoffquithire.eps"
               "brazrloc/graphs/v4/natl/manuf-layoffquithire-98.eps"
          TeX: "brazrloc/tex/v4/labor/labstataer_dspl.tex"
               "brazrloc/tex/v4/labor/labstatare_hire.tex"
               "brazrloc/tex/v4/natl/laborstats/rehircat_natl_subs.tex" */
    /*   Logs: "brazrloc/logs/laborstat-graphs-aer.log" */

*  do "brazrloc/%stata/%4tex/gdp-impact.do"
    /* TABLES WITH GDP IMPACT MEASURES */
    /* INPUT:  "brazrloc/auxil/origs/pib.csv"
               "brazaux/auxil/minwage.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/indnorloc12mbygrp_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/duration/mo2rehr12mbygrp_tbl.dta"
               "brazrloc/tex/v4/natl-maleprime/reg/paper_frmlnlp_tbl.dta" 
               "brazrloc/tex/v4/gdp/subs`margin'`mat'_tbl.dta" (where `margin' in dspl hire and `mat' in _coef _tradvars90 _tradvars92 _tradvars94 _tradvars98) 
               "brazrloc/tex/v4/gdp/gdpwage_tbl.dta"
               "brazrloc/tex/v4/pme/tabelas.dta" 
               "brazrloc/tex/v4/tfp/ollpak_alt_tbl.dta" */
    /* OUTPUT: none
          TeX: "brazrloc/tex/v4/pme/form2nonform_86_99.tex"
               "brazrloc/tex/v4/gdp/turnpred.tex"
               "brazrloc/tex/v4/gdp/turnpred_paper.tex"
               "brazrloc/tex/v4/gdp/rlocsucc_paper.tex"
               "brazrloc/tex/v4/gdp/gdpwage.tex" 
               "brazrloc/tex/v4/gdp/gdploss.tex"
               "brazrloc/tex/v4/gdp/gdp_turnov.tex" */
    /*   Logs: "brazrloc/logs/gdp-impact.log" */ 

* do "brazrloc/%stata/%4tex/gdp-impact-aer.do"
    /* TABLES WITH GDP IMPACT MEASURES */
    /* INPUT:  "brazrloc/auxil/origs/pib.csv"
               "brazaux/auxil/minwage.dta"
               "brazrloc/tex/v4/natl/duration/indnorloc12mbygrp_tbl.dta"
               "brazrloc/tex/v4/natl/duration/mo2rehr12mbygrp_tbl.dta"
               "brazrloc/tex/v4/natl/reg/aer_frmlnlp_tbl.dta" 
               "brazrloc/tex/v4/gdp/subs`margin'`mat'_tbl.dta" (where `margin' in dspl hire and `mat' in _coef _tradvars90 _tradvars92 _tradvars94 _tradvars98) 
               "brazrloc/tex/v4/gdp/gdpwage_tbl.dta"
               "brazrloc/tex/v4/pme/form2nonform_86_99_tbl.dta" 
               "brazrloc/tex/v4/pme/tabelas.dta" 
               "brazrloc/tex/v4/tfp/ollpak_alt_tbl.dta" */
    /* OUTPUT: none
          TeX: "brazrloc/tex/v4/gdp/turnpredaer.tex"
               "brazrloc/tex/v4/gdp/turnpredaer_paper.tex"
               "brazrloc/tex/v4/gdp/rlocsucc_aer.tex"
               "brazrloc/tex/v4/gdp/gdplossaer.tex"
               "brazrloc/tex/v4/gdp/gdp_turnovaer.tex" */
    /*   Logs: "brazrloc/logs/gdp-impact-aer.log" */ 

*  do "brazrloc/%stata/%4tex/fe-corr-v35.do"
    /* OUTPUT TABLES FOR CLOGIT AND LOGIT REGRESSIONS */
    /* INPUT:  "brazrloc/data/separations-natl-subsibge.dta"
               "brazrloc/data/accessions-natl-subsibge.dta"
               "brazrloc/estmat/v4/reg/natl/subsdspl_u.dta"
               "brazrloc/estmat/v4/reg/natl/subshire_u.dta"
               "brazrloc/auxil/origs/pib.csv"
               "brazrloc/auxil/globfin-annual.dta" */
    /* OUTPUT: .
          TeX: "brazrloc/tex/v4/natl/reg/ureg.tex"
               "brazrloc/tex/v4/natl/reg/yreff.tex"
               "brazrloc/tex/v4/natl/reg/fecorr.tex" */
    /*   Logs: "brazrloc/logs/fe-corr.log" */ 

* do "brazrloc/%stata/%4tex/reg-tab.do"
    /* OUTPUT TABLES FOR CLOGIT AND LOGIT REGRESSIONS */
    /* INPUT:  ... */
    /* OUTPUT: .
          TeX: ... */
    /*   Logs: "brazrloc/logs/reg-tab.log" */ 

*  do "brazrloc/%stata/%4tex/reg-aer-tab-v35.do"
    /* OUTPUT TABLES FOR CLOGIT AND LOGIT REGRESSIONS */
    /* INPUT:  ... */
    /* OUTPUT: .
          TeX: ... */
    /*   Logs: "brazrloc/logs/reg-aer-tab.log" */ 

* do "brazrloc/%stata/%4tex/reg-aer-tab-submit-v36.do"
    /* OUTPUT TABLES FOR TWO-WAY CLUSTERED FE REGRESSIONS */
    /* INPUT:  ... */
    /* OUTPUT: .
          TeX: ... */
    /*   Logs: "brazrloc/logs/reg-aer-tab-submit.log" */ 

* do "brazrloc/%stata/%4tex/reg-aer-tab-submit-v37.do"
    /* OUTPUT TABLES FOR TWO-WAY CLUSTERED FE REGRESSIONS; PARTLY REPLACES OUTPUT FROM reg-aer-tab-submit-v36.do */
    /* INPUT:  ... */
    /* OUTPUT: .
          TeX: ... */
    /*   Logs: "brazrloc/logs/reg-aer-tab-submit-v37.log" */ 


* 5. SIMULATIONS
*---------------

* do "brazrloc/%stata/%5simul/monthly-stat-natl.do"
    /* DURATIONS OF REALLOCATION FOR ANY WORKER IN BRAZIL */
    /* INPUT:  "brazrloc/data/wid-draw-workers-natl.dta" */
    /* OUTPUT: "brazrloc/simul/v4/find-secyr`dur'.dta" (where `dur' in 12 48)
               "brazrloc/simul/v4/find-yr`dur'.dta" (where `dur' in 12 48)
               "brazrloc/simul/v4/norlc-secyr`dur'.dta" (where `dur' in 12 48)
               "brazrloc/simul/v4/norlc-yr`dur'.dta" (where `dur' in 12 48)
               "brazrloc/simul/v4/morhr-secyr`dur'.dta" (where `dur' in 12 48)
               "brazrloc/simul/v4/morhr-yr`dur'.dta" (where `dur' in 12 48) */
    /*   Logs: "brazrloc/logs/monthly-stat-natl.log" */

* do "brazrloc/%stata/%5simul/connect-stats-natl.do"
    /* DURATIONS OF REALLOCATION FOR ANY WORKER IN BRAZIL */
    /* INPUT:  "brazrloc/simul/v4/norlc-yr`dur'.dta" (where `dur' in 12 48)
               "brazrloc/simul/v4/morhr-yr`dur'.dta" (where `dur' in 12 48)
               "brazrloc/simul/v4/find-yr`dur'.dta" (where `dur' in 12 48)
               "brazrloc/tex/v4/natl/duration/indnorloc`dur'm_tbl.dta" (where `dur' in 12 48)
               "brazrloc/tex/v4/natl/duration/mo2rehr`dur'm_tbl.dta" (where `dur' in 12 48)
               "brazrloc/data/separations-natl-subsibge-10pct.dta" (where `dur' in 12 48)
               "brazrloc/data/accessions-natl-subsibge-10pct.dta" (where `dur' in 12 48) */
    /* OUTPUT: "brazrloc/simul/v4/connect-stats-natl-`dur'm.dta" (where `dur' in 12 48)
               "brazrloc/simul/v4/connect-stats-natl-`dur'm-annual.dta" (where `dur' in 12 48)
          eps: "brazrloc/graphs/v4/natl/simul/dsplhire`dur'm.eps" (where `dur' in 12 48)
               "brazrloc/graphs/v4/natl/simul/findhire`dur'm.eps" (where `dur' in 12 48)
               "brazrloc/graphs/v4/natl/simul/totnonempl`dur'm.eps" (where `dur' in 12 48)
               "brazrloc/graphs/v4/natl/simul/dsplhire`dur'm-annual.eps" (where `dur' in 12 48)
               "brazrloc/graphs/v4/natl/simul/findhire`dur'm-annual.eps" (where `dur' in 12 48)
               "brazrloc/graphs/v4/natl/simul/totnonempl`dur'm-annual.eps" (where `dur' in 12 48)
               "brazrloc/graphs/v4/natl/simul/compdspl`dur'm-annual.eps" (where `dur' in 12 48)
               "brazrloc/graphs/v4/natl/simul/comphire`dur'm-annual.eps" (where `dur' in 12 48) */
    /*   Logs: "brazrloc/logs/connect-stats-natl.log" */

* do "brazrloc/%stata/%5simul/simulation.do"
    /* STATISTICS FOR REALLOCATION SIMULATION */
    /* INPUT:  "brazaux/auxil/tariff-data.dta"
               "brazrloc/tex/v4/natl10pct/reg/aerrr_subm_tbl.dta"
               "brazrloc/simul/v4/connect-stats-natl-12m.dta"
               "brazrloc/simul/v4/connect-stats-natl-12m-annual.dta"
               "brazrloc/simul/v4/connect-stats-natl-48m.dta"
               "brazrloc/simul/v4/connect-stats-natl-48m-annual.dta" */
    /* OUTPUT: .
          eps: "brazrloc/graphs/v4/natl/simul/pnad-totnonempl48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/pnad-totnonempl48m-annual-1990.eps"
               "brazrloc/graphs/v4/natl/simul/infer-indfind-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/infer-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/infer-dsplhire48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/infer-findhire48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/infer-totnonempl48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/infer-totnonempl48m-annual-1990.eps"
               "brazrloc/graphs/v4/natl/simul/simulpnad-totnonempl48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/simulpnad-totnonempl48m-annual-1990.eps"
               "brazrloc/graphs/v4/natl/simul/simul-indfind-48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/simulpnad-indfind-48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/simulfix-tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulvar-tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulpnad-tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulminpnad-tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulmaxpnad-tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulfix-tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulvar-tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulpnad-tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulminpnad-tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/simulmaxpnad-tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulpnad-totnonempl48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulpnad-totnonempl48m-annual-1990.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulminpnad-totnonempl48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulminpnad-totnonempl48m-annual-1990.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulmaxpnad-totnonempl48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulmaxpnad-totnonempl48m-annual-1990.eps"
               "brazrloc/graphs/v4/natl/simul/simulminpnad-totnonempl48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/simulminpnad-totnonempl48m-annual-1990.eps"
               "brazrloc/graphs/v4/natl/simul/simulmaxpnad-totnonempl48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/simulmaxpnad-totnonempl48m-annual-1990.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimul-indfind-48m-annual.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulpnad-tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulminpnad-tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulmaxpnad-tarfoutp-indnorloc48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulpnad-tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulminpnad-tarfoutp-mo2rehir48-86-98.eps"
               "brazrloc/graphs/v4/natl/simul/cumsimulmaxpnad-tarfoutp-mo2rehir48-86-98.eps" */
    /*   Logs: "brazrloc/logs/simulation.log" */ 
